@@ -2,7 +2,7 @@
 /*! \file
  * \brief Data compression and decompression
  *
- * Copyright (c) 2015-2020 by the developers. See the LICENSE file for details.
+ * Copyright (c) 2015-2024 by the developers. See the LICENSE file for details.
  *
  * If nothing else is specified, function return zero to indicate success
  * and a negative value to indicate an error.
@@ -161,7 +161,8 @@ static voidpf  cmpr_zlib_alloc(voidpf opaque, uInt items, uInt size)
    void*  rv;
    size_t  len = (size_t) items * (size_t) size;
 
-   rv = posix_malloc(len);
+   (void) opaque;
+   rv = api_posix_malloc(len);
    if(NULL != rv)  { res = (voidpf) rv; }
 
    return(res);
@@ -177,7 +178,8 @@ static voidpf  cmpr_zlib_alloc(voidpf opaque, uInt items, uInt size)
 
 static void  cmpr_zlib_free(voidpf  opaque, voidpf  address)
 {
-   posix_free((void*) address);
+   (void) opaque;
+   api_posix_free((void*) address);
 
    return;
 }
@@ -199,15 +201,15 @@ static void  cmpr_zlib_free(voidpf  opaque, voidpf  address)
  * - -1 on error
  */
 
-static posix_ssize_t  cmpr_send_i(void*  stream, const void*  buf, size_t  len,
-                                  int  flush)
+static api_posix_ssize_t  cmpr_send_i(void*  stream, const void*  buf,
+                                      size_t  len, int  flush)
 {
    struct cmpr_stream*  s = (struct cmpr_stream*) stream;
-   posix_ssize_t  res = -1;
+   api_posix_ssize_t  res = -1;
 #  if CFG_USE_ZLIB
    z_streamp  p;
    int  rv;
-   posix_ssize_t  rv2;
+   api_posix_ssize_t  rv2;
    size_t  i;
    size_t  len2;
    int  zflush;
@@ -249,7 +251,7 @@ static posix_ssize_t  cmpr_send_i(void*  stream, const void*  buf, size_t  len,
                   memcpy((void*) s->tx_buf_in, buf, len);
                   p->next_in = (Bytef*) s->tx_buf_in;
                   p->avail_in = (uInt) len;
-                  res = (posix_ssize_t) len;
+                  res = (api_posix_ssize_t) len;
                }
                /* Check whether TX output buffer is full */
                if(p->avail_out)
@@ -280,6 +282,7 @@ static posix_ssize_t  cmpr_send_i(void*  stream, const void*  buf, size_t  len,
                                     "Stream object corrupted");
                         /* No break here is intended */
                      }
+                     /* FALLTHROUGH */
                      default:
                      {
                         /* Fatal error */
@@ -306,9 +309,9 @@ static posix_ssize_t  cmpr_send_i(void*  stream, const void*  buf, size_t  len,
                         rv2 = (*s->tx_send)(s->sd,
                                             &s->tx_buf_out[i], len2 - i, 0);
                      }
-                     while( (posix_ssize_t) -1 == rv2
-                            && POSIX_EINTR == posix_errno );
-                     if((posix_ssize_t) -1 == rv2)
+                     while( (api_posix_ssize_t) -1 == rv2
+                            && API_POSIX_EINTR == api_posix_errno );
+                     if((api_posix_ssize_t) -1 == rv2)
                      {
                         PRINT_ERROR("cmpr_send(): Writing data "
                                     "to underlaying protocol failed");
@@ -359,7 +362,7 @@ static posix_ssize_t  cmpr_send_i(void*  stream, const void*  buf, size_t  len,
  * - -1 on error
  */
 
-posix_ssize_t  cmpr_send(void*  stream, const void*  buf, size_t  len)
+api_posix_ssize_t  cmpr_send(void*  stream, const void*  buf, size_t  len)
 {
 #  if CMPR_DEBUG
    printf("%s--- TX ------------------------\n", MAIN_ERR_PREFIX);
@@ -385,7 +388,7 @@ int  cmpr_flush(void*  stream)
 {
    int  res = -1;
    char  buf = 0;
-   posix_ssize_t  rv;
+   api_posix_ssize_t  rv;
 
 #  if CMPR_DEBUG
    printf("%sFlush requested\n", MAIN_ERR_PREFIX);
@@ -411,7 +414,7 @@ int  cmpr_terminate(void*  stream)
 {
    int  res = -1;
    char  buf = 0;
-   posix_ssize_t  rv;
+   api_posix_ssize_t  rv;
 
 #  if CMPR_DEBUG
    printf("%sTerminate requested\n", MAIN_ERR_PREFIX);
@@ -440,14 +443,14 @@ int  cmpr_terminate(void*  stream)
  * - -1 on error
  */
 
-posix_ssize_t  cmpr_recv(void*  stream, void*  buf, size_t  len, int  peek)
+api_posix_ssize_t  cmpr_recv(void*  stream, void*  buf, size_t  len, int  peek)
 {
    struct cmpr_stream*  s = (struct cmpr_stream*) stream;
-   posix_ssize_t  res = -1;
+   api_posix_ssize_t  res = -1;
 #  if CFG_USE_ZLIB
    z_streamp  p;
    int  rv;
-   posix_ssize_t  rv2;
+   api_posix_ssize_t  rv2;
    size_t  len2;
    size_t  remain;
 #  endif  /* CFG_USE_ZLIB */
@@ -499,6 +502,7 @@ posix_ssize_t  cmpr_recv(void*  stream, void*  buf, size_t  len, int  peek)
                                        "stream object corrupted");
                            /* No break here is intended */
                         }
+                        /* FALLTHROUGH */
                         case Z_NEED_DICT:
                         case Z_MEM_ERROR:
                         default:
@@ -542,7 +546,7 @@ posix_ssize_t  cmpr_recv(void*  stream, void*  buf, size_t  len, int  peek)
                            p->avail_out = (uInt) CMPR_BUFSIZE;
                         }
                      }
-                     res = (posix_ssize_t) len2;
+                     res = (api_posix_ssize_t) len2;
                   }
                   /* Check whether RX input buffer is empty */
                   if(!res && !p->avail_in)
@@ -555,9 +559,9 @@ posix_ssize_t  cmpr_recv(void*  stream, void*  buf, size_t  len, int  peek)
                         /* Use function registered by stream constructor */
                         rv2 = (*s->rx_recv)(s->sd, s->rx_buf_in, len2, 0);
                      }
-                     while( (posix_ssize_t) -1 == rv2
-                            && POSIX_EINTR == posix_errno );
-                     if((posix_ssize_t) -1 == rv2)
+                     while( (api_posix_ssize_t) -1 == rv2
+                            && API_POSIX_EINTR == api_posix_errno );
+                     if((api_posix_ssize_t) -1 == rv2)
                      {
                         PRINT_ERROR("cmpr_recv(): Reading data "
                                     "from underlaying protocol failed");
@@ -624,7 +628,7 @@ struct cmpr_stream*  cmpr_stream_constructor( unsigned int  alg, int  sd,
 #  endif  /* CFG_USE_ZLIB */
 
    /* Allocate and initialize data stream object */
-   res = (struct cmpr_stream*) posix_malloc(sizeof(struct cmpr_stream));
+   res = (struct cmpr_stream*) api_posix_malloc(sizeof(struct cmpr_stream));
    if(NULL == res)  { error = 1; }
    else
    {
@@ -653,10 +657,10 @@ struct cmpr_stream*  cmpr_stream_constructor( unsigned int  alg, int  sd,
    /* Allocate data buffers */
    if(!error)
    {
-      res->tx_buf_in = (char*) posix_malloc(CMPR_BUFSIZE);
-      res->tx_buf_out = (char*) posix_malloc(CMPR_BUFSIZE);
-      res->rx_buf_in = (char*) posix_malloc(CMPR_BUFSIZE);
-      res->rx_buf_out = (char*) posix_malloc(CMPR_BUFSIZE);
+      res->tx_buf_in = (char*) api_posix_malloc(CMPR_BUFSIZE);
+      res->tx_buf_out = (char*) api_posix_malloc(CMPR_BUFSIZE);
+      res->rx_buf_in = (char*) api_posix_malloc(CMPR_BUFSIZE);
+      res->rx_buf_out = (char*) api_posix_malloc(CMPR_BUFSIZE);
       if(NULL == res->tx_buf_in || NULL == res->tx_buf_out
          || NULL == res->rx_buf_in || NULL == res->rx_buf_out)
       {
@@ -673,8 +677,8 @@ struct cmpr_stream*  cmpr_stream_constructor( unsigned int  alg, int  sd,
 #  if CFG_USE_ZLIB
          case CMPR_ALG_DEFLATE:
          {
-            res->tx = posix_malloc(sizeof(z_stream));
-            res->rx = posix_malloc(sizeof(z_stream));
+            res->tx = api_posix_malloc(sizeof(z_stream));
+            res->rx = api_posix_malloc(sizeof(z_stream));
             if(NULL == res->tx || NULL == res->rx)
             {
                PRINT_ERROR("Memory allocation for zlib streams failed");
@@ -740,13 +744,13 @@ struct cmpr_stream*  cmpr_stream_constructor( unsigned int  alg, int  sd,
    {
       if(NULL != res)
       {
-         posix_free((void*) res->tx);
-         posix_free((void*) res->rx);
-         posix_free((void*) res->tx_buf_in);
-         posix_free((void*) res->tx_buf_out);
-         posix_free((void*) res->rx_buf_in);
-         posix_free((void*) res->rx_buf_out);
-         posix_free((void*) res);
+         api_posix_free((void*) res->tx);
+         api_posix_free((void*) res->rx);
+         api_posix_free((void*) res->tx_buf_in);
+         api_posix_free((void*) res->tx_buf_out);
+         api_posix_free((void*) res->rx_buf_in);
+         api_posix_free((void*) res->rx_buf_out);
+         api_posix_free((void*) res);
          res = NULL;
       }
    }
@@ -800,17 +804,17 @@ void  cmpr_stream_destructor(void*  stream)
             break;
          }
       }
-      posix_free((void*) s->rx);
-      posix_free((void*) s->tx);
+      api_posix_free((void*) s->rx);
+      api_posix_free((void*) s->tx);
 
       /* Free data buffers */
-      posix_free((void*) s->rx_buf_out);
-      posix_free((void*) s->rx_buf_in);
-      posix_free((void*) s->tx_buf_out);
-      posix_free((void*) s->tx_buf_in);
+      api_posix_free((void*) s->rx_buf_out);
+      api_posix_free((void*) s->rx_buf_in);
+      api_posix_free((void*) s->tx_buf_out);
+      api_posix_free((void*) s->tx_buf_in);
 
       /* Free stream object */
-      posix_free(stream);
+      api_posix_free(stream);
    }
 }
 
