@@ -2,7 +2,7 @@
 /*! \file
  * \brief Configuration handling
  *
- * Copyright (c) 2012-2023 by the developers. See the LICENSE file for details.
+ * Copyright (c) 2012-2024 by the developers. See the LICENSE file for details.
  *
  * If nothing else is specified, functions return zero to indicate success
  * and a negative value to indicate an error.
@@ -48,7 +48,7 @@
 #define MAIN_ERR_PREFIX  "CONF: "
 
 /*! \brief Permissions for config file */
-#define CONF_PERM  (posix_mode_t) (POSIX_S_IRUSR | POSIX_S_IWUSR)
+#define CONF_PERM  (api_posix_mode_t) (API_POSIX_S_IRUSR | API_POSIX_S_IWUSR)
 
 
 /* ========================================================================== */
@@ -131,7 +131,7 @@ static void  conf_init_configuration(struct conf*  cfg)
    conf_add_entry_int(cfg, CONF_TILE_Y, "tile_y:", 120);
 
    /* NNTP server */
-   string = (char*) posix_malloc(strlen(server_default) + (size_t) 1);
+   string = (char*) api_posix_malloc(strlen(server_default) + (size_t) 1);
    if(NULL == string)  { error = 1; }
    else
    {
@@ -140,7 +140,7 @@ static void  conf_init_configuration(struct conf*  cfg)
    }
 
    /* NNTP service (port) */
-   string = (char*) posix_malloc(strlen(service_default) + (size_t) 1);
+   string = (char*) api_posix_malloc(strlen(service_default) + (size_t) 1);
    if(NULL == string)  { error = 1; }
    else
    {
@@ -154,14 +154,14 @@ static void  conf_init_configuration(struct conf*  cfg)
    /* Authentication against NNTP server */
    conf_add_entry_int(cfg, CONF_AUTH, "auth:", 0);
    conf_add_entry_int(cfg, CONF_IMMEDAUTH, "immedauth:", 1);
-   empty = (char*) posix_malloc((size_t) 1);
+   empty = (char*) api_posix_malloc((size_t) 1);
    if(NULL == empty)  { error = 1; }
    else
    {
       empty[0] = 0;
       conf_add_entry_string(cfg, CONF_USER, "user:", empty);
    }
-   empty = (char*) posix_malloc((size_t) 1);
+   empty = (char*) api_posix_malloc((size_t) 1);
    if(NULL == empty)  { error = 1; }
    else
    {
@@ -173,7 +173,7 @@ static void  conf_init_configuration(struct conf*  cfg)
    conf_add_entry_int(cfg, CONF_CAC, "cac:", 250);
 
    /* "From" name and E-Mail address  */
-   empty = (char*) posix_malloc((size_t) 1);
+   empty = (char*) api_posix_malloc((size_t) 1);
    if(NULL == empty)  { error = 1; }
    else
    {
@@ -182,7 +182,7 @@ static void  conf_init_configuration(struct conf*  cfg)
    }
 
    /* "Reply-To" name and E-Mail address  */
-   empty = (char*) posix_malloc((size_t) 1);
+   empty = (char*) api_posix_malloc((size_t) 1);
    if(NULL == empty)  { error = 1; }
    else
    {
@@ -191,7 +191,7 @@ static void  conf_init_configuration(struct conf*  cfg)
    }
 
    /* Fully qualified domain name (FQDN) */
-   empty = (char*) posix_malloc((size_t) 1);
+   empty = (char*) api_posix_malloc((size_t) 1);
    if(NULL == empty)  { error = 1; }
    else
    {
@@ -200,7 +200,7 @@ static void  conf_init_configuration(struct conf*  cfg)
    }
 
    /* Pathname of shared newsrc file */
-   empty = (char*) posix_malloc((size_t) 1);
+   empty = (char*) api_posix_malloc((size_t) 1);
    if(NULL == empty)  { error = 1; }
    else
    {
@@ -209,7 +209,7 @@ static void  conf_init_configuration(struct conf*  cfg)
    }
 
    /* Pathname of shared scorerc file */
-   empty = (char*) posix_malloc((size_t) 1);
+   empty = (char*) api_posix_malloc((size_t) 1);
    if(NULL == empty)  { error = 1; }
    else
    {
@@ -218,7 +218,7 @@ static void  conf_init_configuration(struct conf*  cfg)
    }
 
    /* Introduction line format */
-   string = (char*) posix_malloc(strlen(intro_default) + (size_t) 1);
+   string = (char*) api_posix_malloc(strlen(intro_default) + (size_t) 1);
    if(NULL == string)  { error = 1; }
    else
    {
@@ -227,7 +227,7 @@ static void  conf_init_configuration(struct conf*  cfg)
    }
 
    /* Organization name */
-   empty = (char*) posix_malloc((size_t) 1);
+   empty = (char*) api_posix_malloc((size_t) 1);
    if(NULL == empty)  { error = 1; }
    else
    {
@@ -242,7 +242,7 @@ static void  conf_init_configuration(struct conf*  cfg)
    conf_add_entry_int(cfg, CONF_ONLYUR, "onlyur:", 0);
 
    /* Secret for Cancel-Key */
-   empty = (char*) posix_malloc((size_t) 1);
+   empty = (char*) api_posix_malloc((size_t) 1);
    if(NULL == empty)  { error = 1; }
    else
    {
@@ -251,7 +251,7 @@ static void  conf_init_configuration(struct conf*  cfg)
    }
 
    /* Pathname of external article editor */
-   empty = (char*) posix_malloc((size_t) 1);
+   empty = (char*) api_posix_malloc((size_t) 1);
    if(NULL == empty)  { error = 1; }
    else
    {
@@ -260,7 +260,7 @@ static void  conf_init_configuration(struct conf*  cfg)
    }
 
    /* Pathname of external article postprocessor */
-   empty = (char*) posix_malloc((size_t) 1);
+   empty = (char*) api_posix_malloc((size_t) 1);
    if(NULL == empty)  { error = 1; }
    else
    {
@@ -269,7 +269,7 @@ static void  conf_init_configuration(struct conf*  cfg)
    }
 
    /* Pathname of external inews */
-   empty = (char*) posix_malloc((size_t) 1);
+   empty = (char*) api_posix_malloc((size_t) 1);
    if(NULL == empty)  { error = 1; }
    else
    {
@@ -284,7 +284,7 @@ static void  conf_init_configuration(struct conf*  cfg)
    conf_add_entry_int(cfg, CONF_QUOTEUNIFY, "quote_unify:", 1);
 
    /* POSIX ERE (Extended Regular Expression) to match test groups */
-   string = (char*) posix_malloc(strlen(test_ere_default) + (size_t) 1);
+   string = (char*) api_posix_malloc(strlen(test_ere_default) + (size_t) 1);
    if(NULL == string)  { error = 1; }
    else
    {
@@ -293,7 +293,7 @@ static void  conf_init_configuration(struct conf*  cfg)
    }
 
    /* Keywords to set for test groups (on ERE match) */
-   string = (char*) posix_malloc(strlen(test_kwords_default) + (size_t) 1);
+   string = (char*) api_posix_malloc(strlen(test_kwords_default) + (size_t) 1);
    if(NULL == string)  { error = 1; }
    else
    {
@@ -309,7 +309,7 @@ static void  conf_init_configuration(struct conf*  cfg)
    conf_add_entry_int(cfg, CONF_CRL_UPD_IV, "crl_upd_iv:", 20);
 
    /* TLS certificate CRL update timestamp */
-   string = (char*) posix_malloc(strlen(crl_upd_ts_default) + (size_t) 1);
+   string = (char*) api_posix_malloc(strlen(crl_upd_ts_default) + (size_t) 1);
    if(NULL == string)  { error = 1; }
    else
    {
@@ -339,7 +339,7 @@ static void  conf_init_configuration(struct conf*  cfg)
    conf_add_entry_int(cfg, CONF_COMPRESSION, "nntp_compression:", 0);
 
    /* Signature file */
-   string = (char*) posix_malloc(strlen(sigfile_default) + (size_t) 1);
+   string = (char*) api_posix_malloc(strlen(sigfile_default) + (size_t) 1);
    if(NULL == string)  { error = 1; }
    else
    {
@@ -366,7 +366,7 @@ static void  conf_init_configuration(struct conf*  cfg)
    conf_add_entry_int(cfg, CONF_ENABLE_UAGENT, "enable_uagent_hfield:", 1);
 
    /* Initial greeting */
-   empty = (char*) posix_malloc((size_t) 1);
+   empty = (char*) api_posix_malloc((size_t) 1);
    if(NULL == empty)  { error = 1; }
    else
    {
@@ -388,12 +388,18 @@ static void  conf_init_configuration(struct conf*  cfg)
    /* Color for external citation */
    conf_add_entry_int(cfg, CONF_COLOR_EXTERNAL, "color_external:", 88);
 
+   /* Color for hyperlink */
+   conf_add_entry_int(cfg, CONF_COLOR_HYPERLINK, "color_hyperlink:", 216);
+
    /* Colors of thread citation level */
    conf_add_entry_int(cfg, CONF_COLOR_LEVEL1, "color_level1:", 140);
    conf_add_entry_int(cfg, CONF_COLOR_LEVEL2, "color_level2:", 152);
    conf_add_entry_int(cfg, CONF_COLOR_LEVEL3, "color_level3:", 91);
    conf_add_entry_int(cfg, CONF_COLOR_LEVEL4, "color_level4:", 75);
 
+   /* Kill threshold (articles below that score will be killed) */
+   conf_add_entry_int(cfg, CONF_SCORE_KILL_TH, "kill_threshold:", -9999);
+
    /* On success, store flag that configuration was initialized */
    if(error)  { PRINT_ERROR("Initializing configuration failed"); }
    else  { conf_initialized = 1; }
@@ -415,7 +421,7 @@ static int  conf_get_confpathname(const char**  confpathname,
    *confpathname = xdg_get_confdir(CFG_NAME);
    if(NULL != *confpathname)
    {
-      rv = fu_create_path(*confpathname, (posix_mode_t) POSIX_S_IRWXU);
+      rv = fu_create_path(*confpathname, (api_posix_mode_t) API_POSIX_S_IRWXU);
       if(0 == rv)
       {
          /* Store config file pathname */
@@ -431,7 +437,7 @@ static int  conf_get_confpathname(const char**  confpathname,
    if(0 != res)
    {
       PRINT_ERROR("Cannot create config file pathname");
-      posix_free((void*) *confpathname);
+      api_posix_free((void*) *confpathname);
       *confpathname = NULL;
    }
 
@@ -488,7 +494,7 @@ static int  conf_extract_entry(char*  line, struct conf*  target)
              * Allocate memory for string entry
              * This memory is not released until program exit.
              */
-            sbuf = (char*) posix_malloc(strlen(string) + (size_t) 1);
+            sbuf = (char*) api_posix_malloc(strlen(string) + (size_t) 1);
             if(NULL == sbuf)
             {
                PRINT_ERROR("Cannot allocate memory for config file entry");
@@ -499,7 +505,7 @@ static int  conf_extract_entry(char*  line, struct conf*  target)
             {
                strcpy(sbuf, string);
                secure_clear_string(target->val.s);
-               posix_free((void*) target->val.s);
+               api_posix_free((void*) target->val.s);
                target->val.s = sbuf;
             }
          }
@@ -535,21 +541,21 @@ static int  conf_update_entry(char**  line, size_t  len, struct conf*  target)
             if(CONF_TYPE_INT == target->type)
             {
                /* Update integer entry */
-               reqd = posix_snprintf(*line, len, "%s %d\n",
-                                     target->label, target->val.i);
+               reqd = api_posix_snprintf(*line, len, "%s %d\n",
+                                         target->label, target->val.i);
             }
             if(CONF_TYPE_STRING == target->type)
             {
                /* Update string entry */
-               reqd = posix_snprintf(*line, len, "%s %s\n",
-                                     target->label, target->val.s);
+               reqd = api_posix_snprintf(*line, len, "%s %s\n",
+                                         target->label, target->val.s);
             }
             if(0 > reqd)  { break; }
             else if(len <= (size_t) reqd)
             {
                /* Allocate more memory */
-               if(POSIX_SIZE_MAX <= (size_t) reqd)  { break; }
-               string = (char*) posix_realloc(*line, (size_t) (reqd + 1));
+               if(API_POSIX_SIZE_MAX <= (size_t) reqd)  { break; }
+               string = (char*) api_posix_realloc(*line, (size_t) (reqd + 1));
                if(NULL == string)  { break; }
                else  { *line = string; }
             }
@@ -570,16 +576,16 @@ static int  conf_import_configuration(struct conf*  cfg, FILE*  fs)
    int  res = -1;
    char*  line = NULL;
    size_t  len = 0;
-   posix_ssize_t  readlen;
+   api_posix_ssize_t  readlen;
    unsigned int  i;
 
    while(1)
    {
       /* Read line */
-      readlen = posix_getline(&line, &len, fs);
+      readlen = api_posix_getline(&line, &len, fs);
       if(-1 == readlen)
       {
-         if(POSIX_ENOMEM == posix_errno)
+         if(API_POSIX_ENOMEM == api_posix_errno)
          {
             PRINT_ERROR("Cannot assign memory for config file parser");
          }
@@ -613,7 +619,7 @@ static int  conf_import_configuration(struct conf*  cfg, FILE*  fs)
 
    /* Release memory for line buffer */
    secure_clear_string(line);
-   posix_free((void*) line);
+   api_posix_free((void*) line);
 
    return(res);
 }
@@ -628,7 +634,7 @@ static int  conf_export_configuration(struct conf*  cfg,
    int  res = -1;
    char*  line = NULL;
    size_t  len = 0;
-   posix_ssize_t  readlen;
+   api_posix_ssize_t  readlen;
    int  rv;
    unsigned int  i;
    size_t  reqd;
@@ -637,10 +643,10 @@ static int  conf_export_configuration(struct conf*  cfg,
    while(1)
    {
       /* Read line */
-      readlen = posix_getline(&line, &len, fs);
+      readlen = api_posix_getline(&line, &len, fs);
       if(-1 == readlen)
       {
-         if(POSIX_ENOMEM == posix_errno)
+         if(API_POSIX_ENOMEM == api_posix_errno)
          {
             PRINT_ERROR("Cannot assign memory for config file parser");
          }
@@ -684,11 +690,11 @@ static int  conf_export_configuration(struct conf*  cfg,
          {
             /* Create new entry */
             reqd = strlen(cfg[i].label);
-            if(POSIX_SIZE_MAX <= reqd)  { break; }
+            if(API_POSIX_SIZE_MAX <= reqd)  { break; }
             if(reqd + (size_t) 1 > len)
             {
                /* Allocate more memory */
-               p = (char*) posix_realloc(line, reqd + (size_t) 1);
+               p = (char*) api_posix_realloc(line, reqd + (size_t) 1);
                if (NULL != p)  line = p;
             }
             strncpy(line, cfg[i].label, len);
@@ -708,7 +714,7 @@ static int  conf_export_configuration(struct conf*  cfg,
    }
 
    /* Release memory for line buffer */
-   posix_free((void*) line);
+   api_posix_free((void*) line);
 
    return(res);
 }
@@ -734,7 +740,7 @@ void  conf_delete(struct conf*  cfg)
          if(CONF_TYPE_STRING == cfg[i].type)
          {
             secure_clear_string(config[i].val.s);
-            posix_free((void*) cfg[i].val.s);
+            api_posix_free((void*) cfg[i].val.s);
             cfg[i].val.s = NULL;
          }
       }
@@ -782,8 +788,8 @@ int  conf_load(struct conf*  cfg)
          }
 
          /* Open and lock config file */
-         res = fu_open_file(confpathname, &fd, POSIX_O_RDWR | POSIX_O_CREAT,
-                            CONF_PERM);
+         res = fu_open_file(confpathname, &fd,
+                            API_POSIX_O_RDWR | API_POSIX_O_CREAT, CONF_PERM);
          if(!res)  { res = fu_lock_file(fd); }
          if(!res)  { res = fu_assign_stream(fd, &fs, "r"); }
 
@@ -795,7 +801,7 @@ int  conf_load(struct conf*  cfg)
       fu_close_file(&fd, &fs);
 
       /* Release memory for pathname */
-      posix_free((void*) confpathname);
+      api_posix_free((void*) confpathname);
 
       /* Delete configuration again on error */
       if(res)  { conf_delete(cfg); }
@@ -832,8 +838,8 @@ int  conf_store(struct conf*  cfg)
    /* Open and lock config file */
    if(!res)
    {
-      res = fu_open_file(confpathname, &fd, POSIX_O_RDWR | POSIX_O_CREAT,
-                         CONF_PERM);
+      res = fu_open_file(confpathname, &fd,
+                         API_POSIX_O_RDWR | API_POSIX_O_CREAT, CONF_PERM);
       if(!res)  { res = fu_lock_file(fd); }
       if(!res)  { res = fu_assign_stream(fd, &fs, "r"); }
    }
@@ -842,8 +848,8 @@ int  conf_store(struct conf*  cfg)
    if(!res)
    {
       res = fu_open_file(tmppathname, &fd_tmp,
-                         POSIX_O_WRONLY | POSIX_O_CREAT | POSIX_O_TRUNC,
-                         CONF_PERM);
+                         API_POSIX_O_WRONLY | API_POSIX_O_CREAT
+                         | API_POSIX_O_TRUNC, CONF_PERM);
       /*
        * Because we have the lock for the config file, it is allowed to
        * assume that no other instance of the program currently use the
@@ -867,7 +873,7 @@ int  conf_store(struct conf*  cfg)
    if(!res)  { res = fu_sync(fd_tmp, fs_tmp); }
 
    /* Rename temporary file to config file */
-   if(!res)  { res = posix_rename(tmppathname, confpathname); }
+   if(!res)  { res = api_posix_rename(tmppathname, confpathname); }
 
    /* Try to unlink temporary file after error */
    if(res)
@@ -888,8 +894,8 @@ int  conf_store(struct conf*  cfg)
    }
 
    /* Release memory for file pathnames */
-   posix_free((void*) tmppathname);
-   posix_free((void*) confpathname);
+   api_posix_free((void*) tmppathname);
+   api_posix_free((void*) confpathname);
 
    return(res);
 }
@@ -920,12 +926,12 @@ int  conf_string_replace(struct conf*  cfg, const char*  s)
       if(CONF_TYPE_STRING == cfg->type)
       {
          len = strlen(s);
-         p = posix_malloc(++len);
+         p = api_posix_malloc(++len);
          if(NULL != p)
          {
             strcpy(p, s);
             secure_clear_string(cfg->val.s);
-            posix_free((void*) cfg->val.s);
+            api_posix_free((void*) cfg->val.s);
             cfg->val.s = p;
             res = 0;
          }
