@@ -2,7 +2,7 @@
 /*! \file
  * \brief Article header database (cache)
  *
- * Copyright (c) 2012-2021 by the developers. See the LICENSE file for details.
+ * Copyright (c) 2012-2024 by the developers. See the LICENSE file for details.
  *
  * If nothing else is specified, function return zero to indicate success
  * and a negative value to indicate an error.
@@ -52,13 +52,13 @@
 #define MAIN_ERR_PREFIX  "DATA: "
 
 /*! \brief Permissions for database content files */
-#define DB_PERM  (posix_mode_t) (POSIX_S_IRUSR | POSIX_S_IWUSR)
+#define DB_PERM  (api_posix_mode_t) (API_POSIX_S_IRUSR | API_POSIX_S_IWUSR)
 
 
 /* ========================================================================== */
 /* Variables */
 
-static posix_pthread_mutex_t  db_mutex = POSIX_PTHREAD_MUTEX_INITIALIZER;
+static api_posix_pthread_mutex_t db_mutex = API_POSIX_PTHREAD_MUTEX_INITIALIZER;
 static int  db_mutex_state = 0;
 static const char*  db_path = NULL;
 static size_t  db_path_len = 0;
@@ -75,7 +75,7 @@ static size_t  db_path_len = 0;
  * operation.
  */
 
-static int  db_mutex_lock()
+static int  db_mutex_lock(void)
 {
    int  res = -1;
    int  rv;
@@ -83,14 +83,15 @@ static int  db_mutex_lock()
 
    if(!db_mutex_state)
    {
-      rv = posix_pthread_setcancelstate(POSIX_PTHREAD_CANCEL_DISABLE, &cs);
+      rv = api_posix_pthread_setcancelstate(API_POSIX_PTHREAD_CANCEL_DISABLE,
+                                            &cs);
       if(rv)  { PRINT_ERROR("Setting thread cancelability state failed"); }
       else
       {
-         rv = posix_pthread_mutex_lock(&db_mutex);
+         rv = api_posix_pthread_mutex_lock(&db_mutex);
          if(rv)  { PRINT_ERROR("Locking mutex failed"); }
          else  { db_mutex_state = 1;  res = 0; }
-         rv = posix_pthread_setcancelstate(cs, &cs);
+         rv = api_posix_pthread_setcancelstate(cs, &cs);
          if(rv)
          {
             PRINT_ERROR("Restoring thread cancelability state failed");
@@ -113,7 +114,7 @@ static int  db_mutex_lock()
  * operation.
  */
 
-static int  db_mutex_unlock()
+static int  db_mutex_unlock(void)
 {
    int  res = -1;
    int  rv;
@@ -121,14 +122,15 @@ static int  db_mutex_unlock()
 
    if(db_mutex_state)
    {
-      rv = posix_pthread_setcancelstate(POSIX_PTHREAD_CANCEL_DISABLE, &cs);
+      rv = api_posix_pthread_setcancelstate(API_POSIX_PTHREAD_CANCEL_DISABLE,
+                                            &cs);
       if(rv)  { PRINT_ERROR("Setting thread cancelability state failed"); }
       else
       {
-         rv = posix_pthread_mutex_unlock(&db_mutex);
+         rv = api_posix_pthread_mutex_unlock(&db_mutex);
          if(rv)  { PRINT_ERROR("Unlocking mutex failed"); }
          else  { db_mutex_state = 0;  res = 0; }
-         rv = posix_pthread_setcancelstate(cs, &cs);
+         rv = api_posix_pthread_setcancelstate(cs, &cs);
          if(rv)
          {
             PRINT_ERROR("Restoring thread cancelability state failed");
@@ -147,9 +149,12 @@ static int  db_mutex_unlock()
  * - Always 0 so that the sort order will be undefined.
  */
 
-static int  db_compar_dummy(const struct_posix_dirent**  a,
-                            const struct_posix_dirent**  b)
+static int  db_compar_dummy(const api_posix_struct_dirent**  a,
+                            const api_posix_struct_dirent**  b)
 {
+   (void) a;
+   (void) b;
+
    return(0);
 }
 
@@ -167,8 +172,8 @@ static int  db_compar_dummy(const struct_posix_dirent**  a,
  * - -1 if b is greater
  */
 
-static int  db_compar_num(const struct_posix_dirent**  a,
-                          const struct_posix_dirent**  b)
+static int  db_compar_num(const api_posix_struct_dirent**  a,
+                          const api_posix_struct_dirent**  b)
 {
    int  res = 0;
    const char*  name_a = (*a)->d_name;
@@ -226,7 +231,7 @@ static int  db_get_path(const char**  dbpath)
       if(0 == rv)
       {
          /* Create database directory if it doesn't exist */
-         res = fu_create_path(*dbpath, (posix_mode_t) POSIX_S_IRWXU);
+         res = fu_create_path(*dbpath, (api_posix_mode_t) API_POSIX_S_IRWXU);
       }
    }
 
@@ -234,7 +239,7 @@ static int  db_get_path(const char**  dbpath)
    if(res)
    {
       PRINT_ERROR("Cannot create database directory");
-      posix_free((void*) *dbpath);
+      api_posix_free((void*) *dbpath);
       *dbpath = NULL;
    }
 
@@ -273,7 +278,7 @@ static int  db_exit_unlocked(void)
 {
    if(NULL != db_path)
    {
-      posix_free((void*) db_path);
+      api_posix_free((void*) db_path);
       db_path = NULL;
       db_path_len = 0;
    }
@@ -377,7 +382,7 @@ int  db_update_groups(size_t  groupcount, const char**  grouplist)
    int  res = -1;
    int  rv;
    int  num;
-   struct_posix_dirent**  content;
+   api_posix_struct_dirent**  content;
    const char*  entry;
    size_t  i;
    size_t  ii;
@@ -391,7 +396,7 @@ int  db_update_groups(size_t  groupcount, const char**  grouplist)
       else
       {
          /* Get groups currently present in database */
-         num = posix_scandir(db_path, &content, NULL, db_compar_dummy);
+         num = api_posix_scandir(db_path, &content, NULL, db_compar_dummy);
          if(0 <= num)
          {
             for(i = 0; i < (size_t) num; ++i)
@@ -413,8 +418,9 @@ int  db_update_groups(size_t  groupcount, const char**  grouplist)
                if(!found)
                {
                   /* Remove group from database */
-                  path = (char*) posix_malloc(strlen(db_path) + strlen(entry)
-                                              + (size_t) 1);
+                  path = (char*) api_posix_malloc(strlen(db_path)
+                                                  + strlen(entry)
+                                                  + (size_t) 1);
                   if(NULL == path)
                   {
                      PRINT_ERROR("Cannot allocate memory for path");
@@ -425,14 +431,14 @@ int  db_update_groups(size_t  groupcount, const char**  grouplist)
                      strcpy(path, db_path);
                      strcat(path, entry);
                      res = fu_delete_tree(path);
-                     posix_free((void*) path);
+                     api_posix_free((void*) path);
                      if(res)  { break; }
                   }
                }
             }
             /* Free memory allocated by scandir() */
-            while(num--)  { posix_free((void*) content[num]); }
-            posix_free((void*) content);
+            while(num--)  { api_posix_free((void*) content[num]); }
+            api_posix_free((void*) content);
          }
       }
       db_mutex_unlock();
@@ -489,10 +495,10 @@ int  db_add(const char*  group, core_anum_t  anum,
       if(!rv)
       {
          /* The additional bytes are for '/' and the terminating NUL */
-         tmppathname = (char*) posix_malloc(db_path_len + strlen(group)
-                                            + tmpfile_len + (size_t) 2);
-         pathname = (char*) posix_malloc(db_path_len + strlen(group)
-                                         + file_len + (size_t) 2);
+         tmppathname = (char*) api_posix_malloc(db_path_len + strlen(group)
+                                                + tmpfile_len + (size_t) 2);
+         pathname = (char*) api_posix_malloc(db_path_len + strlen(group)
+                                             + file_len + (size_t) 2);
          if (NULL == tmppathname || NULL == pathname)
          {
             PRINT_ERROR("Cannot allocate memory for database pathname");
@@ -503,14 +509,15 @@ int  db_add(const char*  group, core_anum_t  anum,
             strcpy(tmppathname, db_path);
             strcat(tmppathname, group);
             strcat(tmppathname, "/");
-            rv = posix_mkdir(tmppathname, (posix_mode_t) POSIX_S_IRWXU);
-            if (!rv || (-1 == rv && POSIX_EEXIST == posix_errno))
+            rv = api_posix_mkdir(tmppathname,
+                                 (api_posix_mode_t) API_POSIX_S_IRWXU);
+            if (!rv || (-1 == rv && API_POSIX_EEXIST == api_posix_errno))
             {
                strcat(tmppathname, tmpfile);
                /* Open and lock temporary file */
                rv = fu_open_file(tmppathname, &fd,
-                                 POSIX_O_WRONLY | POSIX_O_CREAT | POSIX_O_TRUNC,
-                                 DB_PERM);
+                                 API_POSIX_O_WRONLY | API_POSIX_O_CREAT
+                                 | API_POSIX_O_TRUNC, DB_PERM);
                if(!rv)
                {
                   rv = fu_lock_file(fd);
@@ -528,7 +535,7 @@ int  db_add(const char*  group, core_anum_t  anum,
                            strcat(pathname, group);
                            strcat(pathname, "/");
                            strcat(pathname, file);
-                           rv = posix_rename(tmppathname, pathname);
+                           rv = api_posix_rename(tmppathname, pathname);
                         }
                      }
                      if(rv)
@@ -548,8 +555,8 @@ int  db_add(const char*  group, core_anum_t  anum,
             else  { PRINT_ERROR("Cannot create group directory"); }
          }
       }
-      posix_free((void*) pathname);
-      posix_free((void*) tmppathname);
+      api_posix_free((void*) pathname);
+      api_posix_free((void*) tmppathname);
       db_mutex_unlock();
    }
 
@@ -604,8 +611,8 @@ int  db_read(const char*  group, core_anum_t  anum, char**  header,
       if(!rv)
       {
          /* The additional bytes are for '/' and the terminating NUL */
-         pathname = (char*) posix_malloc(db_path_len + strlen(group)
-                                         + file_len + (size_t) 2);
+         pathname = (char*) api_posix_malloc(db_path_len + strlen(group)
+                                             + file_len + (size_t) 2);
          if (NULL == pathname)
          {
             PRINT_ERROR("Cannot allocate memory for database pathname");
@@ -616,7 +623,7 @@ int  db_read(const char*  group, core_anum_t  anum, char**  header,
             strcat(pathname, group);
             strcat(pathname, "/");
             strcat(pathname, file);
-            rv = fu_open_file(pathname, &fd, POSIX_O_RDWR, 0);
+            rv = fu_open_file(pathname, &fd, API_POSIX_O_RDWR, 0);
             if(-1 != rv)
             {
                rv = fu_lock_file(fd);
@@ -629,7 +636,7 @@ int  db_read(const char*  group, core_anum_t  anum, char**  header,
             }
          }
       }
-      posix_free((void*) pathname);
+      api_posix_free((void*) pathname);
       db_mutex_unlock();
    }
 
@@ -664,7 +671,7 @@ int  db_delete(const char*  group, core_anum_t  start, core_anum_t  end)
    char*  pathname = NULL;
    size_t  path_len;
    core_anum_t  i = start;
-   struct_posix_dirent**  content;
+   api_posix_struct_dirent**  content;
    int  num;
    const char*  entry;
    size_t  ii;
@@ -688,8 +695,8 @@ int  db_delete(const char*  group, core_anum_t  start, core_anum_t  end)
    {
       /* Calculate maximum memory requirements for pathname */
       /* The additional 2 bytes are for '/' and the terminating NUL */
-      pathname = (char*) posix_malloc(db_path_len + strlen(group)
-                                      + (size_t) 17 + (size_t) 2);
+      pathname = (char*) api_posix_malloc(db_path_len + strlen(group)
+                                          + (size_t) 17 + (size_t) 2);
       if (NULL == pathname)
       {
          PRINT_ERROR("Cannot allocate memory for database pathname");
@@ -714,7 +721,7 @@ int  db_delete(const char*  group, core_anum_t  start, core_anum_t  end)
          else
          {
             /* Determine first entry of database */
-            num = posix_scandir(pathname, &content, NULL, db_compar_num);
+            num = api_posix_scandir(pathname, &content, NULL, db_compar_num);
             if(0 <= num)
             {
                /* The entries were numerically sorted by 'scandir()' */
@@ -749,12 +756,12 @@ int  db_delete(const char*  group, core_anum_t  start, core_anum_t  end)
                   ++i;
                }
                /* Free memory allocated by scandir() */
-               while(num--)  { posix_free((void*) content[num]); }
-               posix_free((void*) content);
+               while(num--)  { api_posix_free((void*) content[num]); }
+               api_posix_free((void*) content);
             }
          }
       }
-      posix_free((void*) pathname);
+      api_posix_free((void*) pathname);
       db_mutex_unlock();
    }
 
