@@ -2,7 +2,7 @@
 /*! \file
  * \brief External program delegation functions
  *
- * Copyright (c) 2012-2022 by the developers. See the LICENSE file for details.
+ * Copyright (c) 2012-2024 by the developers. See the LICENSE file for details.
  *
  * If nothing else is specified, functions return zero to indicate success
  * and a negative value to indicate an error.
@@ -85,8 +85,8 @@ static char*  ext_check_data(const char*  s,  int  conv)
       if(NULL == strchr(s, 0x27))
       {
          /* No => Copy data unchanged */
-         res = (char*) posix_malloc(++len);  /* One additional byte for NUL */
-         if(NULL != res)  { strncpy(res, s, len); }
+         res = (char*) api_posix_malloc(++len);  /* One byte for NUL */
+         if(NULL != res)  { memcpy(res, s, len); }
       }
       else if(conv)
       {
@@ -97,7 +97,7 @@ static char*  ext_check_data(const char*  s,  int  conv)
          {
             if(0x27 == (int) s[i++])
             {
-               if(POSIX_SIZE_MAX - len < (size_t) 2)
+               if(API_POSIX_SIZE_MAX - len < (size_t) 2)
                {
                   PRINT_ERROR("Aborted before \x27size_t\x27 overflow");
                   error = 1;
@@ -107,7 +107,7 @@ static char*  ext_check_data(const char*  s,  int  conv)
          }
          if(!error)
          {
-            res = (char*) posix_malloc(++len); /* One additional byte for NUL */
+            res = (char*) api_posix_malloc(++len); /* One byte for NUL */
             if(NULL != res)
             {
                i = 0;  ri = 0;
@@ -264,7 +264,7 @@ int  ext_handler_email(const char*  recipient, const char*  subject,
    if(!error)
    {
       len = strlen(command);
-      buf = (char*) posix_malloc(++len);  /* One additional byte for NUL */
+      buf = (char*) api_posix_malloc(++len);  /* One byte for NUL */
       if(NULL == buf)  { error = 1; }
       else  { strncpy(buf, command, len); }
    }
@@ -274,14 +274,14 @@ int  ext_handler_email(const char*  recipient, const char*  subject,
    {
       len_tmp = strlen(subject);
       x = strlen(opt_subject) + (size_t) 1;  /* One additional byte for ' */
-      if(POSIX_SIZE_MAX - len_tmp < x)  { error = 1; }
+      if(API_POSIX_SIZE_MAX - len_tmp < x)  { error = 1; }
       else
       {
-         if(POSIX_SIZE_MAX - len < len_tmp + x)  { error = 1; }
+         if(API_POSIX_SIZE_MAX - len < len_tmp + x)  { error = 1; }
          else
          {
             len += len_tmp + x;
-            tmp = (char*) posix_realloc(buf, len);
+            tmp = (char*) api_posix_realloc(buf, len);
             if(NULL == tmp)  { error = 1; }
             else
             {
@@ -299,14 +299,14 @@ int  ext_handler_email(const char*  recipient, const char*  subject,
    {
       len_tmp = strlen(body);
       x = strlen(opt_body) + (size_t) 1;  /* One additional byte for ' */
-      if(POSIX_SIZE_MAX - len_tmp < x)  { error = 1; }
+      if(API_POSIX_SIZE_MAX - len_tmp < x)  { error = 1; }
       else
       {
-         if(POSIX_SIZE_MAX - len < len_tmp + x)  { error = 1; }
+         if(API_POSIX_SIZE_MAX - len < len_tmp + x)  { error = 1; }
          else
          {
             len += len_tmp + x;
-            tmp = (char*) posix_realloc(buf, len);
+            tmp = (char*) api_posix_realloc(buf, len);
             if(NULL == tmp)  { error = 1; }
             else
             {
@@ -323,15 +323,15 @@ int  ext_handler_email(const char*  recipient, const char*  subject,
    if(!error)
    {
       len_tmp = strlen(recipient);
-      if(POSIX_SIZE_MAX - len_tmp < (size_t) 3)  { error = 1; }
+      if(API_POSIX_SIZE_MAX - len_tmp < (size_t) 3)  { error = 1; }
       else
       {
-         if(POSIX_SIZE_MAX - len < len_tmp + (size_t) 3)  { error = 1; }
+         if(API_POSIX_SIZE_MAX - len < len_tmp + (size_t) 3)  { error = 1; }
          else
          {
             /* 3 additional bytes for space, leading and trailing ' */
             len += len_tmp + (size_t) 3;
-            tmp = (char*) posix_realloc(buf, len);
+            tmp = (char*) api_posix_realloc(buf, len);
             if(NULL == tmp)  { error = 1; }
             else
             {
@@ -348,15 +348,15 @@ int  ext_handler_email(const char*  recipient, const char*  subject,
    /* Spawn new process for e-mail handling */
    if(!error)
    {
-      fs = posix_popen(buf, "w");
-      if(NULL != fs)  { res = posix_pclose(fs); }
+      fs = api_posix_popen(buf, "w");
+      if(NULL != fs)  { res = api_posix_pclose(fs); }
    }
 
    /* Release memory */
-   posix_free((void*) body);
-   posix_free((void*) subject);
-   posix_free((void*) recipient);
-   posix_free((void*) buf);
+   api_posix_free((void*) body);
+   api_posix_free((void*) subject);
+   api_posix_free((void*) recipient);
+   api_posix_free((void*) buf);
 
    return(res);
 }
@@ -440,7 +440,7 @@ int  ext_handler_uri(const char*  uri, int*  invalid)
       printf("%s: %sURI delegation to %s for: %s\n",
              CFG_NAME, MAIN_ERR_PREFIX, command, uri);
       len = strlen(command);
-      buf = (char*) posix_malloc(++len);  /* One additional byte for NUL */
+      buf = (char*) api_posix_malloc(++len);  /* One byte for NUL */
       if(NULL == buf)  { error = 1; }
       else  { strncpy(buf, command, len); }
    }
@@ -449,21 +449,21 @@ int  ext_handler_uri(const char*  uri, int*  invalid)
    if(!error)
    {
       len_tmp = strlen(uri);
-      if(POSIX_SIZE_MAX - len_tmp < (size_t) 5)  { error = 1; }
+      if(API_POSIX_SIZE_MAX - len_tmp < (size_t) 5)  { error = 1; }
       else
       {
-         if(POSIX_SIZE_MAX - len < len_tmp + (size_t) 5)  { error = 1; }
+         if(API_POSIX_SIZE_MAX - len < len_tmp + (size_t) 5)  { error = 1; }
          else
          {
             /* 5 additional bytes for spaces, leading/trailing ' and & */
             len += len_tmp + (size_t) 5;
-            tmp = (char*) posix_realloc(buf, len);
+            tmp = (char*) api_posix_realloc(buf, len);
             if(NULL == tmp)  { error = 1; }
             else
             {
                buf = tmp;
                strcat(buf, " \x27");
-               strncat(buf, uri, len_tmp);
+               strcat(buf, uri);
                strcat(buf, "\x27 &");
             }
          }
@@ -473,13 +473,13 @@ int  ext_handler_uri(const char*  uri, int*  invalid)
    /* Spawn new process for URI handling */
    if(!error)
    {
-      fs = posix_popen(buf, "w");
-      if(NULL != fs)  { res = posix_pclose(fs); }
+      fs = api_posix_popen(buf, "w");
+      if(NULL != fs)  { res = api_posix_pclose(fs); }
    }
 
    /* Release memory */
-   posix_free((void*) uri);
-   posix_free((void*) buf);
+   api_posix_free((void*) uri);
+   api_posix_free((void*) buf);
 
    return(res);
 }
@@ -520,9 +520,9 @@ int  ext_editor(const char*  tfpn, int  async, ...)
    int  res = -1;
    const char*  epn = config[CONF_EDITOR].val.s;
    size_t  len = strlen(epn);
-   posix_pid_t  pid;
+   api_posix_pid_t  pid;
    int  rv;
-   posix_pid_t  rv2;
+   api_posix_pid_t  rv2;
    int  status = -1;
 
    if(len && NULL != tfpn)
@@ -530,17 +530,17 @@ int  ext_editor(const char*  tfpn, int  async, ...)
       if(main_debug)
       {
          printf("%s: %sExternal editor (path)name: \x22%s\x22\n",
-         CFG_NAME, MAIN_ERR_PREFIX, epn);
+                CFG_NAME, MAIN_ERR_PREFIX, epn);
       }
       /* Spawn child process for editor */
-      pid = posix_fork();
+      pid = api_posix_fork();
       if(!pid)
       {
          /* Executed by child process */
          rv = sighandler_exec_prepare();
-         if(!rv)  { posix_execlp(epn, epn, tfpn, (char*) NULL); }
+         if(!rv)  { api_posix_execlp(epn, epn, tfpn, (char*) NULL); }
          PRINT_ERROR("Executing external editor failed");
-         exit(POSIX_EXIT_FAILURE);
+         exit(API_POSIX_EXIT_FAILURE);
       }
       else if(-1 != pid)
       {
@@ -555,8 +555,9 @@ int  ext_editor(const char*  tfpn, int  async, ...)
          else
          {
             /* Get exit status of editor */
-            do  { rv2 = posix_waitpid(pid, &status, 0); }
-            while((posix_pid_t) -1 == rv2 && POSIX_EINTR == posix_errno);
+            do  { rv2 = api_posix_waitpid(pid, &status, 0); }
+            while((api_posix_pid_t) -1 == rv2
+                  && API_POSIX_EINTR == api_posix_errno);
             if(rv2 != pid)
             {
                PRINT_ERROR("Child process not found (bug)");
@@ -568,8 +569,11 @@ int  ext_editor(const char*  tfpn, int  async, ...)
                else
                {
                   PRINT_ERROR("External editor reported error");
-                  if(!POSIX_WIFEXITED(status))  { res = POSIX_EXIT_FAILURE; }
-                  else  { res = POSIX_WEXITSTATUS(status); }
+                  if(!API_POSIX_WIFEXITED(status))
+                  {
+                     res = API_POSIX_EXIT_FAILURE;
+                  }
+                  else  { res = API_POSIX_WEXITSTATUS(status); }
                }
             }
          }
@@ -603,13 +607,13 @@ int  ext_editor(const char*  tfpn, int  async, ...)
 int  ext_editor_status(long int  editor_pid)
 {
    int  res = -1;
-   posix_pid_t  pid = (posix_pid_t) editor_pid;
-   posix_pid_t  rv2;
+   api_posix_pid_t  pid = (api_posix_pid_t) editor_pid;
+   api_posix_pid_t  rv2;
    int  status = -1;
 
    /* Get exit status of editor */
-   do  { rv2 = posix_waitpid(pid, &status, POSIX_WNOHANG); }
-   while((posix_pid_t) -1 == rv2 && POSIX_EINTR == posix_errno);
+   do  { rv2 = api_posix_waitpid(pid, &status, API_POSIX_WNOHANG); }
+   while((api_posix_pid_t) -1 == rv2 && API_POSIX_EINTR == api_posix_errno);
    if(rv2)
    {
       if(rv2 != pid)
@@ -623,8 +627,8 @@ int  ext_editor_status(long int  editor_pid)
          else
          {
             PRINT_ERROR("External editor reported error");
-            if(!POSIX_WIFEXITED(status))  { res = POSIX_EXIT_FAILURE; }
-            else  { res = POSIX_WEXITSTATUS(status); }
+            if(!API_POSIX_WIFEXITED(status))  { res = API_POSIX_EXIT_FAILURE; }
+            else  { res = API_POSIX_WEXITSTATUS(status); }
          }
       }
    }
@@ -648,7 +652,7 @@ int  ext_editor_status(long int  editor_pid)
 
 void  ext_editor_terminate(long int  editor_pid)
 {
-   posix_kill((posix_pid_t) editor_pid, POSIX_SIGTERM);
+   api_posix_kill((api_posix_pid_t) editor_pid, API_POSIX_SIGTERM);
 }
 
 
@@ -684,16 +688,16 @@ const char*  ext_pp_filter(const char*  article)
    const char*  res = article;
    const char*  filter_pathname = config[CONF_PPROC].val.s;
    int  rv;
-   struct_posix_stat  state;
+   api_posix_struct_stat  state;
    int  fd_in[2];
    int  fd_out[2];
-   posix_pid_t  pid;
-   posix_pid_t  rv2;
+   api_posix_pid_t  pid;
+   api_posix_pid_t  rv2;
    int  error = 0;
    int  pushed = 0;
    int  finished = 0;
    size_t  len = strlen(article);
-   posix_ssize_t  rv3;
+   api_posix_ssize_t  rv3;
    size_t  i = 0;
    int  status = -1;
    char*  buf = NULL;
@@ -701,7 +705,7 @@ const char*  ext_pp_filter(const char*  article)
    size_t  bi = 0;
    char*  p;
 
-   if(POSIX_SIZE_MAX != len && strlen(filter_pathname))
+   if(API_POSIX_SIZE_MAX != len && strlen(filter_pathname))
    {
       res = NULL;
       if(main_debug)
@@ -716,53 +720,53 @@ const char*  ext_pp_filter(const char*  article)
       }
       else
       {
-         if(POSIX_S_ISDIR(state.st_mode))
+         if(API_POSIX_S_ISDIR(state.st_mode))
          {
             PRINT_ERROR("Directory specified for article postprocessor");
          }
          else
          {
-            rv = posix_pipe(fd_in);
+            rv = api_posix_pipe(fd_in);
             if(!rv)
             {
-               rv = posix_pipe(fd_out);
+               rv = api_posix_pipe(fd_out);
                if(!rv)
                {
                   /* Spawn child process for filter */
-                  pid = posix_fork();
+                  pid = api_posix_fork();
                   if(!pid)
                   {
                      /* Executed by child process */
-                     posix_close(fd_out[1]);
-                     posix_close(fd_in[0]);
-                     rv = posix_dup2(fd_out[0], POSIX_STDIN_FILENO);
+                     api_posix_close(fd_out[1]);
+                     api_posix_close(fd_in[0]);
+                     rv = api_posix_dup2(fd_out[0], API_POSIX_STDIN_FILENO);
                      if(-1 != rv)
                      {
-                        rv = posix_dup2(fd_in[1], POSIX_STDOUT_FILENO);
+                        rv = api_posix_dup2(fd_in[1], API_POSIX_STDOUT_FILENO);
                         if(-1 != rv)
                         {
                            rv = sighandler_exec_prepare();
                            if(!rv)
                            {
-                              posix_execl(filter_pathname, filter_pathname,
-                                          (char*) NULL);
+                              api_posix_execl(filter_pathname, filter_pathname,
+                                              (char*) NULL);
                            }
                         }
                      }
                      PRINT_ERROR("Executing article post processor failed");
-                     exit(POSIX_EXIT_FAILURE);
+                     exit(API_POSIX_EXIT_FAILURE);
                   }
                   else if(-1 != pid)
                   {
-                     posix_close(fd_out[0]);
-                     posix_close(fd_in[1]);
+                     api_posix_close(fd_out[0]);
+                     api_posix_close(fd_in[1]);
                      /* Set pipes to nonblocking mode */
-                     rv = posix_fcntl(fd_out[1], POSIX_F_SETFL,
-                                      POSIX_O_NONBLOCK);
+                     rv = api_posix_fcntl(fd_out[1], API_POSIX_F_SETFL,
+                                          API_POSIX_O_NONBLOCK);
                      if(-1 != rv)
                      {
-                        rv = posix_fcntl(fd_in[0], POSIX_F_SETFL,
-                                         POSIX_O_NONBLOCK);
+                        rv = api_posix_fcntl(fd_in[0], API_POSIX_F_SETFL,
+                                             API_POSIX_O_NONBLOCK);
                      }
                      if(-1 == rv)
                      {
@@ -776,12 +780,16 @@ const char*  ext_pp_filter(const char*  article)
                            /* Push article into postprocessor */
                            if(i < len)
                            {
-                              rv3 = posix_write(fd_out[1], (void*) &article[i],
-                                                len - i);
+                              rv3 = api_posix_write(fd_out[1],
+                                                    (void*) &article[i],
+                                                    len - i);
                               if(0 > rv3)
                               {
-                                 if(POSIX_EINTR == posix_errno)  { continue; }
-                                 if(POSIX_EAGAIN != posix_errno)
+                                 if(API_POSIX_EINTR == api_posix_errno)
+                                 {
+                                    continue;
+                                 }
+                                 if(API_POSIX_EAGAIN != api_posix_errno)
                                  {
                                     error = 1;
                                     break;
@@ -795,7 +803,7 @@ const char*  ext_pp_filter(const char*  article)
                               if(!pushed)
                               {
                                  pushed = 1;
-                                 posix_close(fd_out[1]);
+                                 api_posix_close(fd_out[1]);
                               }
                            }
                            /* Read result */
@@ -806,17 +814,23 @@ const char*  ext_pp_filter(const char*  article)
                                  /* Allocate more memory for result */
                                  if(!blen)  { blen = 4096; }
                                  else  { blen *= 2; }
-                                 p = (char*) posix_realloc(buf, blen);
+                                 p = (char*) api_posix_realloc(buf, blen);
                                  if(NULL == p)  { error = 1;  break; }
                                  else  { buf = p; }
                               }
                               /* Leave one byte left for NUL termination */
-                              rv3 = posix_read(fd_in[0], (void*) &buf[bi],
-                                               (size_t) 4095);
+                              rv3 = api_posix_read(fd_in[0], (void*) &buf[bi],
+                                                   (size_t) 4095);
                               if(0 > rv3)
                               {
-                                 if(POSIX_EINTR == posix_errno)  { continue; }
-                                 if(POSIX_EAGAIN != posix_errno)  { error = 1; }
+                                 if(API_POSIX_EINTR == api_posix_errno)
+                                 {
+                                    continue;
+                                 }
+                                 if(API_POSIX_EAGAIN != api_posix_errno)
+                                 {
+                                    error = 1;
+                                 }
                                  break;
                               }
                               else if(0 < rv3)  { bi += (size_t) rv3; }
@@ -841,7 +855,7 @@ const char*  ext_pp_filter(const char*  article)
                      /* Terminate postprocessor child process after error */
                      if(error)
                      {
-                        rv = posix_kill(pid, POSIX_SIGTERM);
+                        rv = api_posix_kill(pid, API_POSIX_SIGTERM);
                         if(rv)
                         {
                            PRINT_ERROR("Termination of child process "
@@ -849,9 +863,9 @@ const char*  ext_pp_filter(const char*  article)
                         }
                      }
                      /* Get exit status of filter */
-                     do  { rv2 = posix_waitpid(pid, &status, 0); }
-                     while((posix_pid_t) -1 == rv2
-                           && POSIX_EINTR == posix_errno);
+                     do  { rv2 = api_posix_waitpid(pid, &status, 0); }
+                     while((api_posix_pid_t) -1 == rv2
+                           && API_POSIX_EINTR == api_posix_errno);
                      if(rv2 != pid)
                      {
                         PRINT_ERROR("Child process not found (bug)");
@@ -868,8 +882,8 @@ const char*  ext_pp_filter(const char*  article)
                            res = buf;
                         }
                      }
-                     if(!pushed)  { posix_close(fd_out[1]); }
-                     posix_close(fd_in[0]);
+                     if(!pushed)  { api_posix_close(fd_out[1]); }
+                     api_posix_close(fd_in[0]);
                   }
                }
             }
@@ -878,7 +892,7 @@ const char*  ext_pp_filter(const char*  article)
    }
 
    /* Check for error */
-   if(NULL == res)  { posix_free((void*) buf); }
+   if(NULL == res)  { api_posix_free((void*) buf); }
 
    return(res);
 }
@@ -899,14 +913,14 @@ int  ext_inews(const char*  article)
    int  res = -1;
    const char*  inews_pathname = config[CONF_INEWS].val.s;
    size_t  len = 0;
-   struct_posix_stat  state;
+   api_posix_struct_stat  state;
    int  rv;
    int  fd_out[2];
-   posix_pid_t  pid;
-   posix_pid_t  rv2;
+   api_posix_pid_t  pid;
+   api_posix_pid_t  rv2;
    int  error = 0;
    int  pushed = 0;
-   posix_ssize_t  rv3;
+   api_posix_ssize_t  rv3;
    size_t  i = 0;
    int  status = -1;
 
@@ -927,7 +941,7 @@ int  ext_inews(const char*  article)
          }
          else
          {
-            if(POSIX_S_ISDIR(state.st_mode))
+            if(API_POSIX_S_ISDIR(state.st_mode))
             {
                PRINT_ERROR("Directory specified for external inews");
             }
@@ -943,32 +957,33 @@ int  ext_inews(const char*  article)
    if(!res)
    {
       res = -1;
-      rv = posix_pipe(fd_out);
+      rv = api_posix_pipe(fd_out);
       if(!rv)
       {
          /* Spawn child process for inews */
-         pid = posix_fork();
+         pid = api_posix_fork();
          if(!pid)
          {
             /* Executed by child process */
-            posix_close(fd_out[1]);
-            rv = posix_dup2(fd_out[0], POSIX_STDIN_FILENO);
+            api_posix_close(fd_out[1]);
+            rv = api_posix_dup2(fd_out[0], API_POSIX_STDIN_FILENO);
             if(-1 != rv)
             {
                rv = sighandler_exec_prepare();
                if(!rv)
                {
-                  posix_execl(inews_pathname, inews_pathname, (char*) NULL);
+                  api_posix_execl(inews_pathname, inews_pathname, (char*) NULL);
                }
             }
             PRINT_ERROR("Executing external inews failed");
-            exit(POSIX_EXIT_FAILURE);
+            exit(API_POSIX_EXIT_FAILURE);
          }
          else if(-1 != pid)
          {
-            posix_close(fd_out[0]);
+            api_posix_close(fd_out[0]);
             /* Set pipe to nonblocking mode */
-            rv = posix_fcntl(fd_out[1], POSIX_F_SETFL, POSIX_O_NONBLOCK);
+            rv = api_posix_fcntl(fd_out[1], API_POSIX_F_SETFL,
+                                 API_POSIX_O_NONBLOCK);
             if(-1 == rv)
             {
                PRINT_ERROR("Configuration of pipe failed");
@@ -981,11 +996,12 @@ int  ext_inews(const char*  article)
                   /* Push article into inews */
                   if(i < len)
                   {
-                     rv3 = posix_write(fd_out[1], (void*) &article[i], len - i);
+                     rv3 = api_posix_write(fd_out[1], (void*) &article[i],
+                                           len - i);
                      if(0 > rv3)
                      {
-                        if(POSIX_EINTR == posix_errno)  { continue; }
-                        if(POSIX_EAGAIN != posix_errno)
+                        if(API_POSIX_EINTR == api_posix_errno)  { continue; }
+                        if(API_POSIX_EAGAIN != api_posix_errno)
                         {
                            error = 1;
                            break;
@@ -998,7 +1014,7 @@ int  ext_inews(const char*  article)
                      /* Transfer to stdin of inews complete */
                      if(!pushed)
                      {
-                        posix_close(fd_out[1]);
+                        api_posix_close(fd_out[1]);
                         pushed = 1;
                      }
                   }
@@ -1007,15 +1023,16 @@ int  ext_inews(const char*  article)
             /* Terminate inews child process after error */
             if(error)
             {
-               rv = posix_kill(pid, POSIX_SIGTERM);
+               rv = api_posix_kill(pid, API_POSIX_SIGTERM);
                if(rv)
                {
                   PRINT_ERROR("Termination of child process failed (bug)");
                }
             }
             /* Get exit status of filter */
-            do  { rv2 = posix_waitpid(pid, &status, 0); }
-            while((posix_pid_t) -1 == rv2 && POSIX_EINTR == posix_errno);
+            do  { rv2 = api_posix_waitpid(pid, &status, 0); }
+            while((api_posix_pid_t) -1 == rv2
+                   && API_POSIX_EINTR == api_posix_errno);
             if(rv2 != pid)
             {
                PRINT_ERROR("Child process not found (bug)");
@@ -1034,8 +1051,8 @@ int  ext_inews(const char*  article)
                   res = 0;
                }
             }
-            if(!pushed)  { posix_close(fd_out[1]); }
-            posix_close(fd_out[0]);
+            if(!pushed)  { api_posix_close(fd_out[1]); }
+            api_posix_close(fd_out[0]);
          }
       }
    }
@@ -1142,7 +1159,7 @@ int  ext_download_file(const char*  lpn, const char*  uri)
 
 void  ext_free(void*  p)
 {
-   posix_free(p);
+   api_posix_free(p);
 }
 
 
