@@ -2,7 +2,7 @@
 /*! \file
  * \brief Generic file handling and path checking functions
  *
- * Copyright (c) 2012-2021 by the developers. See the LICENSE file for details.
+ * Copyright (c) 2012-2024 by the developers. See the LICENSE file for details.
  *
  * If nothing else is specified, functions return zero to indicate success
  * and a negative value to indicate an error.
@@ -50,9 +50,12 @@
  * - Always 0 so that the sort order will be undefined.
  */
 
-static int  fu_compar(const struct_posix_dirent**  a,
-                      const struct_posix_dirent**  b)
+static int  fu_compar(const api_posix_struct_dirent**  a,
+                      const api_posix_struct_dirent**  b)
 {
+   (void) a;
+   (void) b;
+
    return(0);
 }
 
@@ -116,7 +119,7 @@ int  fu_check_path(const char*  path)
  * - Negative value on error
  */
 
-int  fu_create_path(const char*  path, posix_mode_t  perm)
+int  fu_create_path(const char*  path, api_posix_mode_t  perm)
 {
    int  res = 0;
    size_t  pos = 1;
@@ -153,7 +156,7 @@ int  fu_create_path(const char*  path, posix_mode_t  perm)
          }
       }
 
-      pcomp = (char*) posix_malloc(pos + (size_t) 1);
+      pcomp = (char*) api_posix_malloc(pos + (size_t) 1);
       if(NULL == pcomp)
       {
          PRINT_ERROR("Can't allocate memory for path component");
@@ -171,13 +174,13 @@ int  fu_create_path(const char*  path, posix_mode_t  perm)
       /* printf("Directory to create: %s\n", pcomp); */
 
       /* Create configuration directory, if it doesn't exist */
-      rv = posix_mkdir(pcomp, perm);
-      if(!(0 == rv || (-1 == rv && POSIX_EEXIST == posix_errno)))
+      rv = api_posix_mkdir(pcomp, perm);
+      if(!(0 == rv || (-1 == rv && API_POSIX_EEXIST == api_posix_errno)))
       {
          goto error;
       }
 
-      posix_free((void*) pcomp);
+      api_posix_free((void*) pcomp);
    }
 
 exit:
@@ -208,13 +211,13 @@ error:
  * - Negative value on error
  */
 
-int  fu_check_file(const char*  pathname, struct_posix_stat*  state)
+int  fu_check_file(const char*  pathname, api_posix_struct_stat*  state)
 {
    int  res = -1;
-   struct_posix_stat  stat_dummy;
+   api_posix_struct_stat  stat_dummy;
 
-   if(NULL == state)  { res = posix_stat(pathname, &stat_dummy); }
-   else  { res = posix_stat(pathname, state); }
+   if(NULL == state)  { res = api_posix_stat(pathname, &stat_dummy); }
+   else  { res = api_posix_stat(pathname, state); }
 
    return(res);
 }
@@ -241,14 +244,14 @@ int  fu_check_file(const char*  pathname, struct_posix_stat*  state)
  */
 
 int  fu_open_file(const char*  pathname, int*  filedesc, int  mode,
-                  posix_mode_t  perm)
+                  api_posix_mode_t  perm)
 {
    int  res = 0;
    int  rv;
 
    /* Open file */
-   do  { *filedesc = posix_open(pathname, mode, perm); }
-   while(-1 == *filedesc && POSIX_EINTR == posix_errno);
+   do  { *filedesc = api_posix_open(pathname, mode, perm); }
+   while(-1 == *filedesc && API_POSIX_EINTR == api_posix_errno);
    if (-1 == *filedesc)
    {
       /* PRINT_ERROR("Cannot open file"); */
@@ -257,12 +260,16 @@ int  fu_open_file(const char*  pathname, int*  filedesc, int  mode,
    else
    {
       /* Set 'FD_CLOEXEC' flag */
-      do  { rv = posix_fcntl(*filedesc, POSIX_F_SETFD, POSIX_FD_CLOEXEC); }
-      while(-1 == rv && POSIX_EINTR == posix_errno);
+      do
+      {
+         rv = api_posix_fcntl(*filedesc, API_POSIX_F_SETFD,
+                              API_POSIX_FD_CLOEXEC);
+      }
+      while(-1 == rv && API_POSIX_EINTR == api_posix_errno);
       if(-1 == rv)
       {
          PRINT_ERROR("fcntl() failed");
-         posix_close(*filedesc);
+         api_posix_close(*filedesc);
          res = -1;
       }
    }
@@ -299,7 +306,7 @@ void  fu_close_file(int*  filedesc, FILE**  stream)
    /* Touch filedescriptor only if there was no stream */
    if (NULL == stream && NULL != filedesc)
    {
-      if (-1 != *filedesc)  { posix_close(*filedesc); }
+      if (-1 != *filedesc)  { api_posix_close(*filedesc); }
    }
    if (NULL != filedesc)  { *filedesc = -1; }
 
@@ -328,13 +335,13 @@ void  fu_close_file(int*  filedesc, FILE**  stream)
 int  fu_lock_file(int  filedesc)
 {
    int  res = -1;
-   struct_posix_flock  fl;
+   api_posix_struct_flock  fl;
 
-   fl.l_type = POSIX_F_WRLCK;
-   fl.l_whence = POSIX_SEEK_SET;
+   fl.l_type = API_POSIX_F_WRLCK;
+   fl.l_whence = API_POSIX_SEEK_SET;
    fl.l_start = 0;
    fl.l_len = 0;
-   res = posix_fcntl(filedesc, POSIX_F_SETLK, &fl);
+   res = api_posix_fcntl(filedesc, API_POSIX_F_SETLK, &fl);
    if(-1 == res)  { PRINT_ERROR("Cannot lock file"); }
    else  res = 0;
 
@@ -354,7 +361,7 @@ int  fu_lock_file(int  filedesc)
 
 int  fu_unlink_file(const char*  pathname)
 {
-   return(posix_unlink(pathname));
+   return(api_posix_unlink(pathname));
 }
 
 
@@ -374,7 +381,7 @@ int  fu_assign_stream(int  filedesc, FILE**  stream, const char*  mode)
 {
    int  res = 0;
 
-   *stream = posix_fdopen(filedesc, mode);
+   *stream = api_posix_fdopen(filedesc, mode);
    if(NULL == *stream)
    {
       PRINT_ERROR("Cannot assign I/O stream to file");
@@ -407,14 +414,14 @@ int  fu_sync(int  filedesc, FILE*  stream)
    {
       /* Flush user space buffers */
       do  { res = fflush(stream); }
-      while(EOF == res && POSIX_EINTR == posix_errno);
+      while(EOF == res && API_POSIX_EINTR == api_posix_errno);
    }
 
    if(!res)
    {
       /* Flush kernel buffers */
-      do  { res = posix_fsync(filedesc); }
-      while(-1 == res && POSIX_EINTR == posix_errno);
+      do  { res = api_posix_fsync(filedesc); }
+      while(-1 == res && API_POSIX_EINTR == api_posix_errno);
    }
 
    return(res);
@@ -447,7 +454,7 @@ int  fu_read_whole_file(int  filedesc, char**  buffer, size_t*  len)
    int  res = -1;
    size_t  i = 0;
    char*  p;
-   posix_ssize_t  rv;
+   api_posix_ssize_t  rv;
 
    *buffer = NULL;
    *len = 0;
@@ -457,13 +464,13 @@ int  fu_read_whole_file(int  filedesc, char**  buffer, size_t*  len)
       {
          /* Allocate more memory in exponentially increasing chunks */
          if(!*len)  { *len = 256; }
-         p = posix_realloc((void*) *buffer, *len *= (size_t) 2);
+         p = api_posix_realloc((void*) *buffer, *len *= (size_t) 2);
          if(NULL == p)  { break; }
          else  { *buffer = p; }
       }
       /* Read data from file */
-      rv = posix_read(filedesc, &(*buffer)[i], *len - i - (size_t) 1);
-      if(-1 == rv && POSIX_EINTR == posix_errno)  { continue; }
+      rv = api_posix_read(filedesc, &(*buffer)[i], *len - i - (size_t) 1);
+      if(-1 == rv && API_POSIX_EINTR == api_posix_errno)  { continue; }
       if(-1 == rv)  { break; }
       else  { i += (size_t)  rv; }
       /* Check for EOF */
@@ -473,7 +480,7 @@ int  fu_read_whole_file(int  filedesc, char**  buffer, size_t*  len)
    /* Check for error */
    if(res)
    {
-      posix_free((void*) *buffer);
+      api_posix_free((void*) *buffer);
       *buffer = NULL;
       *len = 0;
    }
@@ -504,15 +511,18 @@ int  fu_read_whole_file(int  filedesc, char**  buffer, size_t*  len)
 int  fu_read_from_filedesc(int  filedesc, char*  buffer, size_t*  len)
 {
    int  res = -1;
-   posix_ssize_t  rv = -1;
+   api_posix_ssize_t  rv = -1;
    size_t  i = 0;
 
    while(i < *len)
    {
-      rv = posix_read(filedesc, (void*) &buffer[i], *len - i);
-      if((posix_ssize_t) -1 == rv && POSIX_EINTR == posix_errno)  { continue; }
+      rv = api_posix_read(filedesc, (void*) &buffer[i], *len - i);
+      if((api_posix_ssize_t) -1 == rv && API_POSIX_EINTR == api_posix_errno)
+      {
+         continue;
+      }
       if(!rv)  { break; }  /* EOF */
-      if((posix_ssize_t) -1 != rv)  { i += (size_t)  rv; }  else  { break; }
+      if((api_posix_ssize_t) -1 != rv)  { i += (size_t)  rv; }  else  { break; }
    }
    if(-1 == rv)  { PRINT_ERROR("Error while reading from FD"); }
    if(i)
@@ -542,14 +552,17 @@ int  fu_read_from_filedesc(int  filedesc, char*  buffer, size_t*  len)
 int  fu_write_to_filedesc(int  filedesc, const char*  buffer, size_t  len)
 {
    int  res = -1;
-   posix_ssize_t  rv;
+   api_posix_ssize_t  rv;
    size_t  i = 0;
 
    while(i < len)
    {
-      rv = posix_write(filedesc, (void*) &buffer[i], len - i);
-      if((posix_ssize_t) -1 == rv && POSIX_EINTR == posix_errno)  { continue; }
-      if((posix_ssize_t) -1 != rv)  { i += (size_t)  rv; }  else  { break; }
+      rv = api_posix_write(filedesc, (void*) &buffer[i], len - i);
+      if((api_posix_ssize_t) -1 == rv && API_POSIX_EINTR == api_posix_errno)
+      {
+         continue;
+      }
+      if((api_posix_ssize_t) -1 != rv)  { i += (size_t)  rv; }  else  { break; }
    }
    if(len == i)  { res = 0; }
    if(res)  { PRINT_ERROR("Writing data block to FD failed"); }
@@ -582,8 +595,8 @@ int  fu_delete_tree(const char*  dir)
    int  num;
    size_t  len;
    char*  path;
-   struct_posix_dirent**  content;
-   struct_posix_stat  state;
+   api_posix_struct_dirent**  content;
+   api_posix_struct_stat  state;
    const char*  entry;
    char*  pathname;
    size_t  i;
@@ -595,7 +608,7 @@ int  fu_delete_tree(const char*  dir)
       if(len && '/' == dir[0])
       {
          /* Strip potential trailing slash of path */
-         path = (char*) posix_malloc(len + (size_t) 1);
+         path = (char*) api_posix_malloc(len + (size_t) 1);
          if(NULL == path)
          {
             PRINT_ERROR("Can't allocate memory for path");
@@ -605,7 +618,7 @@ int  fu_delete_tree(const char*  dir)
             strcpy(path, dir);
             if('/' == path[len - (size_t) 1])  { path[len - (size_t) 1] = 0; }
             /* Delete directory */
-            num = posix_scandir(path, &content, NULL, fu_compar);
+            num = api_posix_scandir(path, &content, NULL, fu_compar);
             if(0 > num)  { PRINT_ERROR("Cannot scan directory"); }
             else
             {
@@ -620,8 +633,9 @@ int  fu_delete_tree(const char*  dir)
                    */
                   if(!strcmp(".", entry))  { continue; }
                   if(!strcmp("..", entry))  { continue; }
-                  pathname = (char*) posix_malloc(strlen(path) + strlen(entry)
-                                                  + (size_t) 2);
+                  pathname = (char*) api_posix_malloc(strlen(path)
+                                                      + strlen(entry)
+                                                      + (size_t) 2);
                   if(NULL == pathname)
                   {
                      PRINT_ERROR("Cannot allocate memory for path");
@@ -634,10 +648,10 @@ int  fu_delete_tree(const char*  dir)
                   /* printf("Pathname: %s\n", pathname); */
 #if CFG_USE_POSIX_API >= 200112 || CFG_USE_XSI
                   /* This is the desired operation (not follow symlinks) */
-                  rv = posix_lstat(pathname, &state);
+                  rv = api_posix_lstat(pathname, &state);
 #else  /* CFG_USE_POSIX_API >= 200112 || CFG_USE_XSI */
                   /* Fallback that only works if there are no symlinks */
-                  rv = posix_stat(pathname, &state);
+                  rv = api_posix_stat(pathname, &state);
 #endif  /* CFG_USE_POSIX_API >= 200112 || CFG_USE_XSI */
                   if(rv)
                   {
@@ -647,7 +661,7 @@ int  fu_delete_tree(const char*  dir)
                   else
                   {
                      /* Check whether entry is a directory */
-                     if(POSIX_S_ISDIR(state.st_mode))
+                     if(API_POSIX_S_ISDIR(state.st_mode))
                      {
                         /* Yes => Recursively delete it */
                         rv = fu_delete_tree(pathname);
@@ -661,16 +675,16 @@ int  fu_delete_tree(const char*  dir)
                         if(rv)  { res = -1; }
                      }
                   }
-                  posix_free((void*) pathname);
+                  api_posix_free((void*) pathname);
                }
                /* printf("Delete dir : %s\n", path); */
-               rv = posix_rmdir(path);
+               rv = api_posix_rmdir(path);
                if(rv)  { res = -1; }
                /* Free memory allocated by scandir() */
-               while(num--)  { posix_free((void*) content[num]); }
-               posix_free((void*) content);
+               while(num--)  { api_posix_free((void*) content[num]); }
+               api_posix_free((void*) content);
             }
-            posix_free((void*) path);
+            api_posix_free((void*) path);
          }
       }
    }
