@@ -2,7 +2,7 @@
 /*! \file
  * \brief Article filtering
  *
- * Copyright (c) 2012-2020 by the developers. See the LICENSE file for details.
+ * Copyright (c) 2012-2024 by the developers. See the LICENSE file for details.
  *
  * If nothing else is specified, function return zero to indicate success
  * and a negative value to indicate an error.
@@ -58,7 +58,7 @@
 #define MAIN_ERR_PREFIX  "FILTER: "
 
 /*! \brief Permissions for score file */
-#define FILTER_PERM  (posix_mode_t) (POSIX_S_IRUSR | POSIX_S_IWUSR)
+#define FILTER_PERM  (api_posix_mode_t) (API_POSIX_S_IRUSR | API_POSIX_S_IWUSR)
 
 /*! \name Score limits
  *
@@ -99,7 +99,7 @@ struct filter_wm
 {
    int  negate;
    enum filter_cs  cs;
-   posix_regex_t*  ere;
+   api_posix_regex_t*  ere;
    struct filter_wm*  next;
 };
 #endif  /* CFG_USE_POSIX_API >= 200112 || CFG_USE_XSI || CFG_USE_CLB */
@@ -116,7 +116,7 @@ struct filter
    enum filter_cs  cs;
 #if CFG_USE_POSIX_API >= 200112 || CFG_USE_XSI || CFG_USE_CLB
    struct filter_wm*  wm;  /* Object for 'group_wildmat' */
-   posix_regex_t*  ere;  /* Extended regular expression for 'string' */
+   api_posix_regex_t*  ere;  /* Extended regular expression for 'string' */
 #endif  /* CFG_USE_POSIX_API >= 200112 || CFG_USE_XSI || CFG_USE_CLB */
 };
 
@@ -146,7 +146,7 @@ static const char*  filter_type_name[] =
 static enum filter_cs  filter_locale = FILTER_CS_ASCII;
 #if CFG_USE_POSIX_API >= 200112 || CFG_USE_XSI || CFG_USE_CLB
 static enum filter_cs  testgroup_cs;
-static posix_regex_t*  testgroup_ere = NULL;
+static api_posix_regex_t*  testgroup_ere = NULL;
 #endif  /* CFG_USE_POSIX_API >= 200112 || CFG_USE_XSI || CFG_USE_CLB */
 static size_t  score_len_max = 1000;
 static struct filter*  scores = NULL;
@@ -176,7 +176,7 @@ static const char  scorefile_name[] = "scorefile";
  * The error message is always formatted using the POSIX locale.
  */
 
-static void  filter_print_ere_error(int  code, posix_regex_t*  ere)
+static void  filter_print_ere_error(int  code, api_posix_regex_t*  ere)
 {
    const char*  mod_name = MAIN_ERR_PREFIX;
    size_t  mod_len = strlen(mod_name);
@@ -191,16 +191,16 @@ static void  filter_print_ere_error(int  code, posix_regex_t*  ere)
    {
 #  if CFG_USE_POSIX_API >= 200112 || CFG_USE_XSI
       /* Don't use NLS for error messages on stderr */
-      posix_setlocale(POSIX_LC_MESSAGES, "POSIX");
+      api_posix_setlocale(API_POSIX_LC_MESSAGES, "POSIX");
 #  endif  /* CFG_USE_POSIX_API >= 200112 || CFG_USE_XSI */
-      len = posix_regerror(code, ere, buf, 0);
-      if(!len || POSIX_SIZE_MAX - mod_len < len)
+      len = api_posix_regerror(code, ere, buf, 0);
+      if(!len || API_POSIX_SIZE_MAX - mod_len < len)
       {
          PRINT_ERROR("Error message has invalid size");
       }
       else
       {
-         buf = (char*) posix_malloc(mod_len + len);
+         buf = (char*) api_posix_malloc(mod_len + len);
          if(NULL == buf)
          {
             PRINT_ERROR("Cannot allocate memory for error message");
@@ -208,13 +208,13 @@ static void  filter_print_ere_error(int  code, posix_regex_t*  ere)
          else
          {
             memcpy(buf, mod_name, mod_len);
-            posix_regerror(code, ere, &buf[mod_len], len);
+            api_posix_regerror(code, ere, &buf[mod_len], len);
             print_error(buf);
-            posix_free((void*) buf);
+            api_posix_free((void*) buf);
          }
       }
 #  if CFG_USE_POSIX_API >= 200112 || CFG_USE_XSI
-      posix_setlocale(POSIX_LC_MESSAGES, "");
+      api_posix_setlocale(API_POSIX_LC_MESSAGES, "");
 #  endif  /* CFG_USE_POSIX_API >= 200112 || CFG_USE_XSI */
    }
 }
@@ -232,7 +232,7 @@ static void  filter_print_ere_error(int  code, posix_regex_t*  ere)
  * for the object pointed to by \e ere .
  */
 
-static int  filter_compile_ere(enum filter_cs*  cs, posix_regex_t**  ere,
+static int  filter_compile_ere(enum filter_cs*  cs, api_posix_regex_t**  ere,
                                const char*  string)
 {
    int  res = 0;
@@ -263,7 +263,7 @@ static int  filter_compile_ere(enum filter_cs*  cs, posix_regex_t**  ere,
    else
    {
       /* Allocate memory */
-      *ere = (posix_regex_t*)  posix_malloc(sizeof(posix_regex_t));
+      *ere = (api_posix_regex_t*)  api_posix_malloc(sizeof(api_posix_regex_t));
       if(NULL == *ere)
       {
          PRINT_ERROR("Cannot allocate memory for regular expression");
@@ -274,12 +274,13 @@ static int  filter_compile_ere(enum filter_cs*  cs, posix_regex_t**  ere,
          /* Compile regular expression if required */
          pat = string;
          if(FILTER_CS_ISO8859_1 == filter_locale)  { pat = p; }
-         rv = posix_regcomp(*ere, pat, POSIX_REG_EXTENDED | POSIX_REG_NOSUB);
+         rv = api_posix_regcomp(*ere, pat,
+                                API_POSIX_REG_EXTENDED | API_POSIX_REG_NOSUB);
          if(rv)
          {
             PRINT_ERROR("Compiling regular expression failed");
             filter_print_ere_error(rv, *ere);
-            posix_free((void*) *ere);
+            api_posix_free((void*) *ere);
             res = -1;
          }
          else if(main_debug)
@@ -314,27 +315,27 @@ static void  filter_score_rule_destructor(struct filter**  rule)
 
    if(NULL != rule && NULL != *rule)
    {
-      posix_free((void*) (*rule)->group_wildmat);
-      posix_free((void*) (*rule)->string);
+      api_posix_free((void*) (*rule)->group_wildmat);
+      api_posix_free((void*) (*rule)->string);
 #if CFG_USE_POSIX_API >= 200112 || CFG_USE_XSI || CFG_USE_CLB
       /* Destroy wildmat linked pattern list */
       p = (*rule)->wm;
       while(NULL != p)
       {
          q = p->next;
-         posix_regfree(p->ere);
-         posix_free((void*) p->ere);
-         posix_free((void*) p);
+         api_posix_regfree(p->ere);
+         api_posix_free((void*) p->ere);
+         api_posix_free((void*) p);
          p = q;
       }
       /* Destroy regular expression object for string ERE */
       if(NULL != (*rule)->ere)
       {
-         posix_regfree((*rule)->ere);
-         posix_free((void*) (*rule)->ere);
+         api_posix_regfree((*rule)->ere);
+         api_posix_free((void*) (*rule)->ere);
       }
 #endif  /* CFG_USE_POSIX_API >= 200112 || CFG_USE_XSI || CFG_USE_CLB */
-      posix_free((void*) *rule);
+      api_posix_free((void*) *rule);
       *rule = NULL;
    }
 }
@@ -355,8 +356,8 @@ static void  filter_score_rule_destructor(struct filter**  rule)
  *
  * \attention
  * The parameters \e group_wildmat and \e string must point to a memory block
- * allocated with the function \ref posix_malloc() and will become part of the
- * created object.
+ * allocated with the function \ref api_posix_malloc() and will become part of
+ * the created object.
  * On error the caller stay responsible to free the memory for \e wildmat and
  * \e string .
  *
@@ -383,7 +384,7 @@ static int  filter_score_rule_constructor(struct filter**  new_rule,
 #endif  /* CFG_USE_POSIX_API >= 200112 || CFG_USE_XSI || CFG_USE_CLB */
 
    /* Create new rule */
-   *new_rule = (struct filter*) posix_malloc(sizeof(struct filter));
+   *new_rule = (struct filter*) api_posix_malloc(sizeof(struct filter));
    if(NULL == *new_rule)  { res = -1; }
    else
    {
@@ -413,7 +414,7 @@ static int  filter_score_rule_constructor(struct filter**  new_rule,
                for(i = rv; i; --i)
                {
                   pat = (struct filter_wm*)
-                        posix_malloc(sizeof(struct filter_wm));
+                        api_posix_malloc(sizeof(struct filter_wm));
                   if(NULL == pat)  { res = -1;  break; }
                   else
                   {
@@ -592,7 +593,7 @@ static int  filter_decode_rule(struct filter**  rule,
    {
       error = 1;
       wm_len = (size_t) (p - line);
-      q = (char*) posix_realloc((void*) group_wildmat, wm_len + (size_t) 1);
+      q = (char*) api_posix_realloc((void*) group_wildmat, wm_len + (size_t) 1);
       if(NULL == q)
       {
          PRINT_ERROR("Cannot allocate memory for wildmat");
@@ -631,7 +632,7 @@ static int  filter_decode_rule(struct filter**  rule,
    /* Extract string from data field */
    if(!error)
    {
-      string = (char*) posix_malloc((size_t) len);
+      string = (char*) api_posix_malloc((size_t) len);
       if(NULL == string)
       {
          PRINT_ERROR("Cannot allocate memory for score rule parser");
@@ -687,8 +688,8 @@ static int  filter_decode_rule(struct filter**  rule,
    /* Release memory on error */
    if(res)
    {
-      posix_free((void*) group_wildmat);
-      posix_free((void*) string);
+      api_posix_free((void*) group_wildmat);
+      api_posix_free((void*) string);
    }
 
    /*
@@ -740,7 +741,7 @@ static int  filter_encode_rule(char**  line, size_t*  len, struct filter*  rule)
          l += strlen(rule->string);
          l += (size_t) 1;     /* LF line termination */
          l += (size_t) 1;     /* NUL termination */
-         p = (char*) posix_malloc(l);
+         p = (char*) api_posix_malloc(l);
          if(NULL == p)
          {
             PRINT_ERROR("Cannot allocate memory for score rule");
@@ -748,17 +749,17 @@ static int  filter_encode_rule(char**  line, size_t*  len, struct filter*  rule)
          else
          {
             /* Since version 1.0 all rules use a wildmat */
-            rv = posix_snprintf(p, l, "%s:%s:%d:%s\n", rule->group_wildmat,
-                                frt, rule->value, rule->string);
+            rv = api_posix_snprintf(p, l, "%s:%s:%d:%s\n", rule->group_wildmat,
+                                    frt, rule->value, rule->string);
             if(0 > rv || (size_t) rv >= l)
             {
                PRINT_ERROR("Encoding score rule failed");
-               posix_free((void*) p);
+               api_posix_free((void*) p);
             }
             else
             {
                /* Success => Replace line buffer */
-               posix_free((void*) *line);
+               api_posix_free((void*) *line);
                *line = p;
                *len = l;
                res = 0;
@@ -791,7 +792,7 @@ static int  filter_check_rule(char*  line, size_t  len, struct filter*  rule)
    struct filter*  current_rule;
 
    /* Decode line */
-   if('#' != line[0])
+   if('#' != line[0] && '\n' != line[0])
    {
       /* Set 'dcre' flag, we only want to compare the strings of the rule */
       if(!filter_decode_rule(&current_rule, line, len, 1))
@@ -829,7 +830,7 @@ static int  filter_export_score_rules(FILE*  fs, FILE*  fs_tmp)
    int  res = -1;
    char*  line = NULL;
    size_t  len = 0;
-   posix_ssize_t  readlen;
+   api_posix_ssize_t  readlen;
    int  rv;
    struct filter*  rule;
 
@@ -841,10 +842,10 @@ static int  filter_export_score_rules(FILE*  fs, FILE*  fs_tmp)
    while(1)
    {
       /* Read line */
-      readlen = posix_getline(&line, &len, fs);
+      readlen = api_posix_getline(&line, &len, fs);
       if(-1 == readlen)
       {
-         if(POSIX_ENOMEM == posix_errno)
+         if(API_POSIX_ENOMEM == api_posix_errno)
          {
             PRINT_ERROR("Cannot assign memory for score file parser");
          }
@@ -911,7 +912,7 @@ static int  filter_export_score_rules(FILE*  fs, FILE*  fs_tmp)
    }
 
    /* Release memory for line buffer */
-   posix_free((void*) line);
+   api_posix_free((void*) line);
 
    return(res);
 }
@@ -932,7 +933,7 @@ static int  filter_get_pathname(const char**  pathname, const char*  filename)
    *pathname = xdg_get_confdir(CFG_NAME);
    if(NULL != *pathname)
    {
-      rv = fu_create_path(*pathname, (posix_mode_t) POSIX_S_IRWXU);
+      rv = fu_create_path(*pathname, (api_posix_mode_t) API_POSIX_S_IRWXU);
       if(0 == rv)
       {
          /* Store scorefile pathname */
@@ -948,7 +949,7 @@ static int  filter_get_pathname(const char**  pathname, const char*  filename)
    if(0 != res)
    {
       PRINT_ERROR("Cannot create score file pathname");
-      posix_free((void*) *pathname);
+      api_posix_free((void*) *pathname);
       *pathname = NULL;
    }
 
@@ -1002,7 +1003,10 @@ static int  filter_group_check(struct filter*  rule, const char**  grouplist)
             else if(ENC_CS_ISO8859_1 != charset)  { rv = -1; }
             else  { string = p; }
          }
-         if(!rv && !posix_regexec(plp->ere, string, 0, NULL, 0))  { res = 0; }
+         if(!rv && !api_posix_regexec(plp->ere, string, 0, NULL, 0))
+         {
+            res = 0;
+         }
          /* Release memory for ISO 8859-1 string */
          if(NULL != p && group != p)  { enc_free((void*) p); }
          /* Check for ERE match */
@@ -1051,13 +1055,13 @@ int  filter_init(int  utf8)
    const char*  scorepathname = NULL;
    char*  oldscorepathname = NULL;
    int  rv;
-   struct_posix_stat  state;
+   api_posix_struct_stat  state;
    int  fd = -1;
    FILE*  fs = NULL;
    char*  data = NULL;
    size_t  len;
    char*  line = NULL;
-   posix_ssize_t  readlen;
+   api_posix_ssize_t  readlen;
    struct filter*  rule;
 #if CFG_USE_POSIX_API >= 200112 || CFG_USE_XSI
    const char*  loc_ctype;
@@ -1076,7 +1080,7 @@ int  filter_init(int  utf8)
    printf("%s: %sCooked character classification codeset: "
           "US-ASCII\n", CFG_NAME, MAIN_ERR_PREFIX);
 #else  /* !(CFG_USE_POSIX_API >= 200112 || CFG_USE_XSI) */
-   loc_ctype = posix_setlocale(POSIX_LC_CTYPE, "");
+   loc_ctype = api_posix_setlocale(API_POSIX_LC_CTYPE, "");
    if(NULL == loc_ctype)
    {
       PRINT_ERROR("Setting locale for category 'LC_CTYPE' failed");
@@ -1095,7 +1099,7 @@ int  filter_init(int  utf8)
       else
       {
 #  if CFG_USE_XSI
-         loc_ctype = posix_nl_langinfo(CODESET);
+         loc_ctype = api_posix_nl_langinfo(CODESET);
 #  endif  /* CFG_USE_XSI */
          /* Check whether fallback to ISO 8859-1 is possible */
          if( NULL != strstr(loc_ctype, "8859-1")
@@ -1145,11 +1149,11 @@ int  filter_init(int  utf8)
     * Note: Use of snprintf() must no longer be SUS Version 2 compatible.
     * C99/POSIX.1-2001/SUSv3 semantics are now provided by the POSIX module.
     */
-   rv = posix_snprintf(NULL, 0, "%d", FILTER_SCORE_MAX);
+   rv = api_posix_snprintf(NULL, 0, "%d", FILTER_SCORE_MAX);
    if(0 <= rv)
    {
       score_len_max = (size_t) rv;
-      rv = posix_snprintf(NULL, 0, "%d", FILTER_SCORE_MIN);
+      rv = api_posix_snprintf(NULL, 0, "%d", FILTER_SCORE_MIN);
       if(0 <= rv)
       {
          if((size_t) rv > score_len_max)  { score_len_max = (size_t) rv; }
@@ -1170,15 +1174,16 @@ int  filter_init(int  utf8)
          printf("%s: %sImport external scorerc: %s\n",
                 CFG_NAME, MAIN_ERR_PREFIX, scorerc);
       }
-      rv = posix_stat(scorerc, &state);
+      rv = api_posix_stat(scorerc, &state);
       if(rv)  { PRINT_ERROR("Cannot stat scorerc file"); }
-      else if(POSIX_S_ISREG(state.st_mode))
+      else if(API_POSIX_S_ISREG(state.st_mode))
       {
          rv = filter_get_pathname(&scorepathname, scorefile_name);
          if(!rv)
          {
             /* Read scorerc file */
-            rv = fu_open_file(scorerc, &fd, POSIX_O_RDWR, (posix_mode_t) 0);
+            rv = fu_open_file(scorerc, &fd, API_POSIX_O_RDWR,
+                              (api_posix_mode_t) 0);
             if(!rv)
             {
                rv = fu_lock_file(fd);
@@ -1190,7 +1195,7 @@ int  filter_init(int  utf8)
                if(!rv)
                {
                   oldscorepathname =
-                     posix_malloc(strlen(scorepathname) + (size_t) 5);
+                     api_posix_malloc(strlen(scorepathname) + (size_t) 5);
                   if(NULL == oldscorepathname)
                   {
                      PRINT_ERROR("Cannot allocate memory for pathname");
@@ -1199,13 +1204,13 @@ int  filter_init(int  utf8)
                   {
                      strcpy(oldscorepathname, scorepathname);
                      strcat(oldscorepathname, ".old");
-                     rv = posix_rename(scorepathname, oldscorepathname);
+                     rv = api_posix_rename(scorepathname, oldscorepathname);
                      if(rv)
                      {
                         PRINT_ERROR("Renaming score file failed");
                      }
                      rv = fu_open_file(scorepathname, &fd,
-                                       POSIX_O_WRONLY | POSIX_O_CREAT,
+                                       API_POSIX_O_WRONLY | API_POSIX_O_CREAT,
                                        FILTER_PERM);
                      if(!rv)
                      {
@@ -1228,20 +1233,21 @@ int  filter_init(int  utf8)
       }
    }
    /* Release memory */
-   posix_free((void*) data);
-   posix_free((void*) oldscorepathname);
-   posix_free((void*) scorepathname);
+   api_posix_free((void*) data);
+   api_posix_free((void*) oldscorepathname);
+   api_posix_free((void*) scorepathname);
    scorepathname = NULL;
 
    /* Step 2 */
    rv = filter_get_pathname(&scorepathname, scorefile_name);
    if(!rv)
    {
-      rv = posix_stat(scorepathname, &state);
+      rv = api_posix_stat(scorepathname, &state);
       if(rv)  { PRINT_ERROR("Cannot stat score file"); }
-      else if(POSIX_S_ISREG(state.st_mode))
+      else if(API_POSIX_S_ISREG(state.st_mode))
       {
-         rv = fu_open_file(scorepathname, &fd, POSIX_O_RDWR, (posix_mode_t) 0);
+         rv = fu_open_file(scorepathname, &fd, API_POSIX_O_RDWR,
+                           (api_posix_mode_t) 0);
          if(!rv)
          {
             rv = fu_lock_file(fd);
@@ -1259,10 +1265,10 @@ int  filter_init(int  utf8)
                   while(1)
                   {
                      /* Read line */
-                     readlen = posix_getline(&line, &len, fs);
+                     readlen = api_posix_getline(&line, &len, fs);
                      if(-1 == readlen)
                      {
-                        if(POSIX_ENOMEM == posix_errno)
+                        if(API_POSIX_ENOMEM == api_posix_errno)
                         {
                            PRINT_ERROR("Cannot allocate memory for score "
                                        "file parser");
@@ -1280,13 +1286,13 @@ int  filter_init(int  utf8)
                      else
                      {
                         /* Extract data */
-                        if('#' == line[0])  { continue; }
+                        if('#' == line[0] || '\n' == line[0])  { continue; }
                         rv = filter_decode_rule(&rule, line, (size_t) readlen,
                                                 0);
                         if(!rv)  { filter_add_score_rule(rule); }
                      }
                   }
-                  posix_free((void*) line);
+                  api_posix_free((void*) line);
                   rv = 0;
                }
             }
@@ -1296,7 +1302,7 @@ int  filter_init(int  utf8)
       if(rv)  { PRINT_ERROR("Importing rules from score file failed"); }
    }
    /* Release memory */
-   posix_free((void*) scorepathname);
+   api_posix_free((void*) scorepathname);
 
 #if CFG_USE_POSIX_API >= 200112 || CFG_USE_XSI || CFG_USE_CLB
    /* Initialize test group checking facility */
@@ -1344,7 +1350,7 @@ void  filter_exit(void)
    FILE*  fs_tmp = NULL;
    char*  data = NULL;
    size_t  len;
-   struct_posix_stat  state;
+   api_posix_struct_stat  state;
    char*  p;
 
    /* Step 1 */
@@ -1352,19 +1358,20 @@ void  filter_exit(void)
    if(!rv)
    {
       /* Create scorefile if it does not exist */
-      rv = posix_stat(scorepathname, &state);
-      if(rv && POSIX_ENOENT == posix_errno)
+      rv = api_posix_stat(scorepathname, &state);
+      if(rv && API_POSIX_ENOENT == api_posix_errno)
       {
          fu_open_file(scorepathname, &fd_tmp,
-                      POSIX_O_WRONLY | POSIX_O_CREAT, FILTER_PERM);
+                      API_POSIX_O_WRONLY | API_POSIX_O_CREAT, FILTER_PERM);
          fu_close_file(&fd_tmp, NULL);
       }
       /* Open scorefile */
-      rv = posix_stat(scorepathname, &state);
+      rv = api_posix_stat(scorepathname, &state);
       if(rv)  { PRINT_ERROR("Cannot stat score file"); }
-      else if(POSIX_S_ISREG(state.st_mode))
+      else if(API_POSIX_S_ISREG(state.st_mode))
       {
-         rv = fu_open_file(scorepathname, &fd, POSIX_O_RDWR, (posix_mode_t) 0);
+         rv = fu_open_file(scorepathname, &fd, API_POSIX_O_RDWR,
+                           (api_posix_mode_t) 0);
          if(!rv)
          {
             rv = fu_lock_file(fd);
@@ -1374,8 +1381,8 @@ void  filter_exit(void)
                if(!rv)
                {
                   /* Open temporary file */
-                  tmppathname = posix_malloc(strlen(scorepathname)
-                                             + (size_t) 5);
+                  tmppathname = api_posix_malloc(strlen(scorepathname)
+                                                 + (size_t) 5);
                   if(NULL == tmppathname)
                   {
                      PRINT_ERROR("Cannot allocate memory for pathname");
@@ -1384,8 +1391,8 @@ void  filter_exit(void)
                   {
                      strcpy(tmppathname, scorepathname);
                      strcat(tmppathname, ".new");
-                     rv = fu_open_file(tmppathname, &fd_tmp, POSIX_O_WRONLY
-                                       | POSIX_O_CREAT | POSIX_O_TRUNC,
+                     rv = fu_open_file(tmppathname, &fd_tmp, API_POSIX_O_WRONLY
+                                       | API_POSIX_O_CREAT | API_POSIX_O_TRUNC,
                                        FILTER_PERM);
                      /*
                       * Because we have the lock for the score file, it is
@@ -1404,7 +1411,7 @@ void  filter_exit(void)
                         /* Rename temporary file to score file */
                         if(!rv)
                         {
-                           rv = posix_rename(tmppathname, scorepathname);
+                           rv = api_posix_rename(tmppathname, scorepathname);
                         }
                         if(rv)
                         {
@@ -1429,8 +1436,8 @@ void  filter_exit(void)
    if(!rv && strlen(scorerc))
    {
       /* Read scorefile */
-      rv = fu_open_file(scorepathname, &fd, POSIX_O_RDWR,
-                        (posix_mode_t) 0);
+      rv = fu_open_file(scorepathname, &fd, API_POSIX_O_RDWR,
+                        (api_posix_mode_t) 0);
       if(!rv)
       {
          rv = fu_lock_file(fd);
@@ -1447,7 +1454,7 @@ void  filter_exit(void)
                printf("%s: %sExport to external scorerc: %s\n",
                       CFG_NAME, MAIN_ERR_PREFIX, scorerc);
             }
-            p = posix_realloc(tmppathname, strlen(scorerc) + (size_t) 5);
+            p = api_posix_realloc(tmppathname, strlen(scorerc) + (size_t) 5);
             if(NULL == p)
             {
                PRINT_ERROR("Cannot allocate memory for pathname");
@@ -1458,7 +1465,8 @@ void  filter_exit(void)
                strcpy(tmppathname, scorerc);
                strcat(tmppathname, ".new");
                rv = fu_open_file(tmppathname, &fd,
-                                 POSIX_O_WRONLY | POSIX_O_CREAT, FILTER_PERM);
+                                 API_POSIX_O_WRONLY | API_POSIX_O_CREAT,
+                                 FILTER_PERM);
                if(!rv)
                {
                   rv = fu_lock_file(fd);
@@ -1473,7 +1481,7 @@ void  filter_exit(void)
                      }
                      else
                      {
-                        rv = posix_rename(tmppathname, scorerc);
+                        rv = api_posix_rename(tmppathname, scorerc);
                         if(rv)
                         {
                            PRINT_ERROR("Renaming new scorerc file failed");
@@ -1492,17 +1500,17 @@ void  filter_exit(void)
    }
 
    /* Release memory */
-   posix_free((void*) data);
-   posix_free((void*) tmppathname);
-   posix_free((void*) scorepathname);
+   api_posix_free((void*) data);
+   api_posix_free((void*) tmppathname);
+   api_posix_free((void*) scorepathname);
 
 #if CFG_USE_POSIX_API >= 200112 || CFG_USE_XSI || CFG_USE_CLB
    /* Destroy testgroup ERE */
    if(NULL != testgroup_ere)
    {
       /* Destroy regular expression object */
-      posix_regfree(testgroup_ere);
-      posix_free((void*) testgroup_ere);
+      api_posix_regfree(testgroup_ere);
+      api_posix_free((void*) testgroup_ere);
       testgroup_ere = NULL;
    }
 #endif  /* CFG_USE_POSIX_API >= 200112 || CFG_USE_XSI || CFG_USE_CLB */
@@ -1557,7 +1565,7 @@ int  filter_check_testgroup(const char*  group)
       {
          PRINT_ERROR("Test group name cannot be checked with current locale");
       }
-      else if(!posix_regexec(testgroup_ere, string, 0, NULL, 0))
+      else if(!api_posix_regexec(testgroup_ere, string, 0, NULL, 0))
       {
          printf("%s: %sTest group detected\n", CFG_NAME, MAIN_ERR_PREFIX);
          res = 1;
@@ -1705,6 +1713,7 @@ int  filter_get_score(const struct core_hierarchy_element*  he)
                   if(NULL == data)  { data = he->header->from; }
                   /* No break here is intended! */
                }
+               /* FALLTHROUGH */
                case SCORE_TYPE_SUBJECT:
                {
                   if(NULL == data)  { data = he->header->subject; }
@@ -1736,11 +1745,13 @@ int  filter_get_score(const struct core_hierarchy_element*  he)
                   if(NULL == data)  { data = he->header->from; }
                   /* No break here is intended! */
                }
+               /* FALLTHROUGH */
                case SCORE_TYPE_SUBJECT_ERE:
                {
                   if(NULL == data)  { data = he->header->subject; }
                   /* No break here is intended! */
                }
+               /* FALLTHROUGH */
                case SCORE_TYPE_MSGID_ERE:
                {
                   if(NULL == data)  { data = he->header->msgid; }
@@ -1769,7 +1780,7 @@ int  filter_get_score(const struct core_hierarchy_element*  he)
                         else if(ENC_CS_ISO8859_1 != charset)  { rv = -1; }
                         else  { string = p; }
                      }
-                     if(!rv && !posix_regexec(rule->ere, string, 0, NULL, 0))
+                     if(!rv && !api_posix_regexec(rule->ere, string, 0, NULL, 0))
                      {
                         res = filter_score_add(res, rule->value);
                      }
