@@ -2,7 +2,7 @@
 /*! \file
  * \brief Handling of subscribed groups and already viewed articles
  *
- * Copyright (c) 2012-2020 by the developers. See the LICENSE file for details.
+ * Copyright (c) 2012-2024 by the developers. See the LICENSE file for details.
  *
  * If nothing else is specified, functions return zero to indicate success
  * and a negative value to indicate an error.
@@ -47,7 +47,7 @@
 
 
 /*! \brief Permissions for group file */
-#define GROUP_PERM  (posix_mode_t) (POSIX_S_IRUSR | POSIX_S_IWUSR)
+#define GROUP_PERM  (api_posix_mode_t) (API_POSIX_S_IRUSR | API_POSIX_S_IWUSR)
 
 
 /* ========================================================================== */
@@ -80,8 +80,8 @@ static int  group_compar(const void*  a, const void*  b)
    char*  y;
    char*  p;
 
-   x = (char*) posix_malloc(strlen(aa) + (size_t) 1);
-   y = (char*) posix_malloc(strlen(bb) + (size_t) 1);
+   x = (char*) api_posix_malloc(strlen(aa) + (size_t) 1);
+   y = (char*) api_posix_malloc(strlen(bb) + (size_t) 1);
    if(NULL != x && NULL != y)
    {
       strcpy(x, aa);
@@ -90,12 +90,12 @@ static int  group_compar(const void*  a, const void*  b)
       p = strchr(x, (int) '!');  if(NULL != p)  { *p = 0; }
       p = strchr(y, (int) ':');  if(NULL != p)  { *p = 0; }
       p = strchr(y, (int) '!');  if(NULL != p)  { *p = 0; }
-      posix_errno = 0;
+      api_posix_errno = 0;
       res = strcoll(x, y);
-      if(posix_errno)  { res = 0; }
+      if(api_posix_errno)  { res = 0; }
    }
-   posix_free((void*) x);
-   posix_free((void*) y);
+   api_posix_free((void*) x);
+   api_posix_free((void*) y);
 
    return(res);
 }
@@ -117,7 +117,7 @@ static int  group_get_pathname(const char**  pathname, const char*  filename)
    *pathname = xdg_get_confdir(CFG_NAME);
    if(NULL != *pathname)
    {
-      rv = fu_create_path(*pathname, (posix_mode_t) POSIX_S_IRWXU);
+      rv = fu_create_path(*pathname, (api_posix_mode_t) API_POSIX_S_IRWXU);
       if(0 == rv)
       {
          /* Store scorefile pathname */
@@ -133,7 +133,7 @@ static int  group_get_pathname(const char**  pathname, const char*  filename)
    if(0 != res)
    {
       PRINT_ERROR("Cannot create group file pathname");
-      posix_free((void*) *pathname);
+      api_posix_free((void*) *pathname);
       *pathname = NULL;
    }
 
@@ -185,7 +185,7 @@ static int  group_extract_ranges(struct core_range**  list, const char*  s)
       if(enc_ascii_check_digit(s))  { res = -1;  break; }
       while(!enc_ascii_check_digit(++s));
       len = (size_t) (s - p);
-      if((size_t) POSIX_INT_MAX < len)  { res = -1;  break; }
+      if((size_t) API_POSIX_INT_MAX < len)  { res = -1;  break; }
       rv = enc_convert_ascii_to_anum(&tmp, p, (int) len);
       if(rv)  { res = -1;  break; }
       /* Skip potential white space */
@@ -299,7 +299,7 @@ static int  group_export_groups(size_t  num, struct core_groupstate*  grouplist,
 
    char*  line = NULL;
    size_t  len = 0;
-   posix_ssize_t  readlen;
+   api_posix_ssize_t  readlen;
    int  rv;
    char*  p;
    size_t*  inserted = NULL;
@@ -308,7 +308,7 @@ static int  group_export_groups(size_t  num, struct core_groupstate*  grouplist,
    int  modified;
    size_t  nlen = 0;
 
-   inserted = (size_t*) posix_malloc(sizeof(size_t) * num);
+   inserted = (size_t*) api_posix_malloc(sizeof(size_t) * num);
    if(NULL != inserted)
    {
       /* Init insertion flags */
@@ -318,10 +318,10 @@ static int  group_export_groups(size_t  num, struct core_groupstate*  grouplist,
       while(1)
       {
          /* Read line */
-         readlen = posix_getline(&line, &len, fs);
+         readlen = api_posix_getline(&line, &len, fs);
          if(-1 == readlen)
          {
-            if (POSIX_ENOMEM == posix_errno)
+            if (API_POSIX_ENOMEM == api_posix_errno)
             {
                PRINT_ERROR("Cannot assign memory for group file parser");
                break;
@@ -408,8 +408,8 @@ static int  group_export_groups(size_t  num, struct core_groupstate*  grouplist,
    }
 
    /* Release memory */
-   posix_free((void*) line);
-   posix_free((void*) inserted);
+   api_posix_free((void*) line);
+   api_posix_free((void*) inserted);
 
    return(res);
 }
@@ -432,7 +432,7 @@ static int  group_import_groups(size_t*  num,
    int  res = -1;
    char*  line;
    size_t  len = 0;
-   posix_ssize_t  readlen;
+   api_posix_ssize_t  readlen;
    struct core_groupstate*  p;
    char*  c;
    struct core_range*  rp = NULL;
@@ -444,11 +444,11 @@ static int  group_import_groups(size_t*  num,
    {
       /* Read line */
       line = NULL;
-      readlen = posix_getline(&line, &len, fs);
+      readlen = api_posix_getline(&line, &len, fs);
       if(-1 == readlen)
       {
-         posix_free((void*) line);
-         if (POSIX_ENOMEM == posix_errno)
+         api_posix_free((void*) line);
+         if (API_POSIX_ENOMEM == api_posix_errno)
          {
             PRINT_ERROR("Cannot allocate memory for group file parser");
             break;
@@ -476,39 +476,39 @@ static int  group_import_groups(size_t*  num,
          if(enc_ascii_check(line))
          {
             /* Invalid encoding => Ignore line */
-            posix_free((void*) line);
+            api_posix_free((void*) line);
             continue;
          }
          /* Extract group name */
          if(strchr(line, (int) '!'))
          {
             /* Ignore unsubscribed groups */
-            posix_free(line);
+            api_posix_free(line);
             continue;
          }
          c = strchr(line, (int) ':');
          if(NULL == c)
          {
             /* Invalid format => Ignore line */
-            posix_free((void*) line);
+            api_posix_free((void*) line);
             continue;
          }
          /* Terminate group name by replacing ':' with NUL */
          *c = 0;
          /* Add group name to list */
          p = (struct core_groupstate*)
-             posix_realloc((void*) *grouplist,
-                           (*num + (size_t) 1) * sizeof(**grouplist));
+             api_posix_realloc((void*) *grouplist,
+                               (*num + (size_t) 1) * sizeof(**grouplist));
          if(NULL == p)
          {
             PRINT_ERROR("Cannot allocate memory for group list");
-            posix_free((void*) line);
+            api_posix_free((void*) line);
             break;
          }
          else
          {
             *grouplist = p;
-            line[readlen - (posix_ssize_t) 1] = 0;
+            line[readlen - (api_posix_ssize_t) 1] = 0;
             (*grouplist)[(*num)].name = line;
             (*grouplist)[(*num)].info = NULL;
             (*grouplist)[(*num)].last_viewed = 0;
@@ -553,7 +553,7 @@ void  group_init(void)
    const char*  grouppathname = NULL;
    char*  oldgrouppathname = NULL;
    int  rv;
-   struct_posix_stat  state;
+   api_posix_struct_stat  state;
    int  fd = -1;
    char*  data = NULL;
    size_t  len;
@@ -565,15 +565,16 @@ void  group_init(void)
          printf("%s: %sImport external newsrc: %s\n",
                 CFG_NAME, MAIN_ERR_PREFIX, newsrc);
       }
-      rv = posix_stat(newsrc, &state);
+      rv = api_posix_stat(newsrc, &state);
       if(rv)  { PRINT_ERROR("Cannot stat newsrc file"); }
-      else if(POSIX_S_ISREG(state.st_mode))
+      else if(API_POSIX_S_ISREG(state.st_mode))
       {
          rv = group_get_pathname(&grouppathname, groupfile_name);
          if(!rv)
          {
             /* Read newsrc file */
-            rv = fu_open_file(newsrc, &fd, POSIX_O_RDWR, (posix_mode_t) 0);
+            rv = fu_open_file(newsrc, &fd, API_POSIX_O_RDWR,
+                              (api_posix_mode_t) 0);
             if(!rv)
             {
                rv = fu_lock_file(fd);
@@ -585,7 +586,8 @@ void  group_init(void)
                if(!rv)
                {
                   oldgrouppathname =
-                     (char*) posix_malloc(strlen(grouppathname) + (size_t) 5);
+                     (char*) api_posix_malloc(strlen(grouppathname)
+                                              + (size_t) 5);
                   if(NULL == oldgrouppathname)
                   {
                      PRINT_ERROR("Cannot allocate memory for pathname");
@@ -594,7 +596,7 @@ void  group_init(void)
                   {
                      strcpy(oldgrouppathname, grouppathname);
                      strcat(oldgrouppathname, ".old");
-                     rv = posix_rename(grouppathname, oldgrouppathname);
+                     rv = api_posix_rename(grouppathname, oldgrouppathname);
                      if(rv)
                      {
                         PRINT_ERROR("Renaming groupfile failed");
@@ -602,7 +604,8 @@ void  group_init(void)
                      else
                      {
                         rv = fu_open_file(grouppathname, &fd,
-                                          POSIX_O_WRONLY | POSIX_O_CREAT,
+                                          API_POSIX_O_WRONLY
+                                          | API_POSIX_O_CREAT,
                                           GROUP_PERM);
                         if(!rv)
                         {
@@ -627,9 +630,9 @@ void  group_init(void)
    }
 
    /* Release memory */
-   posix_free((void*) data);
-   posix_free((void*) oldgrouppathname);
-   posix_free((void*) grouppathname);
+   api_posix_free((void*) data);
+   api_posix_free((void*) oldgrouppathname);
+   api_posix_free((void*) grouppathname);
 }
 
 
@@ -656,8 +659,8 @@ void  group_exit(void)
       rv = group_get_pathname(&grouppathname, groupfile_name);
       if(!rv)
       {
-         rv = fu_open_file(grouppathname, &fd, POSIX_O_RDWR,
-                           (posix_mode_t) 0);
+         rv = fu_open_file(grouppathname, &fd, API_POSIX_O_RDWR,
+                           (api_posix_mode_t) 0);
          if(!rv)
          {
             rv = fu_lock_file(fd);
@@ -674,7 +677,8 @@ void  group_exit(void)
                   printf("%s: %sExport to external newsrc: %s\n",
                          CFG_NAME, MAIN_ERR_PREFIX, newsrc);
                }
-               tmppathname = (char*) posix_malloc(strlen(newsrc) + (size_t) 5);
+               tmppathname = (char*) api_posix_malloc(strlen(newsrc)
+                                                      + (size_t) 5);
                if(NULL == tmppathname)
                {
                   PRINT_ERROR("Cannot allocate memory for pathname");
@@ -684,7 +688,8 @@ void  group_exit(void)
                   strcpy(tmppathname, newsrc);
                   strcat(tmppathname, ".new");
                   rv = fu_open_file(tmppathname, &fd,
-                                    POSIX_O_WRONLY | POSIX_O_CREAT, GROUP_PERM);
+                                    API_POSIX_O_WRONLY | API_POSIX_O_CREAT,
+                                    GROUP_PERM);
                   if(!rv)
                   {
                      rv = fu_lock_file(fd);
@@ -699,7 +704,7 @@ void  group_exit(void)
                         }
                         else
                         {
-                           rv = posix_rename(tmppathname, newsrc);
+                           rv = api_posix_rename(tmppathname, newsrc);
                            if(rv)
                            {
                               PRINT_ERROR("Renaming new newsrc file failed");
@@ -716,9 +721,9 @@ void  group_exit(void)
    }
 
    /* Release memory */
-   posix_free((void*) data);
-   posix_free((void*) tmppathname);
-   posix_free((void*) grouppathname);
+   api_posix_free((void*) data);
+   api_posix_free((void*) tmppathname);
+   api_posix_free((void*) grouppathname);
 }
 
 
@@ -744,7 +749,7 @@ int  group_article_range_constructor(struct core_range**  range,
 {
    int  res = 0;
 
-   *range = (struct core_range*) posix_malloc(sizeof(struct core_range));
+   *range = (struct core_range*) api_posix_malloc(sizeof(struct core_range));
    if (NULL == *range)  { res = -1; }
    else
    {
@@ -773,7 +778,7 @@ void  group_article_range_destructor(struct core_range**  list)
    while(NULL != current_element)
    {
       tmp_element = current_element->next;
-      posix_free((void*) current_element);
+      api_posix_free((void*) current_element);
       current_element = tmp_element;
    }
    *list = NULL;
@@ -796,12 +801,12 @@ void  group_destroy_list(size_t*  num, struct core_groupstate**  grouplist)
 
    while((*num)--)
    {
-      posix_free((void*) (*grouplist)[*num].name);
+      api_posix_free((void*) (*grouplist)[*num].name);
       group_article_range_destructor(&(*grouplist)[*num].info);
    }
    /* Unsigned integer under/overflow is intended and has defined behaviour */
    ++(*num);
-   posix_free((void*) *grouplist);
+   api_posix_free((void*) *grouplist);
    *grouplist = NULL;
 }
 
@@ -832,7 +837,8 @@ int  group_get_list(size_t*  num, struct core_groupstate**  grouplist)
    res = group_get_pathname(&grouppathname, groupfile_name);
    if(!res)
    {
-      res = fu_open_file(grouppathname, &fd, POSIX_O_RDWR | POSIX_O_CREAT,
+      res = fu_open_file(grouppathname, &fd,
+                         API_POSIX_O_RDWR | API_POSIX_O_CREAT,
                          GROUP_PERM);
       if(!res)  { res = fu_lock_file(fd); }
       if(!res)  { res = fu_assign_stream(fd, &fs, "r"); }
@@ -845,7 +851,7 @@ int  group_get_list(size_t*  num, struct core_groupstate**  grouplist)
    fu_close_file(&fd, &fs);
 
    /* Release memory for file pathname */
-   posix_free((void*) grouppathname);
+   api_posix_free((void*) grouppathname);
 
    return(res);
 }
@@ -883,7 +889,8 @@ int  group_set_list(size_t  num, struct core_groupstate*  grouplist)
    /* Open and lock group file */
    if(!res)
    {
-      res = fu_open_file(grouppathname, &fd, POSIX_O_RDWR | POSIX_O_CREAT,
+      res = fu_open_file(grouppathname, &fd,
+                         API_POSIX_O_RDWR | API_POSIX_O_CREAT,
                          GROUP_PERM);
       if(!res)  { res = fu_lock_file(fd); }
       if(!res)  { res = fu_assign_stream(fd, &fs, "r"); }
@@ -893,7 +900,8 @@ int  group_set_list(size_t  num, struct core_groupstate*  grouplist)
    if(!res)
    {
       res = fu_open_file(tmppathname, &fd_tmp,
-                         POSIX_O_WRONLY | POSIX_O_CREAT | POSIX_O_TRUNC,
+                         API_POSIX_O_WRONLY | API_POSIX_O_CREAT
+                         | API_POSIX_O_TRUNC,
                          GROUP_PERM);
       /*
        * Because we have the lock for the group file, it is allowed to
@@ -910,7 +918,7 @@ int  group_set_list(size_t  num, struct core_groupstate*  grouplist)
    if(!res)  { res = fu_sync(fd_tmp, fs_tmp); }
 
    /* Rename temporary file to group file */
-   if(!res)  { res = posix_rename(tmppathname, grouppathname); }
+   if(!res)  { res = api_posix_rename(tmppathname, grouppathname); }
 
    /* Unlink temporary file after error */
    if(res)
@@ -926,8 +934,8 @@ int  group_set_list(size_t  num, struct core_groupstate*  grouplist)
    fu_close_file(&fd, &fs);
 
    /* Release memory for file pathnames */
-   posix_free((void*) tmppathname);
-   posix_free((void*) grouppathname);
+   api_posix_free((void*) tmppathname);
+   api_posix_free((void*) grouppathname);
 
    return(res);
 }
@@ -952,7 +960,7 @@ int  group_sort_list(void)
    const char*  tmppathname = NULL;
    char*  line;
    size_t  len = 0;
-   posix_ssize_t  readlen;
+   api_posix_ssize_t  readlen;
    const char**  array = NULL;
    const char**  array_tmp;
    size_t  array_len = 0;
@@ -966,7 +974,8 @@ int  group_sort_list(void)
    /* Open and lock group file */
    if(!res)
    {
-      res = fu_open_file(grouppathname, &fd, POSIX_O_RDWR | POSIX_O_CREAT,
+      res = fu_open_file(grouppathname, &fd,
+                         API_POSIX_O_RDWR | API_POSIX_O_CREAT,
                          GROUP_PERM);
       if(!res)  { res = fu_lock_file(fd); }
       if(!res)  { res = fu_assign_stream(fd, &fs, "r"); }
@@ -981,7 +990,8 @@ int  group_sort_list(void)
        * temporary filename.
        */
       res = fu_open_file(tmppathname, &fd_tmp,
-                         POSIX_O_WRONLY | POSIX_O_CREAT | POSIX_O_TRUNC,
+                         API_POSIX_O_WRONLY | API_POSIX_O_CREAT
+                         | API_POSIX_O_TRUNC,
                          GROUP_PERM);
       if(!res)  { res = fu_assign_stream(fd_tmp, &fs_tmp, "w"); }
    }
@@ -993,11 +1003,11 @@ int  group_sort_list(void)
       while(1)
       {
          line = NULL;
-         readlen = posix_getline(&line, &len, fs);
+         readlen = api_posix_getline(&line, &len, fs);
          if(-1 == readlen)
          {
-            posix_free((void*) line);
-            if (POSIX_ENOMEM == posix_errno)
+            api_posix_free((void*) line);
+            if (API_POSIX_ENOMEM == api_posix_errno)
             {
                PRINT_ERROR("Cannot allocate memory for group data");
                break;
@@ -1023,9 +1033,9 @@ int  group_sort_list(void)
          {
             /* Create array of line pointers */
             array_tmp = (const char**)
-                        posix_realloc(array, (array_len + (size_t) 1)
-                                      * (sizeof(const char*)));
-            if(NULL == array_tmp)  { posix_free((void*) line);  break; }
+                        api_posix_realloc(array, (array_len + (size_t) 1)
+                                          * (sizeof(const char*)));
+            if(NULL == array_tmp)  { api_posix_free((void*) line);  break; }
             else
             {
                array = array_tmp;
@@ -1048,14 +1058,14 @@ int  group_sort_list(void)
    }
 
    /* Release memory for array of lines */
-   while(array_len)  { posix_free((void*) array[--array_len]); }
-   posix_free((void*) array);
+   while(array_len)  { api_posix_free((void*) array[--array_len]); }
+   api_posix_free((void*) array);
 
    /* Flush stream of temporary file*/
    if(!res) { res = fu_sync(fd_tmp, fs_tmp); }
 
    /* Rename temporary file to group file */
-   if(!res)  { res = posix_rename(tmppathname, grouppathname); }
+   if(!res)  { res = api_posix_rename(tmppathname, grouppathname); }
 
    /* Unlink temporary file after error */
    if(res)
@@ -1071,8 +1081,8 @@ int  group_sort_list(void)
    fu_close_file(&fd, &fs);
 
    /* Release memory for file pathnames */
-   posix_free((void*) tmppathname);
-   posix_free((void*) grouppathname);
+   api_posix_free((void*) tmppathname);
+   api_posix_free((void*) grouppathname);
 
    return(res);
 }
@@ -1099,7 +1109,7 @@ int  group_add(struct core_groupstate*  group)
    const char*  tmppathname = NULL;
    char*  line = NULL;
    size_t  len = 0;
-   posix_ssize_t  readlen;
+   api_posix_ssize_t  readlen;
    int  rv;
    size_t  nlen;
    char*  p;
@@ -1112,7 +1122,8 @@ int  group_add(struct core_groupstate*  group)
    /* Open and lock group file */
    if(!res)
    {
-      res = fu_open_file(grouppathname, &fd, POSIX_O_RDWR | POSIX_O_CREAT,
+      res = fu_open_file(grouppathname, &fd,
+                         API_POSIX_O_RDWR | API_POSIX_O_CREAT,
                          GROUP_PERM);
       if(!res)  { res = fu_lock_file(fd); }
       if(!res)  { res = fu_assign_stream(fd, &fs, "r"); }
@@ -1122,7 +1133,8 @@ int  group_add(struct core_groupstate*  group)
    if(!res)
    {
       res = fu_open_file(tmppathname, &fd_tmp,
-                         POSIX_O_WRONLY | POSIX_O_CREAT | POSIX_O_TRUNC,
+                         API_POSIX_O_WRONLY | API_POSIX_O_CREAT
+                         | API_POSIX_O_TRUNC,
                          GROUP_PERM);
       /*
        * Because we have the lock for the group file, it is allowed to
@@ -1139,10 +1151,10 @@ int  group_add(struct core_groupstate*  group)
       while(1)
       {
          /* Read line */
-         readlen = posix_getline(&line, &len, fs);
+         readlen = api_posix_getline(&line, &len, fs);
          if(-1 == readlen)
          {
-            if (POSIX_ENOMEM == posix_errno)
+            if (API_POSIX_ENOMEM == api_posix_errno)
             {
                PRINT_ERROR("Cannot assign memory to read group file");
             }
@@ -1195,7 +1207,7 @@ int  group_add(struct core_groupstate*  group)
    if(!res) { res = fu_sync(fd_tmp, fs_tmp); }
 
    /* Rename temporary file to group file */
-   if(!res)  { res = posix_rename(tmppathname, grouppathname); }
+   if(!res)  { res = api_posix_rename(tmppathname, grouppathname); }
 
    /* Unlink temporary file after error */
    if(res)
@@ -1211,9 +1223,9 @@ int  group_add(struct core_groupstate*  group)
    fu_close_file(&fd, &fs);
 
    /* Release memory for file pathnames */
-   posix_free((void*) line);
-   posix_free((void*) tmppathname);
-   posix_free((void*) grouppathname);
+   api_posix_free((void*) line);
+   api_posix_free((void*) tmppathname);
+   api_posix_free((void*) grouppathname);
 
    return(res);
 }
