@@ -2,7 +2,7 @@
 /*! \file
  * \brief Keyed-Hash Message Authentication Code
  *
- * Copyright (c) 2012-2022 by the developers. See the LICENSE file for details.
+ * Copyright (c) 2012-2024 by the developers. See the LICENSE file for details.
  *
  * If nothing else is specified, function return zero to indicate success
  * and a negative value to indicate an error.
@@ -128,12 +128,12 @@ static int  hmac_openssl(enum hmac_alg  alg, const char*  text,
 #  elif CFG_USE_OPENSSL_API_1_1 || CFG_USE_LIBRESSL_API_3_5
       ctx = HMAC_CTX_new();
 #  else   /* CFG_USE_OPENSSL_API_1_1 */
-      ctx = (HMAC_CTX*) posix_malloc(sizeof(HMAC_CTX));
+      ctx = (HMAC_CTX*) api_posix_malloc(sizeof(HMAC_CTX));
 #  endif   /* CFG_USE_OPENSSL_API_1_1 */
       if(NULL == ctx)  { PRINT_ERROR("Creating context failed"); }
 
       /* Check whether length values can be represented as data type 'int' */
-      else if(!(POSIX_INT_MAX >= text_len && POSIX_INT_MAX >= key_len))
+      else if(!(API_POSIX_INT_MAX >= text_len && API_POSIX_INT_MAX >= key_len))
       {
          PRINT_ERROR("Message or key is too long");
       }
@@ -188,7 +188,7 @@ static int  hmac_openssl(enum hmac_alg  alg, const char*  text,
       HMAC_CTX_free(ctx);
 #  else  /* CFG_USE_OPENSSL_API_1_1 */
       HMAC_CTX_cleanup(ctx);
-      posix_free((void*) ctx);
+      api_posix_free((void*) ctx);
 #  endif  /* CFG_USE_OPENSSL_API_1_1 */
    }
 
