@@ -2,7 +2,7 @@
 /*! \file
  * \brief Minimalistic WWW client
  *
- * Copyright (c) 2015-2020 by the developers. See the LICENSE file for details.
+ * Copyright (c) 2015-2024 by the developers. See the LICENSE file for details.
  *
  * If nothing else is specified, functions return zero to indicate success
  * and a negative value to indicate an error.
@@ -59,7 +59,7 @@ struct http_status
 #define MAIN_ERR_PREFIX  "HTTP: "
 
 /*! \brief Permissions for downloaded files that are created by this module */
-#define HTTP_PERM  (posix_mode_t) (POSIX_S_IRUSR | POSIX_S_IWUSR)
+#define HTTP_PERM  (api_posix_mode_t) (API_POSIX_S_IRUSR | API_POSIX_S_IWUSR)
 
 /*! \brief At least 8000 octets recommended by RFC 7230 */
 #define HTTP_LINE_MAX  (size_t) 8192
@@ -72,7 +72,8 @@ static int  http_prepare_local_file(int*  fd, const char*  lpn)
 {
    int  res = -1;
 
-   res = fu_open_file(lpn, fd, POSIX_O_RDWR | POSIX_O_CREAT| POSIX_O_TRUNC,
+   res = fu_open_file(lpn, fd,
+                      API_POSIX_O_RDWR | API_POSIX_O_CREAT| API_POSIX_O_TRUNC,
                       HTTP_PERM);
    if(!res)  { res = fu_lock_file(*fd); }
 
@@ -97,9 +98,9 @@ static void  http_uri_data_destructor(struct http_uri_data**  uri_data)
 {
    if(NULL != *uri_data)
    {
-      posix_free((void*) (*uri_data)->authority);
-      posix_free((void*) (*uri_data)->path);
-      posix_free((void*) *uri_data);
+      api_posix_free((void*) (*uri_data)->authority);
+      api_posix_free((void*) (*uri_data)->path);
+      api_posix_free((void*) *uri_data);
       *uri_data = NULL;
    }
 }
@@ -132,7 +133,7 @@ static int  http_uri_data_constructor(struct http_uri_data**  uri_data,
    size_t  len;
 
    *uri_data = (struct http_uri_data*)
-               posix_malloc(sizeof(struct http_uri_data));
+               api_posix_malloc(sizeof(struct http_uri_data));
    if(NULL != *uri_data)
    {
       (*uri_data)->authority = NULL;
@@ -147,7 +148,7 @@ static int  http_uri_data_constructor(struct http_uri_data**  uri_data,
          if(NULL != q)
          {
             len = (size_t) (q - p);
-            t = (char*) posix_malloc(len + (size_t) 1);
+            t = (char*) api_posix_malloc(len + (size_t) 1);
             if(NULL != t)
             {
                strncpy(t, p, len);
@@ -155,10 +156,10 @@ static int  http_uri_data_constructor(struct http_uri_data**  uri_data,
                (*uri_data)->authority = t;
                /* Extract path */
                len = strlen(q);
-               t = (char*) posix_malloc(len + (size_t) 1);
+               t = (char*) api_posix_malloc(len + (size_t) 1);
                if(NULL != t)
                {
-                  strncpy(t, q, len);
+                  memcpy(t, q, len);
                   t[len] = 0;
                   (*uri_data)->path = t;
                   res = 0;
@@ -197,7 +198,7 @@ static int  http_uri_data_constructor(struct http_uri_data**  uri_data,
 static int  http_connect(int*  sd, const char*  authority)
 {
    int  res = 0;
-   int  af = POSIX_AF_UNSPEC;
+   int  af = API_POSIX_AF_UNSPEC;
    const char*  host = authority;
    const char*  service = "www";
    const char*  p;
@@ -215,11 +216,11 @@ static int  http_connect(int*  sd, const char*  authority)
    {
       i = (size_t) (p - authority);
       len = strlen(authority);
-      q = (char*) posix_malloc(len + (size_t) 1);
+      q = (char*) api_posix_malloc(len + (size_t) 1);
       if(NULL == q)  { res = -1; }
       else
       {
-         strncpy(q, authority, len);
+         memcpy(q, authority, len);
          q[len] = 0;
          host = q;
          q[i] = 0;
@@ -253,7 +254,7 @@ static int  http_connect(int*  sd, const char*  authority)
       else  { res = -1; }
    }
 
-   if(NULL != q)  { posix_free((void*) q); }
+   if(NULL != q)  { api_posix_free((void*) q); }
 
    return(res);
 }
@@ -274,7 +275,7 @@ static int  http_connect(int*  sd, const char*  authority)
 static int  http_te_check(char*  resp_header)
 {
    int  res = 0;
-   posix_locale_t  lcp = 0;
+   api_posix_locale_t  lcp = 0;
    const char*  te_hfn = "Transfer-Encoding:";
    size_t  te_hfn_len = strlen(te_hfn);
    const char*  te_chunked = "chunked";
@@ -284,8 +285,9 @@ static int  http_te_check(char*  resp_header)
    size_t  i;
 
    /* Create a locale object with LC_CTYPE == POSIX */
-   lcp = posix_newlocale(POSIX_LC_CTYPE_MASK, "POSIX", (posix_locale_t) 0);
-   if((posix_locale_t) 0 == lcp)
+   lcp = api_posix_newlocale(API_POSIX_LC_CTYPE_MASK, "POSIX",
+                             (api_posix_locale_t) 0);
+   if((api_posix_locale_t) 0 == lcp)
    {
       PRINT_ERROR("Cannot create locale object");
       res = -1;
@@ -300,12 +302,13 @@ static int  http_te_check(char*  resp_header)
          if(NULL != p)
          {
             rh = p + 1;
-            if(!posix_strncasecmp_l(rh, te_hfn, te_hfn_len, lcp))
+            if(!api_posix_strncasecmp_l(rh, te_hfn, te_hfn_len, lcp))
             {
                /* "Transfer-Encoding" header field found */
                i = te_hfn_len;
                while(0x09 == (int) rh[i] || 0x20 == (int) rh[i])  { ++i; }
-               if(!posix_strncasecmp_l(&rh[i], te_chunked, te_chunked_len, lcp))
+               if(!api_posix_strncasecmp_l(&rh[i], te_chunked, te_chunked_len,
+                                           lcp))
                {
                   /*
                    * The "chunked" transfer encoding is defined as mandatory
@@ -327,7 +330,7 @@ static int  http_te_check(char*  resp_header)
    }
 
    /* Release memory allocated for locale object */
-   if((posix_locale_t) 0 != lcp)  { posix_freelocale(lcp); }
+   if((api_posix_locale_t) 0 != lcp)  { api_posix_freelocale(lcp); }
 
    return(res);
 }
@@ -351,7 +354,7 @@ static int  http_add_to_buffer(char**  buf, size_t*  l, const char*  line)
    size_t  len;
 
    len = strlen(line);
-   *buf = posix_realloc(*buf, *l + len);
+   *buf = api_posix_realloc(*buf, *l + len);
    if(NULL == buf)
    {
       PRINT_ERROR("Out of memory while adding data to buffer");
@@ -390,8 +393,8 @@ static int  http_get_tx(int  sd, struct http_uri_data*  uri_data)
    ssize_t  rv2;
 
    /* Prepare GET request */
-   rv = posix_snprintf(line, HTTP_LINE_MAX, "GET %s HTTP/1.1\r\n",
-                       uri_data->path);
+   rv = api_posix_snprintf(line, HTTP_LINE_MAX, "GET %s HTTP/1.1\r\n",
+                            uri_data->path);
    if(0 <= rv && HTTP_LINE_MAX - (size_t) 1 > (size_t) rv)
    {
       res = http_add_to_buffer(&buf, &l, line);
@@ -399,8 +402,8 @@ static int  http_get_tx(int  sd, struct http_uri_data*  uri_data)
    if(!res)
    {
       res = -1;
-      rv = posix_snprintf(line, HTTP_LINE_MAX, "Host: %s\r\n",
-                          uri_data->authority);
+      rv = api_posix_snprintf(line, HTTP_LINE_MAX, "Host: %s\r\n",
+                              uri_data->authority);
       if(0 <= rv && HTTP_LINE_MAX - (size_t) 1 > (size_t) rv)
       {
          res = http_add_to_buffer(&buf, &l, line);
@@ -409,7 +412,7 @@ static int  http_get_tx(int  sd, struct http_uri_data*  uri_data)
    if(!res)
    {
       res = -1;
-      rv = posix_snprintf(line, HTTP_LINE_MAX, "Connection: close\r\n");
+      rv = api_posix_snprintf(line, HTTP_LINE_MAX, "Connection: close\r\n");
       if(0 <= rv && HTTP_LINE_MAX - (size_t) 1 > (size_t) rv)
       {
          res = http_add_to_buffer(&buf, &l, line);
@@ -419,8 +422,8 @@ static int  http_get_tx(int  sd, struct http_uri_data*  uri_data)
    {
       res = -1;
       /* Accept cached results if they are not too old */
-      rv = posix_snprintf(line, HTTP_LINE_MAX,
-                          "Cache-Control: max-age=1800\r\n");
+      rv = api_posix_snprintf(line, HTTP_LINE_MAX,
+                              "Cache-Control: max-age=1800\r\n");
       if(0 <= rv && HTTP_LINE_MAX - (size_t) 1 > (size_t) rv)
       {
          res = http_add_to_buffer(&buf, &l, line);
@@ -437,10 +440,10 @@ static int  http_get_tx(int  sd, struct http_uri_data*  uri_data)
        * Legacy Netscape MIME types are accepted too (for backward
        * compatibility) but associated with lower quality factors.
        */
-      rv = posix_snprintf(line, HTTP_LINE_MAX,
-                          "Accept: application/pkix-crl, "
-                          "application/pkcs7-crl;q=0.8, "
-                          "application/x-pkcs7-crl;q=0.2\r\n");
+      rv = api_posix_snprintf(line, HTTP_LINE_MAX,
+                             "Accept: application/pkix-crl, "
+                             "application/pkcs7-crl;q=0.8, "
+                             "application/x-pkcs7-crl;q=0.2\r\n");
       if(0 <= rv && HTTP_LINE_MAX - (size_t) 1 > (size_t) rv)
       {
          res = http_add_to_buffer(&buf, &l, line);
@@ -450,7 +453,8 @@ static int  http_get_tx(int  sd, struct http_uri_data*  uri_data)
    if(!res)
    {
       res = -1;
-      rv = posix_snprintf(line, HTTP_LINE_MAX, "Accept-Encoding: identity\r\n");
+      rv = api_posix_snprintf(line, HTTP_LINE_MAX,
+                              "Accept-Encoding: identity\r\n");
       if(0 <= rv && HTTP_LINE_MAX - (size_t) 1 > (size_t) rv)
       {
          res = http_add_to_buffer(&buf, &l, line);
@@ -459,8 +463,8 @@ static int  http_get_tx(int  sd, struct http_uri_data*  uri_data)
    if(!res)
    {
       res = -1;
-      rv = posix_snprintf(line, HTTP_LINE_MAX, "User-Agent: %s/%s\r\n",
-                          CFG_NAME, CFG_VERSION);
+      rv = api_posix_snprintf(line, HTTP_LINE_MAX, "User-Agent: %s/%s\r\n",
+                              CFG_NAME, CFG_VERSION);
       if(0 <= rv && HTTP_LINE_MAX - (size_t) 1 > (size_t) rv)
       {
          res = http_add_to_buffer(&buf, &l, line);
@@ -469,7 +473,7 @@ static int  http_get_tx(int  sd, struct http_uri_data*  uri_data)
    if(!res)
    {
       res = -1;
-      rv = posix_snprintf(line, HTTP_LINE_MAX, "\r\n");
+      rv = api_posix_snprintf(line, HTTP_LINE_MAX, "\r\n");
       if(0 <= rv && HTTP_LINE_MAX - (size_t) 1 > (size_t) rv)
       {
          res = http_add_to_buffer(&buf, &l, line);
@@ -489,8 +493,8 @@ static int  http_get_tx(int  sd, struct http_uri_data*  uri_data)
       i = 0;
       while(i < len)
       {
-         do  { rv2 = posix_send(sd, &buf[i], len - i, 0); }
-         while((ssize_t) -1 == rv2 && POSIX_EINTR == posix_errno);
+         do  { rv2 = api_posix_send(sd, &buf[i], len - i, 0); }
+         while((ssize_t) -1 == rv2 && API_POSIX_EINTR == api_posix_errno);
          if((ssize_t) -1 == rv2)
          {
             PRINT_ERROR("Failed to send GET request");
@@ -502,7 +506,7 @@ static int  http_get_tx(int  sd, struct http_uri_data*  uri_data)
    }
 
    /* Release memory for request buffer */
-   posix_free((void*) buf);
+   api_posix_free((void*) buf);
 
    return(res);
 }
@@ -531,10 +535,9 @@ static int  http_get_rx_header(struct http_status*  sc, int  sd, int*  cte)
    size_t  len = 512;  /* Length of buffer at address 'resp' */
    size_t  ri = 0;  /* Index for received data */
    size_t  pi;  /* Index for peek (look ahead) data */
-   posix_ssize_t  rv;
+   api_posix_ssize_t  rv;
    size_t  i;
    char*  p;
-   size_t  lines = 0;
    int  df[3] = { 100, 10, 1 };  /* Decimal digit factors */
 
    /*
@@ -543,7 +546,7 @@ static int  http_get_rx_header(struct http_status*  sc, int  sd, int*  cte)
     * We allocate 512Byte at the beginning and expontially increase the size
     * if required.
     */
-   resp = (char*) posix_malloc(len);
+   resp = (char*) api_posix_malloc(len);
    if(NULL == resp)
    {
       PRINT_ERROR("Out of memory while receiving response");
@@ -557,8 +560,11 @@ static int  http_get_rx_header(struct http_status*  sc, int  sd, int*  cte)
       {
          /* Peek into next block of input */
          pi = ri;
-         do  { rv = posix_recv(sd, &resp[ri], len - ri, POSIX_MSG_PEEK); }
-         while(-1 == rv && POSIX_EINTR == posix_errno);
+         do
+         {
+            rv = api_posix_recv(sd, &resp[ri], len - ri, API_POSIX_MSG_PEEK);
+         }
+         while(-1 == rv && API_POSIX_EINTR == api_posix_errno);
          if(-1 == rv)
          {
             PRINT_ERROR("Reading from socket failed");
@@ -574,7 +580,6 @@ static int  http_get_rx_header(struct http_status*  sc, int  sd, int*  cte)
             /* Check for EOL */
             if('\n' == resp[i])
             {
-               ++lines;
                if(1 == i && '\r' == resp[i - 1])
                {
                   /* Empty header */
@@ -597,14 +602,13 @@ static int  http_get_rx_header(struct http_status*  sc, int  sd, int*  cte)
          if(eoh)
          {
             ++i;
-            --lines;
          }
          /* 'i' now points behind last character of empty separation line */
          /* Read next block of input (up to but not including index 'i') */
          while(i > ri)
          {
-            do  { rv = posix_recv(sd, &resp[ri], i - ri, 0); }
-            while(-1 == rv && POSIX_EINTR == posix_errno);
+            do  { rv = api_posix_recv(sd, &resp[ri], i - ri, 0); }
+            while(-1 == rv && API_POSIX_EINTR == api_posix_errno);
             if(-1 == rv)
             {
                PRINT_ERROR("Reading from socket failed");
@@ -619,7 +623,7 @@ static int  http_get_rx_header(struct http_status*  sc, int  sd, int*  cte)
       if(!res && !eoh)
       {
          len *= 2;
-         p = (char*) posix_realloc(resp, len);
+         p = (char*) api_posix_realloc(resp, len);
          if(NULL == p)
          {
             PRINT_ERROR("Out of memory while receiving response");
@@ -675,7 +679,7 @@ static int  http_get_rx_header(struct http_status*  sc, int  sd, int*  cte)
          }
       }
    }
-   posix_free((void*) resp);
+   api_posix_free((void*) resp);
 
    return(res);
 }
@@ -696,7 +700,7 @@ static int  http_get_chunk_size(size_t*  cs, int  sd)
 {
    int  res = 0;
    char  line[HTTP_LINE_MAX];
-   posix_ssize_t  rv;
+   api_posix_ssize_t  rv;
    size_t  i = 0;
    unsigned long int  value;
 
@@ -704,8 +708,8 @@ static int  http_get_chunk_size(size_t*  cs, int  sd)
    do
    {
       if(HTTP_LINE_MAX <= i)  { res = -1;  break; }
-      do  { rv = posix_recv(sd, &line[i], 1, 0); }
-      while(-1 == rv && POSIX_EINTR == posix_errno);
+      do  { rv = api_posix_recv(sd, &line[i], 1, 0); }
+      while(-1 == rv && API_POSIX_EINTR == api_posix_errno);
       if(0 > rv)
       {
          res = -1;
@@ -721,7 +725,7 @@ static int  http_get_chunk_size(size_t*  cs, int  sd)
       if(1 != res)  { res = -1; }
       else
       {
-         if((unsigned long int) POSIX_UINT_MAX < value)  { res = -1; }
+         if((unsigned long int) API_POSIX_UINT_MAX < value)  { res = -1; }
          else
          {
             *cs = (size_t) value;
@@ -754,7 +758,7 @@ static int  http_get_chunk_size(size_t*  cs, int  sd)
 static int  http_get_rx_body(int  fd, int  sd, int  cte)
 {
    int  res = 0;
-   posix_ssize_t  rv;
+   api_posix_ssize_t  rv;
    char*  chunk = NULL;
    size_t  chunk_size = 4096;
    size_t  len;
@@ -764,13 +768,13 @@ static int  http_get_rx_body(int  fd, int  sd, int  cte)
    if(!cte)
    {
       /* No transfer encoding */
-      chunk = (char*) posix_malloc(chunk_size);
+      chunk = (char*) api_posix_malloc(chunk_size);
       if(NULL == chunk)  { res = -1; }
       while(!res)
       {
          /* Read data from socket */
-         do  { rv = posix_recv(sd, chunk, chunk_size, 0); }
-         while(-1 == rv && POSIX_EINTR == posix_errno);
+         do  { rv = api_posix_recv(sd, chunk, chunk_size, 0); }
+         while(-1 == rv && API_POSIX_EINTR == api_posix_errno);
          if(0 > rv)
          {
             PRINT_ERROR("Reading from socket failed");
@@ -795,7 +799,7 @@ static int  http_get_rx_body(int  fd, int  sd, int  cte)
          else if(chunk_size)
          {
             /* Reallocate buffer for next chunk */
-            p = (char*) posix_realloc(chunk, chunk_size);
+            p = (char*) api_posix_realloc(chunk, chunk_size);
             if(NULL == p)  { res = -1; }
             else
             {
@@ -805,8 +809,11 @@ static int  http_get_rx_body(int  fd, int  sd, int  cte)
                while(chunk_size > len)
                {
                   /* Read data from socket */
-                  do  { rv = posix_recv(sd, &chunk[len], chunk_size - len, 0); }
-                  while(-1 == rv && POSIX_EINTR == posix_errno);
+                  do 
+                  {
+                     rv = api_posix_recv(sd, &chunk[len], chunk_size - len, 0);
+                  }
+                  while(-1 == rv && API_POSIX_EINTR == api_posix_errno);
                   if(0 >= rv)
                   {
                      PRINT_ERROR("Reading from socket failed");
@@ -828,8 +835,8 @@ static int  http_get_rx_body(int  fd, int  sd, int  cte)
                len = 0;
                while(2 > len)
                {
-                  do  { rv = posix_recv(sd, &crlf[len], 2 - len, 0); }
-                  while(-1 == rv && POSIX_EINTR == posix_errno);
+                  do  { rv = api_posix_recv(sd, &crlf[len], 2 - len, 0); }
+                  while(-1 == rv && API_POSIX_EINTR == api_posix_errno);
                   if(0 >= rv)
                   {
                      PRINT_ERROR("Reading from socket failed");
@@ -850,7 +857,7 @@ static int  http_get_rx_body(int  fd, int  sd, int  cte)
    }
 
    /* Release memory allocated for buffer */
-   posix_free((void*) chunk);
+   api_posix_free((void*) chunk);
 
    return(res);
 }
