@@ -10,7 +10,7 @@
 /* Constants */
 
 /*! \brief Number of entries in global configuration array */
-#define CONF_NUM  57
+#define CONF_NUM  59
 
 
 /* ========================================================================== */
@@ -82,10 +82,12 @@ enum conf_entry
    CONF_UNREAD_IN_NEXT_GROUP = 50, /*!< Skip to next group for unread article */
    CONF_COLOR_SIGNATURE = 51,      /*!< Signature color */
    CONF_COLOR_EXTERNAL = 52,       /*!< External citation color */
-   CONF_COLOR_LEVEL1 = 53,         /*!< Citation color level 1 */
-   CONF_COLOR_LEVEL2 = 54,         /*!< Citation color level 2 */
-   CONF_COLOR_LEVEL3 = 55,         /*!< Citation color level 3 */
-   CONF_COLOR_LEVEL4 = 56          /*!< Citation color level 4 */
+   CONF_COLOR_HYPERLINK = 53,      /*!< Color for hyperlink */
+   CONF_COLOR_LEVEL1 = 54,         /*!< Citation color level 1 */
+   CONF_COLOR_LEVEL2 = 55,         /*!< Citation color level 2 */
+   CONF_COLOR_LEVEL3 = 56,         /*!< Citation color level 3 */
+   CONF_COLOR_LEVEL4 = 57,         /*!< Citation color level 4 */
+   CONF_SCORE_KILL_TH = 58         /*!< Kill threshold (negative score value) */
    /* !!! Set 'CONF_NUM' above to the first unused value !!! */
 };
 
