@@ -6,7 +6,7 @@
 /* Function prototypes */
 
 int  ext_handler_email(const char*, const char*, const char*);
-int  ext_handler_uri(const char*);
+int  ext_handler_uri(const char*, int*);
 int  ext_editor(const char*, int, ...);
 int  ext_editor_status(long int);
 void  ext_editor_terminate(long int);
