@@ -6,9 +6,9 @@
 /* Function prototypes */
 
 int  fu_check_path(const char*);
-int  fu_create_path(const char*, posix_mode_t);
-int  fu_check_file(const char*, struct_posix_stat*);
-int  fu_open_file(const char*, int*, int, posix_mode_t);
+int  fu_create_path(const char*, api_posix_mode_t);
+int  fu_check_file(const char*, api_posix_struct_stat*);
+int  fu_open_file(const char*, int*, int, api_posix_mode_t);
 void  fu_close_file(int*, FILE**);
 int  fu_lock_file(int);
 int  fu_unlink_file(const char*);
