@@ -16,7 +16,7 @@
 /* Macros */
 
 /*! \brief Prepend module prefix and print error message */
-#define PRINT_ERROR(s)  { print_error(MAIN_ERR_PREFIX s); }
+#define PRINT_ERROR(s)  print_error(MAIN_ERR_PREFIX s)
 
 
 /*! @} */
