@@ -13,7 +13,7 @@
 #define TEST_TAB  "   "
 
 /*! \brief Permissions for test files */
-#define TEST_PERM  (posix_mode_t) (POSIX_S_IRUSR | POSIX_S_IWUSR)
+#define TEST_PERM  (api_posix_mode_t) (API_POSIX_S_IRUSR | API_POSIX_S_IWUSR)
 
 
 /*! @} */
