@@ -25,8 +25,8 @@ int  tls_close(void**);
 int  tls_get_ciphersuite(void**, const char**, const char**, const char**);
 int  tls_cert_verify(void**, void**, const char*, int);
 int  tls_cert_get_string(void*, const char**);
-posix_ssize_t  tls_send(void*, const void*, size_t);
-posix_ssize_t  tls_recv(void*, void*, size_t, int);
+api_posix_ssize_t  tls_send(void*, const void*, size_t);
+api_posix_ssize_t  tls_recv(void*, void*, size_t, int);
 void  tls_free(void*);
 
 
