@@ -2,7 +2,7 @@
 /*! \file
  * \brief Internet connection handling
  *
- * Copyright (c) 2015-2022 by the developers. See the LICENSE file for details.
+ * Copyright (c) 2015-2024 by the developers. See the LICENSE file for details.
  *
  * If nothing else is specified, functions return zero to indicate success
  * and a negative value to indicate an error.
@@ -56,7 +56,7 @@ int  inet_force_ipv4 = 0;
  * \param[in]  af       Address family
  * \param[out] sai      Pointer to socket address information
  *
- * The parameter \e af should be set to \c POSIX_AF_UNSPEC except if only
+ * The parameter \e af should be set to \c API_POSIX_AF_UNSPEC except if only
  * results for a specific address family should be requested.
  *
  * \note
@@ -65,7 +65,7 @@ int  inet_force_ipv4 = 0;
  *
  * \note
  * On success the caller is responsible to free the ressources allocated by this
- * function using \c posix_freeaddrinfo() .
+ * function using \c api_posix_freeaddrinfo() .
  *
  * \return
  * - Zero if connection was successfully established
@@ -73,10 +73,10 @@ int  inet_force_ipv4 = 0;
  */
 
 static int  inet_name_resolver(const char*  host, const char*  service,
-                               int  af, struct_posix_addrinfo**  sai)
+                               int  af, api_posix_struct_addrinfo**  sai)
 {
    int  res = 0;
-   struct_posix_addrinfo  hints;
+   api_posix_struct_addrinfo  hints;
    int  rv;
    const char*  err_str;
    char*  ebuf = NULL;
@@ -84,33 +84,40 @@ static int  inet_name_resolver(const char*  host, const char*  service,
 
    memset((void*) &hints, 0, sizeof(hints));
    /* Only return results for address families configured on local system */
-   hints.ai_flags = POSIX_AI_ADDRCONFIG;
+   hints.ai_flags = API_POSIX_AI_ADDRCONFIG;
    hints.ai_family = af;
-   hints.ai_socktype = POSIX_SOCK_STREAM;
+   hints.ai_socktype = API_POSIX_SOCK_STREAM;
    hints.ai_protocol = 0;
-   rv = posix_getaddrinfo(host, service, &hints, sai);
+   rv = api_posix_getaddrinfo(host, service, &hints, sai);
    if(rv)
    {
       PRINT_ERROR("getaddrinfo() failed");
-      err_str = posix_gai_strerror(rv);
+#if CFG_USE_POSIX_API >= 200112 || CFG_USE_XSI
+      /* Don't use NLS for error messages on stderr */
+      api_posix_setlocale(API_POSIX_LC_MESSAGES, "POSIX");
+#endif  /* CFG_USE_POSIX_API >= 200112 || CFG_USE_XSI */
+      err_str = api_posix_gai_strerror(rv);
+#if CFG_USE_POSIX_API >= 200112 || CFG_USE_XSI
+      api_posix_setlocale(API_POSIX_LC_MESSAGES, "");
+#endif  /* CFG_USE_POSIX_API >= 200112 || CFG_USE_XSI */
       if(NULL != err_str)
       {
          len = strlen(MAIN_ERR_PREFIX);
          len += strlen(err_str);
-         ebuf = (char*) posix_malloc(++len);
+         ebuf = (char*) api_posix_malloc(++len);
          if(NULL != ebuf)
          {
             strcpy(ebuf, MAIN_ERR_PREFIX);
             strcat(ebuf, err_str);
             print_error(ebuf);
          }
-         posix_free((void*) ebuf);
+         api_posix_free((void*) ebuf);
       }
       switch(rv)
       {
-         case POSIX_EAI_FAMILY:  { res = INET_ERR_AF;  break; }
-         case POSIX_EAI_NONAME:  { res = INET_ERR_HNR;  break; }
-         case POSIX_EAI_SERVICE:  { res = INET_ERR_SNR;  break; }
+         case API_POSIX_EAI_FAMILY:  { res = INET_ERR_AF;  break; }
+         case API_POSIX_EAI_NONAME:  { res = INET_ERR_HNR;  break; }
+         case API_POSIX_EAI_SERVICE:  { res = INET_ERR_SNR;  break; }
          default:  { res = INET_ERR_UNSPEC;  break; }
       }
    }
@@ -125,7 +132,8 @@ static int  inet_name_resolver(const char*  host, const char*  service,
  * \param[out] sd  Pointer to socket descriptor
  * \param[in]  af  Address family
  *
- * The value for \e af must be \c POSIX_INET or \c POSIX_INET6 respectively.
+ * The value for \e af must be \c API_POSIX_INET or \c API_POSIX_INET6
+ * respectively.
  *
  * \note
  * The value -1 is written to the location pointed to by \e sd on error.
@@ -140,9 +148,9 @@ static int  inet_socket_create(int*  sd, int  af)
    int  res = 0;
    int  rv;
 
-   if(POSIX_AF_INET != af
+   if(API_POSIX_AF_INET != af
 #if CFG_USE_IP6
-      && POSIX_AF_INET6 != af
+      && API_POSIX_AF_INET6 != af
 #endif  /* CFG_USE_IP6 */
      )
    {
@@ -151,7 +159,7 @@ static int  inet_socket_create(int*  sd, int  af)
    }
    else
    {
-      *sd = posix_socket(af, POSIX_SOCK_STREAM, 0);
+      *sd = api_posix_socket(af, API_POSIX_SOCK_STREAM, 0);
       if(0 > *sd)
       {
          PRINT_ERROR("socket() failed");
@@ -161,8 +169,11 @@ static int  inet_socket_create(int*  sd, int  af)
       else
       {
          /* Set "Close on exec()" flag */
-         do  { rv = posix_fcntl(*sd, POSIX_F_SETFD, POSIX_FD_CLOEXEC); }
-         while(-1 == rv && POSIX_EINTR == posix_errno);
+         do
+         {
+            rv = api_posix_fcntl(*sd, API_POSIX_F_SETFD, API_POSIX_FD_CLOEXEC);
+         }
+         while(-1 == rv && API_POSIX_EINTR == api_posix_errno);
          if(-1 == rv)
          {
             PRINT_ERROR("fcntl() failed");
@@ -196,8 +207,8 @@ static int  inet_socket_options(int  sd, int  action, int  opts)
    int  opts_new;
 
    /* Get socket options */
-   do  { rv = posix_fcntl(sd, POSIX_F_GETFL); }
-   while(-1 == rv && POSIX_EINTR == posix_errno);
+   do  { rv = api_posix_fcntl(sd, API_POSIX_F_GETFL); }
+   while(-1 == rv && API_POSIX_EINTR == api_posix_errno);
    if(-1 == rv)
    {
       PRINT_ERROR("fcntl() failed");
@@ -211,8 +222,8 @@ static int  inet_socket_options(int  sd, int  action, int  opts)
       else  { opts_new = rv & ~opts; }
 
       /* Set socket options */
-      do  { rv = posix_fcntl(sd, POSIX_F_SETFL, opts_new); }
-      while(-1 == rv && POSIX_EINTR == posix_errno);
+      do  { rv = api_posix_fcntl(sd, API_POSIX_F_SETFL, opts_new); }
+      while(-1 == rv && API_POSIX_EINTR == api_posix_errno);
       if(-1 == rv)
       {
          PRINT_ERROR("fcntl() failed");
@@ -235,8 +246,8 @@ static int  inet_socket_options(int  sd, int  action, int  opts)
  *
  * On success the socket descriptor of the established connection is written to
  * the location pointed to by \e sd . If the address family was specified as
- * \c POSIX_AF_UNSPEC or was enforced by configuration, it is overwritten with
- * the address family that was used to establish the connection.
+ * \c API_POSIX_AF_UNSPEC or was enforced by configuration, it is overwritten
+ * with the address family that was used to establish the connection.
  *
  * On error -1 is written to the location pointed to by \e sd and the value
  * pointed to by \e af is unchanged.
@@ -255,14 +266,14 @@ int  inet_connect(int*  sd, int*  af, const char*  host, const char*  service)
 {
    int  res;
    int  rv;
-   struct_posix_addrinfo*  sai;
-   struct_posix_addrinfo*  saie;
+   api_posix_struct_addrinfo*  sai;
+   api_posix_struct_addrinfo*  saie;
    int  family;
    int  socket;
-   struct_posix_pollfd  fds[1];
-   posix_socklen_t  opt_len;
+   api_posix_struct_pollfd  fds[1];
+   api_posix_socklen_t  opt_len;
 #if CFG_USE_CONNECT_TIMEOUT
-   posix_time_t  ts1, ts2, ts_diff;
+   api_posix_time_t  ts1 = 0, ts2, ts_diff;
 #endif
    int  timeout;
    int  timed_out = 0;
@@ -271,7 +282,7 @@ int  inet_connect(int*  sd, int*  af, const char*  host, const char*  service)
    *sd = -1;
 
    /* Override address family on request */
-   if(inet_force_ipv4)  { *af = POSIX_AF_INET; }
+   if(inet_force_ipv4)  { *af = API_POSIX_AF_INET; }
 
    /* Resolve host and service names */
    res = inet_name_resolver(host, service, *af, &sai);
@@ -286,10 +297,11 @@ int  inet_connect(int*  sd, int*  af, const char*  host, const char*  service)
          if(!res)
          {
             /* Configure socket to nonblocking mode */
-            res = inet_socket_options(socket, INET_OPTS_SET, POSIX_O_NONBLOCK);
+            res = inet_socket_options(socket, INET_OPTS_SET,
+                                      API_POSIX_O_NONBLOCK);
             /* Store timestamp */
-            ts1 = posix_time(NULL);
-            if((posix_time_t) 0 > ts1)  { ts1 = 0; }
+            ts1 = api_posix_time(NULL);
+            if((api_posix_time_t) 0 > ts1)  { ts1 = 0; }
          }
 #endif
          if(!res)
@@ -297,14 +309,15 @@ int  inet_connect(int*  sd, int*  af, const char*  host, const char*  service)
             /* Try to establish connection */
             refused = 0;
             timed_out = 0;
-            rv = posix_connect(socket, saie->ai_addr, saie->ai_addrlen);
+            rv = api_posix_connect(socket, saie->ai_addr, saie->ai_addrlen);
             if(rv)
             {
-               if(POSIX_ECONNREFUSED == posix_errno)  { refused = 1; }
+               if(API_POSIX_ECONNREFUSED == api_posix_errno)  { refused = 1; }
                res = INET_ERR_CONN;
             }
             if(-1 == rv &&
-               (POSIX_EINPROGRESS == posix_errno || POSIX_EINTR == posix_errno))
+               (API_POSIX_EINPROGRESS == api_posix_errno
+                || API_POSIX_EINTR == api_posix_errno))
             {
                /*
                 * Interrupted by signal (or nonblocking mode)
@@ -316,8 +329,8 @@ int  inet_connect(int*  sd, int*  af, const char*  host, const char*  service)
 #if CFG_USE_CONNECT_TIMEOUT
                   timeout = 500;  /* Milliseconds */
                   /* Timeout will be aborted/restartet by signals */
-                  ts2 = posix_time(NULL);
-                  if((posix_time_t) 0 > ts2)  { ts2 = 0; }
+                  ts2 = api_posix_time(NULL);
+                  if((api_posix_time_t) 0 > ts2)  { ts2 = 0; }
                   ts_diff = ts2 - ts1;
                   if ((float) CFG_USE_CONNECT_TIMEOUT < (float) ts_diff)
                   {
@@ -326,18 +339,19 @@ int  inet_connect(int*  sd, int*  af, const char*  host, const char*  service)
                   }
 #endif
                   fds[0].fd = socket;
-                  fds[0].events = POSIX_POLLOUT;
+                  fds[0].events = API_POSIX_POLLOUT;
                   fds[0].revents = 0;
-                  rv = posix_poll(fds, 1, timeout);
+                  rv = api_posix_poll(fds, 1, timeout);
                }
-               while(0 == rv || (-1 == rv && POSIX_EINTR == posix_errno));
+               while(0 == rv ||
+                     (-1 == rv && API_POSIX_EINTR == api_posix_errno));
                if(0 == rv) { timed_out = 1; }
                else if(1 == rv)
                {
                   /* Get return value of 'connect()' */
                   opt_len = sizeof(int);
-                  rv = posix_getsockopt(socket, POSIX_SOL_SOCKET,
-                                        POSIX_SO_ERROR, &res, &opt_len);
+                  rv = api_posix_getsockopt(socket, API_POSIX_SOL_SOCKET,
+                                            API_POSIX_SO_ERROR, &res, &opt_len);
                   if(-1 == rv || res)  { res = INET_ERR_CONN; }
                }
             }
@@ -347,7 +361,7 @@ int  inet_connect(int*  sd, int*  af, const char*  host, const char*  service)
          {
             /* Configure socket to blocking mode */
             res = inet_socket_options(socket, INET_OPTS_CLEAR,
-                                      POSIX_O_NONBLOCK);
+                                      API_POSIX_O_NONBLOCK);
          }
 #endif
 
@@ -366,13 +380,13 @@ int  inet_connect(int*  sd, int*  af, const char*  host, const char*  service)
          else
          {
             /* Connection established */
-            if(POSIX_AF_INET == family)
+            if(API_POSIX_AF_INET == family)
             {
                printf("%s: %s%s\n", CFG_NAME, MAIN_ERR_PREFIX,
                       "Using IPv4 protocol");
             }
 #if CFG_USE_IP6
-            else if(POSIX_AF_INET6 == family)
+            else if(API_POSIX_AF_INET6 == family)
             {
                printf("%s: %s%s\n", CFG_NAME, MAIN_ERR_PREFIX,
                       "Using IPv6 protocol");
@@ -384,7 +398,7 @@ int  inet_connect(int*  sd, int*  af, const char*  host, const char*  service)
          }
       }
       /* Release ressources allocated by name resolver */
-      posix_freeaddrinfo(sai);
+      api_posix_freeaddrinfo(sai);
    }
 
    return(res);
@@ -420,23 +434,28 @@ int  inet_set_rx_timeout(int  sd, unsigned int  rx_to)
 {
    int res = INET_ERR_BADF;
    int  rv;
-   struct_posix_timeval  rx;
+   api_posix_struct_timeval  rx;
 
    if(-1 != sd)
    {
       if(3600U >= rx_to)
       {
-         rx.tv_sec = (posix_time_t) rx_to;
+         rx.tv_sec = (api_posix_time_t) rx_to;
          rx.tv_usec = 0;
-         rv = posix_setsockopt(sd, POSIX_SOL_SOCKET, POSIX_SO_RCVTIMEO,
-                               (void*) &rx,
-                               (posix_socklen_t) sizeof(struct_posix_timeval));
+         rv = api_posix_setsockopt(sd, API_POSIX_SOL_SOCKET,
+                                   API_POSIX_SO_RCVTIMEO, (void*) &rx,
+                                   (api_posix_socklen_t)
+                                   sizeof(api_posix_struct_timeval));
          if(-1 == rv)
          {
             PRINT_ERROR("setsockopt() failed for RX timeout");
-            if(POSIX_EINVAL == posix_errno)  { res = INET_ERR_RX_TO; }
-            if(POSIX_ENOPROTOOPT == posix_errno)  { res = INET_ERR_RX_TO; }
-            if(POSIX_EBADF != posix_errno && POSIX_ENOTSOCK != errno)
+            if(API_POSIX_EINVAL == api_posix_errno)  { res = INET_ERR_RX_TO; }
+            if(API_POSIX_ENOPROTOOPT == api_posix_errno)
+            {
+               res = INET_ERR_RX_TO;
+            }
+            if(API_POSIX_EBADF != api_posix_errno
+               && API_POSIX_ENOTSOCK != errno)
             {
                res = INET_ERR_UNSPEC;
             }
@@ -478,23 +497,28 @@ int  inet_set_tx_timeout(int  sd, unsigned int  tx_to)
 {
    int res = INET_ERR_BADF;
    int  rv;
-   struct_posix_timeval  tx;
+   api_posix_struct_timeval  tx;
 
    if(-1 != sd)
    {
       if(3600U >= tx_to)
       {
-         tx.tv_sec = (posix_time_t) tx_to;
+         tx.tv_sec = (api_posix_time_t) tx_to;
          tx.tv_usec = 0;
-         rv = posix_setsockopt(sd, POSIX_SOL_SOCKET, POSIX_SO_SNDTIMEO,
-                               (void*) &tx,
-                               (posix_socklen_t) sizeof(struct_posix_timeval));
+         rv = api_posix_setsockopt(sd, API_POSIX_SOL_SOCKET,
+                                   API_POSIX_SO_SNDTIMEO, (void*) &tx,
+                                   (api_posix_socklen_t)
+                                   sizeof(api_posix_struct_timeval));
          if(-1 == rv)
          {
             PRINT_ERROR("setsockopt() failed for TX timeout");
-            if(POSIX_EINVAL == posix_errno)  { res = INET_ERR_TX_TO; }
-            if(POSIX_ENOPROTOOPT == posix_errno)  { res = INET_ERR_TX_TO; }
-            if(POSIX_EBADF != posix_errno && POSIX_ENOTSOCK != errno)
+            if(API_POSIX_EINVAL == api_posix_errno)  { res = INET_ERR_TX_TO; }
+            if(API_POSIX_ENOPROTOOPT == api_posix_errno)
+            {
+               res = INET_ERR_TX_TO;
+            }
+            if(API_POSIX_EBADF != api_posix_errno
+               && API_POSIX_ENOTSOCK != errno)
             {
                res = INET_ERR_UNSPEC;
             }
@@ -525,7 +549,7 @@ void  inet_close(int*  sd)
 {
    if(-1 != *sd)
    {
-      posix_close(*sd);
+      api_posix_close(*sd);
       *sd = -1;
    }
 }
