@@ -2,7 +2,7 @@
 /*! \file
  * \brief Server protocol logging
  *
- * Copyright (c) 2012-2020 by the developers. See the LICENSE file for details.
+ * Copyright (c) 2012-2024 by the developers. See the LICENSE file for details.
  * If nothing else is specified, functions return zero to indicate success
  * and a negative value to indicate an error.
  */
@@ -38,7 +38,7 @@
 #define MAIN_ERR_PREFIX  "LOG: "
 
 /*! \brief Permissions for server protocol logfile */
-#define LOG_PERM  (posix_mode_t) (POSIX_S_IRUSR | POSIX_S_IWUSR)
+#define LOG_PERM  (api_posix_mode_t) (API_POSIX_S_IRUSR | API_POSIX_S_IWUSR)
 
 
 /* ========================================================================== */
@@ -62,14 +62,14 @@ const char*  log_get_logpathname(void)
    res = xdg_get_confdir(CFG_NAME);
    if(NULL != res)
    {
-      rv = fu_create_path(res, (posix_mode_t) POSIX_S_IRWXU);
+      rv = fu_create_path(res, (api_posix_mode_t) API_POSIX_S_IRWXU);
       if(0 == rv)
       {
          /* Store scorefile pathname */
          rv = xdg_append_to_path(&res, logname);
          if(0 != rv)
          {
-            posix_free((void*) res);
+            api_posix_free((void*) res);
             res = NULL;
          }
       }
@@ -89,7 +89,7 @@ void  log_delete_logfile(void)
    if(NULL != lfpn)
    {
       (void) fu_unlink_file(lfpn);
-      posix_free((void*) lfpn);
+      api_posix_free((void*) lfpn);
    }
 }
 
@@ -122,7 +122,9 @@ int  log_open_logfile(FILE**  lfs, const char*  logfile)
 
    /* Open logfile */
    res = fu_open_file(logfile, &fd,
-                      POSIX_O_WRONLY | POSIX_O_CREAT | POSIX_O_TRUNC, LOG_PERM);
+                      API_POSIX_O_WRONLY | API_POSIX_O_CREAT
+                      | API_POSIX_O_TRUNC,
+                      LOG_PERM);
    if(res)
    {
       PRINT_ERROR("Opening logfile failed");
@@ -199,7 +201,7 @@ void  log_add(FILE*  lfs, const char*  data)
 
 void  log_free(void*  p)
 {
-   posix_free(p);
+   api_posix_free(p);
 }
 
 
