@@ -2,7 +2,7 @@
 /*! \file
  * \brief Security related functions
  *
- * Copyright (c) 2017-2020 by the developers. See the LICENSE file for details.
+ * Copyright (c) 2017-2024 by the developers. See the LICENSE file for details.
  * If nothing else is specified, functions return zero to indicate success
  * and a negative value to indicate an error.
  *
@@ -38,7 +38,8 @@
 /* Constants */
 
 /*! \brief Permissions for Cancel-Lock secret file */
-#define SECURE_CL_PERM  (posix_mode_t) (POSIX_S_IRUSR | POSIX_S_IWUSR)
+#define SECURE_CL_PERM  \
+   (api_posix_mode_t) (API_POSIX_S_IRUSR | API_POSIX_S_IWUSR)
 
 /*! \brief Size of secret (64 octets is sufficient for the SHA2 family) */
 #define SECURE_CL_SECSIZE  (size_t) 64
@@ -145,12 +146,13 @@ void  secure_cl_secret(const char*  pathname)
    if(NULL != pathname)
    {
       rv = fu_check_file(pathname, NULL);
-      if(-1 == rv && POSIX_ENOENT == posix_errno)
+      if(-1 == rv && API_POSIX_ENOENT == api_posix_errno)
       {
          /* CL secret file for scheme SHA256 not present */
          printf("%s: %s%s\n", CFG_NAME, MAIN_ERR_PREFIX,
                 "Generate CL secret for scheme SHA256");
-         rv = fu_open_file(pathname, &fd, POSIX_O_WRONLY | POSIX_O_CREAT,
+         rv = fu_open_file(pathname, &fd,
+                           API_POSIX_O_WRONLY | API_POSIX_O_CREAT,
                            SECURE_CL_PERM);
          if(rv)  { PRINT_ERROR("Creation of CL secret file failed"); }
          else
