@@ -2,7 +2,7 @@
 /*! \file
  * \brief Test of \c enc_mime_encode_base64() implementation
  *
- * Copyright (c) 2012-2022 by the developers. See the LICENSE file for details.
+ * Copyright (c) 2012-2024 by the developers. See the LICENSE file for details.
  */
 
 
@@ -52,7 +52,7 @@ int  test_base64(void)
       "VGhpcyBpcyBhIHRlc3QhISE=",
       "MDEyMzQ1Njc4OS4wMTIzNDU2Nzg5LjAwMDAwMDAw"
    };
-   int  res = POSIX_EXIT_SUCCESS;
+   int  res = API_POSIX_EXIT_SUCCESS;
    int  rv;
    size_t  i;
    const char*  buf = NULL;
@@ -63,7 +63,7 @@ int  test_base64(void)
       if(rv)
       {
          print_error("Base64 encoder failed");
-         res = POSIX_EXIT_FAILURE;
+         res = API_POSIX_EXIT_FAILURE;
          break;
       }
       if(strcmp(rs[i], buf))
@@ -73,7 +73,7 @@ int  test_base64(void)
          fprintf(stderr, TEST_TAB "Input data: \"%s\"\n", ts[i]);
          fprintf(stderr, TEST_TAB "Result is : \"%s\"\n", buf);
          fprintf(stderr, TEST_TAB "Should be : \"%s\"\n", rs[i]);
-         res = POSIX_EXIT_FAILURE;
+         res = API_POSIX_EXIT_FAILURE;
          break;
       }
       enc_free((void*) buf);
