@@ -2,7 +2,7 @@
 /*! \file
  * \brief Test of \c core_get_cancel_lock() implementation
  *
- * Copyright (c) 2015-2022 by the developers. See the LICENSE file for details.
+ * Copyright (c) 2015-2024 by the developers. See the LICENSE file for details.
  */
 
 
@@ -57,7 +57,7 @@ int  test_cancellock(void)
       "Secret3"
    };
 
-   int  res = POSIX_EXIT_SUCCESS;
+   int  res = API_POSIX_EXIT_SUCCESS;
    size_t  i;
    const char*  buf = NULL;
    int  rv;
@@ -69,14 +69,14 @@ int  test_cancellock(void)
       if(rv)
       {
          print_error("Preparation of configuration failed");
-         res = POSIX_EXIT_FAILURE;
+         res = API_POSIX_EXIT_FAILURE;
          break;
       }
       buf = core_get_cancel_lock(CORE_CL_SHA1, ts[i]);
       if(NULL == buf)
       {
          print_error("Cancel-Lock generation failed");
-         res = POSIX_EXIT_FAILURE;
+         res = API_POSIX_EXIT_FAILURE;
          break;
       }
       if(strcmp(&rs_sha1[i][4], &buf[4]))
@@ -88,7 +88,7 @@ int  test_cancellock(void)
          fprintf(stderr, TEST_TAB "Message-ID: \"%s\"\n", ts[i]);
          fprintf(stderr, TEST_TAB "Result is : \"%s\"\n", buf);
          fprintf(stderr, TEST_TAB "Should be : \"%s\"\n", rs_sha1[i]);
-         res = POSIX_EXIT_FAILURE;
+         res = API_POSIX_EXIT_FAILURE;
          break;
       }
       core_free((void*) buf);
