@@ -2,7 +2,7 @@
 /*! \file
  * \brief Test of \c cmpr_send() and \c cmpr_recv() implementation
  *
- * Copyright (c) 2015-2020 by the developers. See the LICENSE file for details.
+ * Copyright (c) 2015-2024 by the developers. See the LICENSE file for details.
  */
 
 
@@ -39,27 +39,27 @@
 
 
 /* ========================================================================== */
-/* Emulation of \c posix_send() */
+/* Emulation of \c api_posix_send() */
 
 static ssize_t  test_send(int  sd, const void*  buf, size_t  len, int  flags)
 {
-   return(posix_write(sd, buf, len));
+   return(api_posix_write(sd, buf, len));
 }
 
 
 /* ========================================================================== */
-/* Emulation \c posix_recv() */
+/* Emulation \c api_posix_recv() */
 
 static ssize_t  test_recv(int  sd, void*  buf, size_t  len, int  flags)
 {
-   posix_ssize_t  res = -1;
+   api_posix_ssize_t  res = -1;
 
    if(flags)
    {
-      posix_errno = POSIX_EINVAL;
+      api_posix_errno = API_POSIX_EINVAL;
       print_error("test_recv(): Flags not supported");
    }
-   else  { res = posix_read(sd, buf, len); }
+   else  { res = api_posix_read(sd, buf, len); }
 
    return(res);
 }
@@ -118,21 +118,21 @@ int  test_compression(void)
 
       ""
    };
-   int  res = POSIX_EXIT_SUCCESS;
+   int  res = API_POSIX_EXIT_SUCCESS;
 #  if TEST_CMPR_USE_NETWORK
    const char*  echo_host = "localhost";
-   int  af = POSIX_AF_UNSPEC;
+   int  af = API_POSIX_AF_UNSPEC;
 #  else  /* TEST_CMPR_USE_NETWORK */
    const char*  pathname = "/tmp/flnews_loopb";
    int  testfile_open = 0;
-   posix_off_t  rv3;
+   api_posix_off_t  rv3;
 #  endif  /* TEST_CMPR_USE_NETWORK */
    int  sd = -1;
    char  buf[BUF_LEN + (size_t) 1];
    size_t  i;
    const char*  loc;
    int  rv;
-   posix_ssize_t  rv2;
+   api_posix_ssize_t  rv2;
    void*  cs = NULL;
    size_t  len;
 
@@ -142,12 +142,12 @@ int  test_compression(void)
    if(rv)
    {
       print_error("This test requires an echo daemon running on localhost");
-      res = POSIX_EXIT_FAILURE;
+      res = API_POSIX_EXIT_FAILURE;
    }
 #  else  /* TEST_CMPR_USE_NETWORK */
    /* Use regular file as loopback facility */
    rv = fu_open_file(pathname, &sd,
-                     POSIX_O_RDWR | POSIX_O_CREAT | POSIX_O_TRUNC,
+                     API_POSIX_O_RDWR | API_POSIX_O_CREAT | API_POSIX_O_TRUNC,
                      TEST_PERM);
    if(!rv)
    {
@@ -157,25 +157,25 @@ int  test_compression(void)
    if(rv)
    {
       print_error("Creating or locking test file failed");
-      res = POSIX_EXIT_FAILURE;
+      res = API_POSIX_EXIT_FAILURE;
    }
    else  { testfile_open = 1; }
 #  endif  /* TEST_CMPR_USE_NETWORK */
 
    /* Create compressed data stream */
-   if(POSIX_EXIT_SUCCESS == res)
+   if(API_POSIX_EXIT_SUCCESS == res)
    {
       cs = cmpr_stream_constructor(CMPR_ALG_DEFLATE, sd,
 #  if TEST_CMPR_USE_NETWORK
-                                   posix_send, posix_recv);
+                                   api_posix_send, api_posix_recv);
 #  else  /* TEST_CMPR_USE_NETWORK */
                                    test_send, test_recv);
 #  endif  /* TEST_CMPR_USE_NETWORK */
-      if(NULL == cs)  { res = POSIX_EXIT_FAILURE; }
+      if(NULL == cs)  { res = API_POSIX_EXIT_FAILURE; }
    }
 
    /* Loopback test */
-   if(POSIX_EXIT_SUCCESS == res)
+   if(API_POSIX_EXIT_SUCCESS == res)
    {
       for(i = 0; i < TS_NUM; ++i)
       {
@@ -184,26 +184,26 @@ int  test_compression(void)
          if(BUF_LEN < len)
          {
             print_error("Length of test string too long");
-            res = POSIX_EXIT_FAILURE;
+            res = API_POSIX_EXIT_FAILURE;
             break;
          }
 #  if !TEST_CMPR_USE_NETWORK
 #     if CFG_USE_POSIX_API >= 200112 || CFG_USE_XSI
          /* Truncate test file */
-         rv = posix_ftruncate(sd, (posix_off_t) 0);
+         rv = api_posix_ftruncate(sd, (api_posix_off_t) 0);
          if(rv)
          {
             print_error("Truncation of test file failed");
-            res = POSIX_EXIT_FAILURE;
+            res = API_POSIX_EXIT_FAILURE;
             break;
          }
 #     endif  /* CFG_USE_POSIX_API >= 200112 || CFG_USE_XSI */
          /* Reset offset of test file to zero */
-         rv3 = posix_lseek(sd, (posix_off_t) 0, POSIX_SEEK_SET);
-         if((posix_off_t) -1 == rv3)
+         rv3 = api_posix_lseek(sd, (api_posix_off_t) 0, API_POSIX_SEEK_SET);
+         if((api_posix_off_t) -1 == rv3)
          {
             print_error("Seek in test file failed");
-            res = POSIX_EXIT_FAILURE;
+            res = API_POSIX_EXIT_FAILURE;
             break;
          }
 #  endif  /* ! TEST_CMPR_USE_NETWORK */
@@ -211,23 +211,23 @@ int  test_compression(void)
          rv2 = cmpr_send(cs, ts[i], len);
          if(0 >= rv2)
          {
-            res = POSIX_EXIT_FAILURE;
+            res = API_POSIX_EXIT_FAILURE;
             break;
          }
          /* Flush */
          rv = cmpr_flush(cs);
          if(rv)
          {
-            res = POSIX_EXIT_FAILURE;
+            res = API_POSIX_EXIT_FAILURE;
             break;
          }
 #  if !TEST_CMPR_USE_NETWORK
          /* Rewind test file offset to zero */
-         rv3 = posix_lseek(sd, (posix_off_t) 0, POSIX_SEEK_SET);
-         if((posix_off_t) -1 == rv3)
+         rv3 = api_posix_lseek(sd, (api_posix_off_t) 0, API_POSIX_SEEK_SET);
+         if((api_posix_off_t) -1 == rv3)
          {
             print_error("Seek in test file failed");
-            res = POSIX_EXIT_FAILURE;
+            res = API_POSIX_EXIT_FAILURE;
             break;
          }
 #  endif  /* ! TEST_CMPR_USE_NETWORK */
@@ -235,7 +235,7 @@ int  test_compression(void)
          rv2 = cmpr_recv(cs, buf, len, 0);
          if(0 >= rv2)
          {
-            res = POSIX_EXIT_FAILURE;
+            res = API_POSIX_EXIT_FAILURE;
             break;
          }
          /* Compare */
@@ -244,7 +244,7 @@ int  test_compression(void)
             print_error("Result is not correct");
             /* For debugging */
 #  if CFG_USE_POSIX_API >= 200112 || CFG_USE_XSI
-            loc = posix_setlocale(POSIX_LC_CTYPE, "");
+            loc = api_posix_setlocale(API_POSIX_LC_CTYPE, "");
 #  else  /* CFG_USE_POSIX_API >= 200112 || CFG_USE_XSI */
             loc = NULL;
 #  endif  /* CFG_USE_POSIX_API >= 200112 || CFG_USE_XSI */
@@ -266,7 +266,7 @@ int  test_compression(void)
                   fprintf(stderr, TEST_TAB "Data received: \"%s\"\n", buf);
                }
             }
-            res = POSIX_EXIT_FAILURE;
+            res = API_POSIX_EXIT_FAILURE;
             break;
          }
       }
