@@ -1,8 +1,8 @@
 /* ========================================================================== */
 /*! \file
- * \brief Test of \c posix_inet_pton() implementation
+ * \brief Test of \c api_posix_inet_pton() implementation
  *
- * Copyright (c) 2017-2020 by the developers. See the LICENSE file for details.
+ * Copyright (c) 2017-2024 by the developers. See the LICENSE file for details.
  */
 
 
@@ -25,7 +25,7 @@
 
 
 /* ========================================================================== */
-/*! \brief Test \c posix_inet_pton() implementation
+/*! \brief Test \c api_posix_inet_pton() implementation
  *
  * The following cases are tested:
  * - Valid IPv4 address with maximum length
@@ -39,11 +39,11 @@
 
 int  test_inet_pton(void)
 {
-   int  res = POSIX_EXIT_SUCCESS;
+   int  res = API_POSIX_EXIT_SUCCESS;
    const char*  s;
    CFG_UINT32_TYPE  expected1 = (CFG_UINT32_TYPE) 3232261220UL;
    CFG_UINT32_TYPE  expected2 = (CFG_UINT32_TYPE) 16909060UL;
-   posix_in_addr_t  valh, valn;
+   api_posix_in_addr_t  valh, valn;
    int  rv;
 
    /*
@@ -52,22 +52,22 @@ int  test_inet_pton(void)
     */
    s = "192.168.100.100";
    valn = 0;
-   rv = posix_inet_pton(POSIX_AF_INET, s, &valn);
+   rv = api_posix_inet_pton(API_POSIX_AF_INET, s, &valn);
    if(!rv)
    {
       print_error("Conversion failed");
-      res = POSIX_EXIT_FAILURE;
+      res = API_POSIX_EXIT_FAILURE;
 
       /* For debugging */
       fprintf(stderr, TEST_TAB "Input: \"%s\"\n", s);
    }
    if(1 == rv)
    {
-      valh = posix_ntohl(valn);
+      valh = api_posix_ntohl(valn);
       if(expected1 != valh)
       {
          print_error("Result is not correct");
-         res = POSIX_EXIT_FAILURE;
+         res = API_POSIX_EXIT_FAILURE;
 
          /* For debugging */
          fprintf(stderr, TEST_TAB "Input: \"%s\"\n", s);
@@ -86,22 +86,22 @@ int  test_inet_pton(void)
        */
       s = "1.2.3.4";
       valn = 0;
-      rv = posix_inet_pton(POSIX_AF_INET, s, &valn);
+      rv = api_posix_inet_pton(API_POSIX_AF_INET, s, &valn);
       if(!rv)
       {
          print_error("Conversion failed");
-         res = POSIX_EXIT_FAILURE;
+         res = API_POSIX_EXIT_FAILURE;
 
          /* For debugging */
          fprintf(stderr, TEST_TAB "Input: \"%s\"\n", s);
       }
       if(1 == rv)
       {
-         valh = posix_ntohl(valn);
+         valh = api_posix_ntohl(valn);
          if(expected2 != valh)
          {
             print_error("Result is not correct");
-            res = POSIX_EXIT_FAILURE;
+            res = API_POSIX_EXIT_FAILURE;
 
             /* For debugging */
             fprintf(stderr, TEST_TAB "Input: \"%s\"\n", s);
@@ -121,11 +121,11 @@ int  test_inet_pton(void)
        */
       s = "x192.168.100.100";
       valn = 0;
-      rv = posix_inet_pton(POSIX_AF_INET, s, &valn);
+      rv = api_posix_inet_pton(API_POSIX_AF_INET, s, &valn);
       if(rv)
       {
          print_error("Conversion succeeded for invalid input");
-         res = POSIX_EXIT_FAILURE;
+         res = API_POSIX_EXIT_FAILURE;
 
          /* For debugging */
          fprintf(stderr, TEST_TAB "Input: \"%s\"\n", s);
