@@ -2,7 +2,7 @@
 /*! \file
  * \brief Test of \c enc_timestamp_decode() implementation
  *
- * Copyright (c) 2012-2022 by the developers. See the LICENSE file for details.
+ * Copyright (c) 2012-2024 by the developers. See the LICENSE file for details.
  */
 
 
@@ -65,7 +65,7 @@ int  test_timestamp(void)
       2087931600U,
       347153400U
    };
-   int  res = POSIX_EXIT_SUCCESS;
+   int  res = API_POSIX_EXIT_SUCCESS;
    int  rv;
    size_t  i;
 
@@ -75,7 +75,7 @@ int  test_timestamp(void)
       if(!rv)
       {
          print_error("Timestamp decoder failed");
-         res = POSIX_EXIT_FAILURE;
+         res = API_POSIX_EXIT_FAILURE;
          break;
       }
       if(t[i] != rv)
@@ -87,7 +87,7 @@ int  test_timestamp(void)
                  (unsigned long int) rv);
          fprintf(stderr, TEST_TAB "Should be: \"%lu\"\n",
                  (unsigned long int) t[i]);
-         res = POSIX_EXIT_FAILURE;
+         res = API_POSIX_EXIT_FAILURE;
          break;
       }
    }
