@@ -2,7 +2,7 @@
 /*! \file
  * \brief Test of \c enc_convert_to_utf8_nfc() implementation
  *
- * Copyright (c) 2012-2022 by the developers. See the LICENSE file for details.
+ * Copyright (c) 2012-2024 by the developers. See the LICENSE file for details.
  */
 
 
@@ -54,6 +54,39 @@ enum sm_state
 /*! @{ */
 
 
+/* ========================================================================== */
+/* Create octet representation for debug output
+ *
+ * \param[out] ob         Pointer to buffer for human readable octets
+ * \param[in]  len_ob     Size of buffer at address \e ob
+ * \param[in]  uc_string  Unicode string in UTF-8 format
+ *
+ * \e len_ob must be at least (3 * strlen( \e uc_string ))
+ *
+ * \note Only the first 16 octets are printed.
+ */
+
+void test_unicode_octets(char*  ob, size_t  len_ob, const char*  uc_string)
+{
+    size_t  len = strlen(uc_string);
+    size_t  i   = 0;
+
+    if (0U == len_ob || 3U * len > len_ob)
+    {
+       ob[0] = 0;
+       return;
+    }
+
+    for (; len > i; ++i)
+    {
+        api_posix_snprintf(&ob[3U * i], len_ob - 3U * i,
+                           "%02X ", (unsigned int)(unsigned char)uc_string[i]);
+    }
+
+    ob[3U * len - 1] = 0;
+}
+
+
 /* ========================================================================== */
 /* Test Unicode conformance with official test data
  *
@@ -75,7 +108,7 @@ static int  test_unicode_conformance(size_t  record, const char*  src_utf8,
                                      const char*  nfc_utf8,
                                      const char*  nfd_utf8)
 {
-   int  res = POSIX_EXIT_SUCCESS;
+   int  res = API_POSIX_EXIT_SUCCESS;
    const char*  buf1 = NULL;
    const char*  buf2 = NULL;
    const char*  buf3 = NULL;
@@ -86,9 +119,9 @@ static int  test_unicode_conformance(size_t  record, const char*  src_utf8,
 #if 0
    /* For debugging */
    printf("================\nrecord: %u\n", (unsigned int) record);
-   printf("src_utf8: %s\n", src_utf8);
-   printf("nfc_utf8: %s\n", nfc_utf8);
-   printf("nfd_utf8: %s\n", nfd_utf8);
+   printf("src_utf8: \"%s\"\n", src_utf8);
+   printf("nfc_utf8: \"%s\"\n", nfc_utf8);
+   printf("nfd_utf8: \"%s\"\n", nfd_utf8);
    printf("================\n"),
 #endif
 
@@ -98,56 +131,56 @@ static int  test_unicode_conformance(size_t  record, const char*  src_utf8,
    if(NULL == buf1)
    {
       print_error("Conversion SRC => NFC failed");
-      res = POSIX_EXIT_FAILURE;
+      res = API_POSIX_EXIT_FAILURE;
    }
    else if(strcmp(nfc_utf8, buf1))
    {
       print_error("Result mismatch for SRC => NFC");
       err = buf1;
-      res = POSIX_EXIT_FAILURE;
+      res = API_POSIX_EXIT_FAILURE;
    }
 
    /* nfc_utf8 == toNFC(nfc_utf8) */
-   if(POSIX_EXIT_SUCCESS == res)
+   if(API_POSIX_EXIT_SUCCESS == res)
    {
       input = nfc_utf8;
       buf2 = enc_convert_to_utf8_nfc(ENC_CS_UTF_8, input);
       if(NULL == buf2)
       {
          print_error("Conversion NFC => NFC failed");
-         res = POSIX_EXIT_FAILURE;
+         res = API_POSIX_EXIT_FAILURE;
       }
       else if(strcmp(nfc_utf8, buf2))
       {
          print_error("Result mismatch for NFC => NFC");
          err = buf2;
-         res = POSIX_EXIT_FAILURE;
+         res = API_POSIX_EXIT_FAILURE;
       }
    }
 
    /* nfc_utf8 == toNFC(nfd_utf8) */
-   if(POSIX_EXIT_SUCCESS == res)
+   if(API_POSIX_EXIT_SUCCESS == res)
    {
       input = nfd_utf8;
       buf3 = enc_convert_to_utf8_nfc(ENC_CS_UTF_8, input);
       if(NULL == buf3)
       {
          print_error("Conversion NFD => NFC failed");
-         res = POSIX_EXIT_FAILURE;
+         res = API_POSIX_EXIT_FAILURE;
       }
       else if(strcmp(nfc_utf8, buf3))
       {
          print_error("Result mismatch for NFD => NFC");
          err = buf3;
-         res = POSIX_EXIT_FAILURE;
+         res = API_POSIX_EXIT_FAILURE;
       }
    }
 
    /* For debugging */
-   if(POSIX_EXIT_SUCCESS != res && NULL != err)
+   if(API_POSIX_EXIT_SUCCESS != res && NULL != err)
    {
 #if CFG_USE_POSIX_API >= 200112 || CFG_USE_XSI
-      loc = posix_setlocale(POSIX_LC_CTYPE, "");
+      loc = api_posix_setlocale(API_POSIX_LC_CTYPE, "");
 #else  /* CFG_USE_POSIX_API >= 200112 || CFG_USE_XSI */
       loc = NULL;
 #endif  /* CFG_USE_POSIX_API >= 200112 || CFG_USE_XSI */
@@ -165,11 +198,17 @@ static int  test_unicode_conformance(size_t  record, const char*  src_utf8,
          }
          else
          {
+#define TEST_BUFSIZE  60U
+            char ob[TEST_BUFSIZE];  /* Buffer for human readable octets */
+
             fprintf(stderr, TEST_TAB "Record number in test data file: %lu\n",
                     (unsigned long int) record);
-            fprintf(stderr, TEST_TAB "Input data: \"%s\"\n", input);
-            fprintf(stderr, TEST_TAB "Result is : \"%s\"\n", err);
-            fprintf(stderr, TEST_TAB "Should be : \"%s\"\n", nfc_utf8);
+            test_unicode_octets(ob, TEST_BUFSIZE, input);
+            fprintf(stderr, TEST_TAB "Input data: \"%s\" (%s)\n", input, ob);
+            test_unicode_octets(ob, TEST_BUFSIZE, err);
+            fprintf(stderr, TEST_TAB "Result is : \"%s\" (%s)\n", err, ob);
+            test_unicode_octets(ob, TEST_BUFSIZE, nfc_utf8);
+            fprintf(stderr, TEST_TAB "Should be : \"%s\" (%s)\n", nfc_utf8, ob);
          }
       }
    }
@@ -193,7 +232,7 @@ static int  test_unicode_conformance(size_t  record, const char*  src_utf8,
 
 static int  test_unicode_part2(void)
 {
-   int  res = POSIX_EXIT_SUCCESS;
+   int  res = API_POSIX_EXIT_SUCCESS;
    size_t  i = 0;
    long int  ucp = -1L;
    enum sm_state  state = SM_SRC;
@@ -210,7 +249,7 @@ static int  test_unicode_part2(void)
    size_t  rec = 0;
 
    /* Assignment in truth expression is intended */
-   while(POSIX_EXIT_SUCCESS == res && -1 != (ucp = uc_test_nfc_table[i++]))
+   while(API_POSIX_EXIT_SUCCESS == res && -1 != (ucp = uc_test_nfc_table[i++]))
    {
       /* Test sequence parser (-2: Field separator, -3: Record separator) */
       switch(state)
@@ -221,14 +260,14 @@ static int  test_unicode_part2(void)
             else if(0L > ucp)
             {
                print_error("Invalid data found");
-               res = POSIX_EXIT_FAILURE;
+               res = API_POSIX_EXIT_FAILURE;
             }
             else
             {
                if(BUFSIZE <= src_i)
                {
                   print_error("SRC data buffer too small");
-                  res = POSIX_EXIT_FAILURE;
+                  res = API_POSIX_EXIT_FAILURE;
                }
                else  { src[src_i++] = ucp; }
             }
@@ -240,14 +279,14 @@ static int  test_unicode_part2(void)
             else if(0L > ucp)
             {
                print_error("Invalid data found");
-               res = POSIX_EXIT_FAILURE;
+               res = API_POSIX_EXIT_FAILURE;
             }
             else
             {
                if(BUFSIZE <= nfc_i)
                {
                   print_error("NFC data buffer too small");
-                  res = POSIX_EXIT_FAILURE;
+                  res = API_POSIX_EXIT_FAILURE;
                }
                else  { nfc[nfc_i++] = ucp; }
             }
@@ -270,7 +309,7 @@ static int  test_unicode_part2(void)
                if(src_i || nfc_i || nfd_i)
                {
                   print_error("Encoding test data to UTF-8 failed");
-                  res = POSIX_EXIT_FAILURE;
+                  res = API_POSIX_EXIT_FAILURE;
                }
                else
                {
@@ -284,14 +323,14 @@ static int  test_unicode_part2(void)
             else if(0L > ucp)
             {
                print_error("Invalid data found");
-               res = POSIX_EXIT_FAILURE;
+               res = API_POSIX_EXIT_FAILURE;
             }
             else
             {
                if(BUFSIZE <= nfd_i)
                {
                   print_error("NFD data buffer too small");
-                  res = POSIX_EXIT_FAILURE;
+                  res = API_POSIX_EXIT_FAILURE;
                }
                else  { nfd[nfd_i++] = ucp; }
             }
@@ -300,7 +339,7 @@ static int  test_unicode_part2(void)
          default:
          {
             print_error("Parser state machine error");
-            res = POSIX_EXIT_FAILURE;
+            res = API_POSIX_EXIT_FAILURE;
             break;
          }
       }
@@ -379,7 +418,7 @@ int  test_unicode(void)
       "This is an Unicode string: Violinschl\xC3\xBCssel (\xF0\x9D\x84\x9E)",
       "Shift sequence terminated by SP or end-of-data: A\xC3\x84 O\xC3\x96 U\xC3\x9C"
    };
-   int  res = POSIX_EXIT_SUCCESS;
+   int  res = API_POSIX_EXIT_SUCCESS;
    size_t  i;
    const char*  buf;
    const char*  loc;
@@ -398,7 +437,7 @@ int  test_unicode(void)
       if(NULL == buf)
       {
          print_error("Conversion of data to UTF-8 failed");
-         res = POSIX_EXIT_FAILURE;
+         res = API_POSIX_EXIT_FAILURE;
          break;
       }
       if(strcmp(rs[i], buf))
@@ -406,7 +445,7 @@ int  test_unicode(void)
          print_error("Result is not correct");
          /* For debugging */
 #if CFG_USE_POSIX_API >= 200112 || CFG_USE_XSI
-         loc = posix_setlocale(POSIX_LC_CTYPE, "");
+         loc = api_posix_setlocale(API_POSIX_LC_CTYPE, "");
 #else  /* CFG_USE_POSIX_API >= 200112 || CFG_USE_XSI */
          loc = NULL;
 #endif  /* CFG_USE_POSIX_API >= 200112 || CFG_USE_XSI */
@@ -429,14 +468,14 @@ int  test_unicode(void)
                fprintf(stderr, TEST_TAB "Should be : \"%s\"\n", rs[i]);
             }
          }
-         res = POSIX_EXIT_FAILURE;
+         res = API_POSIX_EXIT_FAILURE;
          break;
       }
       if(buf != ts[i])  { enc_free((void*) buf); }
    }
 
    /* Part 2: Check with external test data (from Unicode data file) */
-   if(POSIX_EXIT_SUCCESS == res)
+   if(API_POSIX_EXIT_SUCCESS == res)
    {
       res = test_unicode_part2();
    }
