@@ -2,7 +2,7 @@
 /*! \file
  * \brief Transport layer security
  *
- * Copyright (c) 2012-2022 by the developers. See the LICENSE file for details.
+ * Copyright (c) 2012-2024 by the developers. See the LICENSE file for details.
  *
  * If nothing else is specified, function return zero to indicate success
  * and a negative value to indicate an error.
@@ -237,7 +237,7 @@
 /* ========================================================================== */
 /* Variables */
 
-static posix_locale_t  tls_loc_ctype_posix = 0;
+static api_posix_locale_t  tls_loc_ctype_posix = 0;
 static SSL_CTX*  tls_ctx = NULL;  /* Global context for all connections */
 #  if CFG_USE_OPENSSL_API_1_1
 static SSL_CONF_CTX*  cctx;  /* Global configuration context */
@@ -299,7 +299,7 @@ static int  tls_cert_check_root(X509*  cc, int*  is_root, size_t  bufsize,
          if(!len)  { res = -1; }
          else
          {
-            b_i = (char*) posix_malloc(len + (size_t) 1);
+            b_i = (char*) api_posix_malloc(len + (size_t) 1);
             if(NULL == b_i)  { res = -1; }
             else
             {
@@ -330,7 +330,7 @@ static int  tls_cert_check_root(X509*  cc, int*  is_root, size_t  bufsize,
             if(!len)  { res = -1; }
             else
             {
-               b_s = (char*) posix_malloc(len + (size_t) 1);
+               b_s = (char*) api_posix_malloc(len + (size_t) 1);
                if(NULL == b_s)  { res = -1; }
                else
                {
@@ -373,8 +373,8 @@ static int  tls_cert_check_root(X509*  cc, int*  is_root, size_t  bufsize,
    }
 
    /* Release memory */
-   posix_free((void*) b_i);
-   posix_free((void*) b_s);
+   api_posix_free((void*) b_i);
+   api_posix_free((void*) b_s);
    if(NULL != biop)  { BIO_free(biop); }
 
    return(res);
@@ -406,7 +406,7 @@ static int  tls_get_certpath(const char**  certpath)
       if(0 == rv)
       {
          /* Create database directory if it doesn't exist */
-         res = fu_create_path(*certpath, (posix_mode_t) POSIX_S_IRWXU);
+         res = fu_create_path(*certpath, (api_posix_mode_t) API_POSIX_S_IRWXU);
       }
    }
 
@@ -414,7 +414,7 @@ static int  tls_get_certpath(const char**  certpath)
    if(res)
    {
       PRINT_ERROR("Cannot create certificate directory");
-      posix_free((void*) *certpath);
+      api_posix_free((void*) *certpath);
       *certpath = NULL;
    }
 
@@ -437,7 +437,7 @@ static int  tls_get_certpath(const char**  certpath)
 static int  tls_check_crl_age(void)
 {
    int  res;
-   posix_time_t  ts;
+   api_posix_time_t  ts;
    core_time_t  pts_last;
    core_time_t  pts_current;
    core_time_t  age;
@@ -446,8 +446,8 @@ static int  tls_check_crl_age(void)
    res = enc_convert_iso8601_to_posix(&pts_last, config[CONF_CRL_UPD_TS].val.s);
    if(!res)
    {
-      posix_time(&ts);
-      if((posix_time_t) 0 > ts)  { res = -1; }
+      api_posix_time(&ts);
+      if((api_posix_time_t) 0 > ts)  { res = -1; }
       else
       {
          pts_current = (core_time_t) ts;
@@ -538,7 +538,7 @@ static int  tls_get_crlpath(const char**  crlpath)
       if(0 == rv)
       {
          /* Create database directory if it doesn't exist */
-         res = fu_create_path(*crlpath, (posix_mode_t) POSIX_S_IRWXU);
+         res = fu_create_path(*crlpath, (api_posix_mode_t) API_POSIX_S_IRWXU);
       }
    }
 
@@ -546,7 +546,7 @@ static int  tls_get_crlpath(const char**  crlpath)
    if(res)
    {
       PRINT_ERROR("Cannot create CRL directory");
-      posix_free((void*) *crlpath);
+      api_posix_free((void*) *crlpath);
       *crlpath = NULL;
    }
 
@@ -589,7 +589,7 @@ static int  tls_download_crl(int  cci, const char*  uri, char**  pn)
       }
       else
       {
-         rv = posix_snprintf(&filename[4], 4, "%d", cci);
+         rv = api_posix_snprintf(&filename[4], 4, "%d", cci);
          if(1 > rv || 3 < rv)
          {
             PRINT_ERROR("Download of CRL failed, filename invalid");
@@ -598,7 +598,7 @@ static int  tls_download_crl(int  cci, const char*  uri, char**  pn)
          {
             len = strlen(tls_crlpath);
             len += strlen(filename);
-            pathname = (char*) posix_malloc(++len);
+            pathname = (char*) api_posix_malloc(++len);
             if(NULL != pathname)
             {
                strcpy(pathname, tls_crlpath);
@@ -613,7 +613,7 @@ static int  tls_download_crl(int  cci, const char*  uri, char**  pn)
    /* Release memory for buffer on error */
    if(res)
    {
-      posix_free((void*) *pn);
+      api_posix_free((void*) *pn);
       *pn = NULL;
    }
 
@@ -645,7 +645,7 @@ static int  tls_convert_crl_to_pem(const char*  pn_der, char**  pn_pem)
    /* Prepare target filename */
    len = strlen(pn_der);
    len += 4;  /* for ".pem" Extension */
-   *pn_pem = (char*) posix_malloc(++len);
+   *pn_pem = (char*) api_posix_malloc(++len);
    if(NULL == *pn_pem)
    {
       PRINT_ERROR("Memory allocation failed for filename");
@@ -715,8 +715,8 @@ static int  tls_convert_crl_to_pem(const char*  pn_der, char**  pn_pem)
       res = -1;
       /* Create CRL file with desired permissions, then reopen it via BIO */
       /* Attention: Calling 'umask()' would affect other threads! */
-      rv = fu_open_file(*pn_pem, &fd, POSIX_O_WRONLY | POSIX_O_CREAT,
-                        POSIX_S_IRUSR | POSIX_S_IWUSR);
+      rv = fu_open_file(*pn_pem, &fd, API_POSIX_O_WRONLY | API_POSIX_O_CREAT,
+                        API_POSIX_S_IRUSR | API_POSIX_S_IWUSR);
       if(!rv)
       {
          fu_close_file(&fd, NULL);
@@ -751,14 +751,14 @@ static int  tls_convert_crl_to_pem(const char*  pn_der, char**  pn_pem)
    /* Create symlink if CRL is already in PEM format */
    if(1 == res)
    {
-      res = posix_symlink(pn_der, *pn_pem);
+      res = api_posix_symlink(pn_der, *pn_pem);
    }
 
    /* Release memory for buffer on error */
    if(res)
    {
       PRINT_ERROR("Conversion of CRL to PEM format failed");
-      posix_free((void*) *pn_pem);
+      api_posix_free((void*) *pn_pem);
       *pn_pem = NULL;
    }
 
@@ -805,7 +805,8 @@ static int  tls_create_hash_symlink(const char*  pn_pem, X509*  cert)
       {
          issuer_hash = X509_issuer_name_hash(cert);
          /* See 'c_rehash' manual for the name format */
-         rv = posix_snprintf(name_symlink, 13, "/%08lx.r%u", issuer_hash, i);
+         rv = api_posix_snprintf(name_symlink, 13, "/%08lx.r%u", issuer_hash,
+                                 i);
          if(12 != rv)
          {
             PRINT_ERROR("Creating of symlink failed, name not valid");
@@ -815,13 +816,13 @@ static int  tls_create_hash_symlink(const char*  pn_pem, X509*  cert)
          {
             len = strlen(tls_crlpath);
             len += strlen(name_symlink);
-            pn_symlink = (char*) posix_malloc(++len);
+            pn_symlink = (char*) api_posix_malloc(++len);
             if(NULL == pn_symlink)  { abort = 1; }
             else
             {
                strcpy(pn_symlink, tls_crlpath);
                strcat(pn_symlink, name_symlink);
-               res = posix_symlink(pn_pem, pn_symlink);
+               res = api_posix_symlink(pn_pem, pn_symlink);
                if(!res)
                {
                   /* Success */
@@ -830,14 +831,14 @@ static int  tls_create_hash_symlink(const char*  pn_pem, X509*  cert)
                else
                {
                   /* Check whether symlink already exist */
-                  if(!(-1 == res && POSIX_EEXIST == posix_errno))
+                  if(!(-1 == res && API_POSIX_EEXIST == api_posix_errno))
                   {
                      /* No => Creation failed => Abort */
                      PRINT_ERROR("Creating of symlink failed");
                      abort = 1;
                   }
                }
-               posix_free((void*) pn_symlink);
+               api_posix_free((void*) pn_symlink);
             }
          }
          ++i;
@@ -869,7 +870,7 @@ static int  tls_crl_get_lock(int*  fd)
    lockpathname = xdg_get_confdir(CFG_NAME);
    if(NULL != lockpathname)
    {
-      rv = fu_create_path(lockpathname, (posix_mode_t) POSIX_S_IRWXU);
+      rv = fu_create_path(lockpathname, (api_posix_mode_t) API_POSIX_S_IRWXU);
       if(0 == rv)
       {
          /* Store lock file pathname */
@@ -877,8 +878,8 @@ static int  tls_crl_get_lock(int*  fd)
          if(0 == rv)
          {
             rv = fu_open_file(lockpathname, fd,
-                              POSIX_O_WRONLY | POSIX_O_CREAT,
-                              POSIX_S_IRUSR | POSIX_S_IWUSR);
+                              API_POSIX_O_WRONLY | API_POSIX_O_CREAT,
+                              API_POSIX_S_IRUSR | API_POSIX_S_IWUSR);
             if(rv)
             {
                PRINT_ERROR("Cannot open mutex file for CRL directory");
@@ -898,7 +899,7 @@ static int  tls_crl_get_lock(int*  fd)
          }
       }
    }
-   posix_free((void*) lockpathname);
+   api_posix_free((void*) lockpathname);
 
    return(res);
 }
@@ -964,7 +965,8 @@ static int  tls_update_crls(STACK_OF(X509)*  certificate_chain)
       {
          if(!fu_delete_tree(tls_crlpath))
          {
-            if(!posix_mkdir(tls_crlpath, (posix_mode_t) POSIX_S_IRWXU))
+            if(!api_posix_mkdir(tls_crlpath,
+                                (api_posix_mode_t) API_POSIX_S_IRWXU))
             {
                /* Empty CRL directory is now available */
                crlpath_ok = 1;
@@ -1081,8 +1083,8 @@ static int  tls_update_crls(STACK_OF(X509)*  certificate_chain)
                                  }
                               }
                               /* Release memory allocated for pathnames */
-                              posix_free((void*) crl_pn_pem);
-                              posix_free((void*) crl_pn_der);
+                              api_posix_free((void*) crl_pn_pem);
+                              api_posix_free((void*) crl_pn_der);
                               break;
                            }
                         }
@@ -1147,7 +1149,7 @@ static int  tls_chain_check_sigalgs(STACK_OF(X509)*  certificate_chain,
    int  cci;  /* Index in certificate chain */
    X509*  cc;  /* Current certificate */
    int  rv;
-   posix_ssize_t  rv2;
+   api_posix_ssize_t  rv2;
    int  is_root = 0;
    const char*  s;
    EVP_PKEY*  pkey = NULL;
@@ -1258,8 +1260,8 @@ static int  tls_chain_check_sigalgs(STACK_OF(X509)*  certificate_chain,
          else
          {
             /* 'SubjectPublicKeyInfo' structure now stored in buf */
-            rv2 = posix_snprintf(prefix, 80, "%s: %s   ",
-                                 CFG_NAME, MAIN_ERR_PREFIX);
+            rv2 = api_posix_snprintf(prefix, 80, "%s: %s   ",
+                                     CFG_NAME, MAIN_ERR_PREFIX);
             if(0 > rv2)
             {
                PRINT_ERROR("Creating message prefix failed");
@@ -1398,7 +1400,7 @@ static int  tls_subject_check(const char*  cn, const char*  subject)
    if(!res)
    {
       /* Compare using POSIX locale */
-      res = posix_strcasecmp_l(cn, subject, tls_loc_ctype_posix);
+      res = api_posix_strcasecmp_l(cn, subject, tls_loc_ctype_posix);
    }
    if(0 < res)  { res = -res; }
 
@@ -1742,10 +1744,10 @@ static void  tls_destroy_context(void)
       tls_ctx = NULL;
    }
 
-   posix_free((void*) tls_certpath);
+   api_posix_free((void*) tls_certpath);
    tls_certpath = NULL;
 #  if !CFG_TLS_CRLS_DISABLE
-   posix_free((void*) tls_crlpath);
+   api_posix_free((void*) tls_crlpath);
    tls_crlpath = NULL;
 #  endif  /* !CFG_TLS_CRLS_DISABLE */
 }
@@ -1764,9 +1766,9 @@ int  tls_init(void)
    int  res = 0;
 
    /* Create a locale object with LC_CTYPE == POSIX */
-   tls_loc_ctype_posix = posix_newlocale(POSIX_LC_CTYPE_MASK, "POSIX",
-                                         (posix_locale_t) 0);
-   if((posix_locale_t) 0 == tls_loc_ctype_posix)
+   tls_loc_ctype_posix = api_posix_newlocale(API_POSIX_LC_CTYPE_MASK, "POSIX",
+                                             (api_posix_locale_t) 0);
+   if((api_posix_locale_t) 0 == tls_loc_ctype_posix)
    {
       PRINT_ERROR("Cannot create locale object");
       res = -1;
@@ -1812,9 +1814,9 @@ int  tls_init(void)
 
 void  tls_exit(void)
 {
-   if((posix_locale_t) 0 != tls_loc_ctype_posix)
+   if((api_posix_locale_t) 0 != tls_loc_ctype_posix)
    {
-      posix_freelocale(tls_loc_ctype_posix);
+      api_posix_freelocale(tls_loc_ctype_posix);
    }
 
    /* Since OpenSSL 1.1.0 explicit cleanup is no longer required */
@@ -1847,6 +1849,8 @@ void  tls_exit(void)
  * 0x20000000 (2.0.0 dev, reported by LibreSSL)
  * <br>
  * 0x30000000 (3.0.0 dev, reported by OpenSSL Alpha versions)
+ * <br>
+ * 0x300000D0 (3.0.13 release)
  *
  * \note
  * LibreSSL always reports the same OpenSSL version.
@@ -1916,20 +1920,20 @@ int  tls_vulnerability_check(int  check)
 #  if CFG_USE_LIBRESSL && defined(LIBRESSL_VERSION_NUMBER)
    /* LibreSSL */
    printf("%s: %sCompiled for LibreSSL\n", CFG_NAME, MAIN_ERR_PREFIX);
-   printf("%s: %sLibreSSL library version: %X.%X.%X (0x%08lX)\n",
+   printf("%s: %sLibreSSL library version: %u.%u.%u (0x%08lX)\n",
           CFG_NAME, MAIN_ERR_PREFIX, major, minor, fix, version);
 #  else   /* CFG_USE_LIBRESSL && LIBRESSL_VERSION_NUMBER */
    /* OpenSSL */
 #     if CFG_USE_OPENSSL_API_3
-   printf("%s: %sOpenSSL library version: %X.%X.%X (0x%08lX)\n",
+   printf("%s: %sOpenSSL library version: %u.%u.%u (0x%08lX)\n",
           CFG_NAME, MAIN_ERR_PREFIX, major, minor, patch, version);
 #     else  /* CFG_USE_OPENSSL_API_3 */
-   printf("%s: %sOpenSSL library version: %X.%X.%X%s (0x%08lX)\n",
+   printf("%s: %sOpenSSL library version: %u.%u.%u%s (0x%08lX)\n",
           CFG_NAME, MAIN_ERR_PREFIX, major, minor, fix, patch_string, version);
 #     endif  /* CFG_USE_OPENSSL_API_3 */
 #  endif  /* CFG_USE_LIBRESSL && LIBRESSL_VERSION_NUMBER */
 
-   /* Print message if TLSv1.3 is avialable */
+   /* Print message if TLSv1.3 is available */
 #  if CFG_USE_OPENSSL_API_1_1 && (OPENSSL_VERSION_NUMBER >= 0x10101000L) \
    || CFG_USE_LIBRESSL && (LIBRESSL_VERSION_NUMBER >= 0x30101000L)
    printf("%s: %sProtocol version TLSv1.3 available for negotiation\n",
@@ -2006,10 +2010,10 @@ const char*  tls_sni(const char*  sn)
    const char*  res = NULL;
    unsigned char  buf[16];
 
-   if(1 != posix_inet_pton(POSIX_AF_INET, sn, buf))
+   if(1 != api_posix_inet_pton(API_POSIX_AF_INET, sn, buf))
    {
 #if CFG_USE_IP6
-      if(1 != posix_inet_pton(POSIX_AF_INET6, sn, buf))
+      if(1 != api_posix_inet_pton(API_POSIX_AF_INET6, sn, buf))
       {
          res = sn;
       }
@@ -2168,7 +2172,7 @@ int  tls_open(int  sd, void**  co, int  weak, const char*  sni)
             while((error = ERR_get_error()))
             {
                sp = ERR_reason_error_string(error);
-               posix_snprintf(b, 200, "%sError: %s", MAIN_ERR_PREFIX, sp);
+               api_posix_snprintf(b, 200, "%sError: %s", MAIN_ERR_PREFIX, sp);
                print_error(b);
             }
             res = -1;
@@ -2574,9 +2578,9 @@ int  tls_cert_verify(void**  co, void**  cert, const char*  cn, int  weak)
          {
             sp = X509_verify_cert_error_string(rv);
             /* printf("Errorcode: %d\n", ERR_GET_REASON(rv)); */
-            posix_snprintf(b, 256,
-                           "%sAlert: Server X.509 certificate verification "
-                           "failed (%s)", MAIN_ERR_PREFIX, sp);
+            api_posix_snprintf(b, 256,
+                               "%sAlert: Server X.509 certificate verification "
+                               "failed (%s)", MAIN_ERR_PREFIX, sp);
             print_error(b);
 #  if !CFG_TLS_CRLS_DISABLE
             if(X509_V_ERR_UNABLE_TO_GET_CRL == rv
@@ -2646,11 +2650,11 @@ int  tls_cert_verify(void**  co, void**  cert, const char*  cn, int  weak)
                }
                if(!match)
                {
-                  posix_snprintf(b, 256,
-                                 "%sAlert: Server X.509 certificate "
-                                 "verification failed "
-                                 "(Subject doesn't match hostname %s)",
-                                 MAIN_ERR_PREFIX, cn);
+                  api_posix_snprintf(b, 256,
+                                     "%sAlert: Server X.509 certificate "
+                                    "verification failed "
+                                     "(Subject doesn't match hostname %s)",
+                                    MAIN_ERR_PREFIX, cn);
                   print_error(b);
                }
                else
@@ -2720,7 +2724,7 @@ int  tls_cert_get_string(void*  cert, const char**  cbuf)
       len = (size_t) BIO_get_mem_data(biop, &p);
       if(NULL != p && len)
       {
-         buf = (char*) posix_malloc(len + (size_t) 1);
+         buf = (char*) api_posix_malloc(len + (size_t) 1);
          if(NULL != buf)
          {
             memcpy((void*) buf, (void*) p, len);
@@ -2733,7 +2737,7 @@ int  tls_cert_get_string(void*  cert, const char**  cbuf)
 
    /* Clean up */
    if(NULL != biop)  { BIO_free(biop); }
-   if(res)  { posix_free((void*) buf); }
+   if(res)  { api_posix_free((void*) buf); }
 
    return(res);
 }
@@ -2751,19 +2755,19 @@ int  tls_cert_get_string(void*  cert, const char**  cbuf)
  * - -1 on error
  */
 
-posix_ssize_t  tls_send(void*  co, const void*  buf, size_t  len)
+api_posix_ssize_t  tls_send(void*  co, const void*  buf, size_t  len)
 {
-   posix_ssize_t  res = -1;
+   api_posix_ssize_t  res = -1;
    int  num;
 
    /* Check size */
-   if(POSIX_INT_MAX < len)
+   if(API_POSIX_INT_MAX < len)
    {
       PRINT_ERROR("tls_send(): Data length too large");
    }
    num = (int) len;
 
-   res = (posix_ssize_t) SSL_write((SSL*) co, buf, num);
+   res = (api_posix_ssize_t) SSL_write((SSL*) co, buf, num);
    if(!res)  { res = -1; }
 
    return(res);
@@ -2788,13 +2792,13 @@ posix_ssize_t  tls_send(void*  co, const void*  buf, size_t  len)
  * - -1 on error
  */
 
-posix_ssize_t  tls_recv(void*  co, void*  buf, size_t  len, int  peek)
+api_posix_ssize_t  tls_recv(void*  co, void*  buf, size_t  len, int  peek)
 {
-   posix_ssize_t  res = -1;
+   api_posix_ssize_t  res = -1;
    int  num;
 
    /* Check size */
-   if(POSIX_INT_MAX < len)
+   if(API_POSIX_INT_MAX < len)
    {
       PRINT_ERROR("tls_recv(): Data length too large");
    }
@@ -2807,10 +2811,10 @@ posix_ssize_t  tls_recv(void*  co, void*  buf, size_t  len, int  peek)
       PRINT_ERROR("tls_recv(): "
                   "Flag 'peek' not supported with OpenSSL 1.1.x");
 #  else   /* CFG_USE_OPENSSL_API_1_1 && !CFG_USE_OPENSSL_API_3 */
-      res = (posix_ssize_t) SSL_peek((SSL*) co, buf, num);
+      res = (api_posix_ssize_t) SSL_peek((SSL*) co, buf, num);
 #  endif   /* CFG_USE_OPENSSL_API_1_1 && !CFG_USE_OPENSSL_API_3 */
    }
-   else  { res = (posix_ssize_t) SSL_read((SSL*) co, buf, num); }
+   else  { res = (api_posix_ssize_t) SSL_read((SSL*) co, buf, num); }
    if(!res)  { res = -1; }
 
    return(res);
@@ -2871,6 +2875,8 @@ void  tls_crl_update_control(int crl_upd_disable)
 #  if !CFG_TLS_CRLS_DISABLE
    /* Store CRL update flag */
    tls_crl_update_skip = crl_upd_disable;
+#  else  /* !CFG_TLS_CRLS_DISABLE */
+   (void) crl_upd_disable;
 #  endif  /* !CFG_TLS_CRLS_DISABLE */
 }
 
@@ -2892,7 +2898,7 @@ void  tls_crl_update_control(int crl_upd_disable)
 
 void  tls_free(void*  p)
 {
-   posix_free(p);
+   api_posix_free(p);
 }
 
 
