@@ -2,7 +2,7 @@
 /*! \file
  * \brief Thread safe replacement functions
  *
- * Copyright (c) 2012-2022 by the developers. See the LICENSE file for details.
+ * Copyright (c) 2012-2024 by the developers. See the LICENSE file for details.
  * If nothing else is specified, functions return zero to indicate success
  * and a negative value to indicate an error.
  */
@@ -63,9 +63,9 @@ void  ts_environ_init(void)
    size_t  alen;
 
    /* Calculate size of strings */
-   while(NULL != posix_environ[i])
+   while(NULL != api_posix_environ[i])
    {
-      len += strlen(posix_environ[i]) + (size_t) 1;
+      len += strlen(api_posix_environ[i]) + (size_t) 1;
       ++i;
    }
    /* Calculate size of NULL-terminated pointer array */
@@ -83,11 +83,11 @@ void  ts_environ_init(void)
       {
          i = 0;
          di = 0;
-         while(NULL != posix_environ[i])
+         while(NULL != api_posix_environ[i])
          {
-            strcpy(&environ_data[di], posix_environ[i]);
+            strcpy(&environ_data[di], api_posix_environ[i]);
             environ_copy[i] = &environ_data[di];
-            di += strlen(posix_environ[i]) + (size_t) 1;
+            di += strlen(api_posix_environ[i]) + (size_t) 1;
             ++i;
          }
          environ_copy[i] = NULL;
@@ -106,8 +106,8 @@ void  ts_environ_init(void)
 
 void  ts_environ_exit(void)
 {
-   posix_free((void*) environ_data);
-   posix_free((void*) environ_copy);
+   api_posix_free((void*) environ_data);
+   api_posix_free((void*) environ_copy);
 
    return;
 }
@@ -155,7 +155,7 @@ int  ts_getenv(const char*  name, const char**  buf)
                /* Found => Copy content to target buffer */
                content = &environ_copy[i][++len];
                len = strlen(content);
-               tmp = (char*) posix_realloc((void*) *buf, ++len);
+               tmp = (char*) api_posix_realloc((void*) *buf, ++len);
                if(NULL != tmp)
                {
                   strcpy(tmp, content);
@@ -170,7 +170,7 @@ int  ts_getenv(const char*  name, const char**  buf)
       /* Check for error */
       if(res)
       {
-         posix_free((void*) *buf);
+         api_posix_free((void*) *buf);
          *buf = NULL;
       }
    }
